<?php

namespace MairieBO\MairieImportBundle\Controller;

use Symfony\Component\HttpFoundation\Request;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Method;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use MairieBO\MairieImportBundle\Entity\Mairie;
use MairieBO\MairieImportBundle\Form\MairieType;
use Knp\Snappy\Pdf;
use Doctrine\ORM\Query\ResultSetMapping;

/**
 * Mairie controller.
 *
 * @Route("/mairie")
 */
class MairieController extends Controller
{
    /**
     * 
     *
     * @Route("/generer-devis/{id}", name="mairie_generer_devis")
     * @Method("GET")
     * @Template()
     */
    public function genererDevisAction($id)
    {
	$snappy = new Pdf('/usr/local/bin/wkhtmltopdf');

	header('Content-Type: application/pdf');
	header('Content-Disposition: attachment; filename="devis_reference_'.$id.'.pdf"');
	echo $snappy->getOutput('http://mairiebo.lybliamay.fr/app.php/mairie/devis/'.$id);

	return new Symfony\Component\HttpFoundation\Response();
    }
    
    /**
     * 
     *
     * @Route("/devis/{id}", name="mairie_devis")
     * @Method("GET")
     * @Template()
     */
    public function devisAction($id)
    {
	$em = $this->getDoctrine()->getManager();
	$mairie = $em->getRepository('MairieBOMairieImportBundle:Mairie')->find($id);

	if (!$mairie) {
		throw $this->createNotFoundException('La mairie n\'existe pas');
	}

	$rsm = new ResultSetMapping();
	$rsm->addScalarResult('id', 'id');
	$rsm->addScalarResult('value', 'value');
	$query = $em->createNativeQuery('SELECT id, value FROM mairie_compteur WHERE id = ?', $rsm);
	$query->setParameter(1, 'numero_devis');
	$compteur = $query->getResult();
	
	$em->getConnection()->executeUpdate('UPDATE mairie_compteur SET value = value + 1 WHERE id = ?', array('numero_devis'));
	
	return array(
	    'mairie' => $mairie,
	    'compteur' => $compteur[0]
	);
    }
    
    /**
     * 
     *
     * @Route("/relance", name="mairie_relance")
     * @Method("GET")
     * @Template()
     */
    public function relanceAction(Request $request)
    {
        $em = $this->getDoctrine()->getManager();
	$dql = "SELECT m FROM MairieBOMairieImportBundle:Mairie m WHERE m.statut = :statut ORDER BY m.dateRelance, m.heureRelance";
	$query = $em->createQuery($dql);
	$query->setParameter('statut', 3);
	
	$paginator = $this->get('knp_paginator');
	$pagination = $paginator->paginate(
	    $query,
	    $request->query->getInt('page', 1)/*page number*/,
	    50/*limit per page*/
	);

        return array(
            'pagination' => $pagination,
	    'texte2heure' => \MairieBO\MairieImportBundle\Util\HeureRelance::texte2heure()
        );
    }
    
    /**
     * Lists all Mairie entities.
     *
     * @Route("/", name="mairie")
     * @Method({"GET", "POST"})
     * @Template()
     */
    public function indexAction(Request $request)
    {
	$session = $request->getSession();
	$reference = $request->get('inputReference', $session->get('inputReference'));
	$statut = $request->get('inputStatut', $session->get('inputStatut'));
	$rechercheLibre = $request->get('inputRechercheLibre', $session->get('inputRechercheLibre'));
	$joursOuverture = $request->get('inputJoursOuverture', $session->get('inputJoursOuverture'));
	
	$session->set('inputReference', $reference);
	$session->set('inputStatut', $statut);
	$session->set('inputRechercheLibre', $rechercheLibre);
	$session->set('inputJoursOuverture', $joursOuverture);
	
	$days = array(
	    1 => 'Lundi matin',
	    2 => 'Lundi après midi',
	    3 => 'Mardi matin',
	    4 => 'Mardi après midi',
	    5 => 'Mercredi matin',
	    6 => 'Mercredi après midi',
	    7 => 'Jeudi matin',
	    8 => 'Jeudi après midi',
	    9 => 'Vendredi matin',
	    10 => 'Vendredi après midi',
	    11 => 'Samedi matin',
	    12 => 'Samedi après midi',
	);
	
        $em = $this->getDoctrine()->getManager();
	$dql = "SELECT m FROM MairieBOMairieImportBundle:Mairie m WHERE 1 = 1 ";
	
	if (!is_null($reference)) {
		$dql .= "AND m.reference LIKE :inputReference ";
	}
	
	if (!is_null($statut) && $statut != '') {
		$dql .= "AND m.statut = :inputStatut ";
	}

	if (!is_null($rechercheLibre)) {
		$dql .= "AND (m.nomMairie LIKE :inputRechercheLibre "
			. "OR m.adresse LIKE :inputRechercheLibre "
			. "OR m.codePostal LIKE :inputRechercheLibre "
			. "OR m.ville LIKE :inputRechercheLibre "
			. "OR m.nomMaire LIKE :inputRechercheLibre) ";
	}

	if (!is_null($joursOuverture)) {
		$dqlJoursOuverture = array();

		if (array_key_exists(1, $joursOuverture)) {
			$dqlJoursOuverture[] = "m.lundiMatin = 1";
		}

		if (array_key_exists(2, $joursOuverture)) {
			$dqlJoursOuverture[] = "m.lundiApresMidi = 1";
		}

		if (array_key_exists(3, $joursOuverture)) {
			$dqlJoursOuverture[] = "m.mardiMatin = 1";
		}

		if (array_key_exists(4, $joursOuverture)) {
			$dqlJoursOuverture[] = "m.mardiApresMidi = 1";
		}

		if (array_key_exists(5, $joursOuverture)) {
			$dqlJoursOuverture[] = "m.mercrediMatin = 1";
		}

		if (array_key_exists(6, $joursOuverture)) {
			$dqlJoursOuverture[] = "m.mercrediApresMidi = 1";
		}

		if (array_key_exists(7, $joursOuverture)) {
			$dqlJoursOuverture[] = "m.jeudiMatin = 1";
		}

		if (array_key_exists(8, $joursOuverture)) {
			$dqlJoursOuverture[] = "m.jeudiApresMidi = 1";
		}

		if (array_key_exists(9, $joursOuverture)) {
			$dqlJoursOuverture[] = "m.vendrediMatin = 1";
		}

		if (array_key_exists(10, $joursOuverture)) {
			$dqlJoursOuverture[] = "m.vendrediApresMidi = 1";
		}

		if (array_key_exists(11, $joursOuverture)) {
			$dqlJoursOuverture[] = "m.samediMatin = 1";
		}

		if (array_key_exists(12, $joursOuverture)) {
			$dqlJoursOuverture[] = "m.samediApresMidi = 1";
		}

		$dql .= "AND (".implode(" OR ", $dqlJoursOuverture).") ";
	}
	
	$query = $em->createQuery($dql);
	
	if (!is_null($reference)) {
		$query->setParameter('inputReference', $reference.'%');
	}

	if (!is_null($statut) && $statut != '') {
		$query->setParameter('inputStatut', $statut);
	}

	if (!is_null($rechercheLibre)) {
		$query->setParameter('inputRechercheLibre', '%'.$rechercheLibre.'%');
	}

	$paginator = $this->get('knp_paginator');
	$pagination = $paginator->paginate(
	    $query,
	    $request->query->getInt('page', 1)/*page number*/,
	    10/*limit per page*/
	);

        return array(
            'pagination' => $pagination,
	    'inputReference' => $reference,
	    'inputStatut' => $statut,
	    'inputRechercheLibre' => $rechercheLibre,
	    'inputJoursOuverture' => $joursOuverture,
	    'days' => $days
        );
    }
    /**
     * Creates a new Mairie entity.
     *
     * @Route("/", name="mairie_create")
     * @Method("POST")
     * @Template("MairieBOMairieImportBundle:Mairie:new.html.twig")
     */
    public function createAction(Request $request)
    {
        $entity = new Mairie();
        $form = $this->createCreateForm($entity);
        $form->handleRequest($request);

        if ($form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->persist($entity);
            $em->flush();

            return $this->redirect($this->generateUrl('mairie'));
        }

        return array(
            'entity' => $entity,
            'form'   => $form->createView(),
        );
    }

    /**
     * Creates a form to create a Mairie entity.
     *
     * @param Mairie $entity The entity
     *
     * @return \Symfony\Component\Form\Form The form
     */
    private function createCreateForm(Mairie $entity)
    {
        $form = $this->createForm(new MairieType(), $entity, array(
            'action' => $this->generateUrl('mairie_create'),
            'method' => 'POST',
        ));

        $form->add('submit', 'submit', array('label' => 'Create'));

        return $form;
    }

    /**
     * Displays a form to create a new Mairie entity.
     *
     * @Route("/new", name="mairie_new")
     * @Method("GET")
     * @Template()
     */
    public function newAction()
    {
        $entity = new Mairie();
        $form   = $this->createCreateForm($entity);

        return array(
            'entity' => $entity,
            'form'   => $form->createView(),
        );
    }

    /**
     * Displays a form to edit an existing Mairie entity.
     *
     * @Route("/{id}/edit", name="mairie_edit")
     * @Method("GET")
     * @Template()
     */
    public function editAction(Request $request, $id)
    {
        $em = $this->getDoctrine()->getManager();

        $entity = $em->getRepository('MairieBOMairieImportBundle:Mairie')->find($id);

        if (!$entity) {
            throw $this->createNotFoundException('Unable to find Mairie entity.');
        }

        $editForm = $this->createEditForm($entity);
	
	$dql = "SELECT n FROM MairieBOMairieImportBundle:Note n WHERE n.mairie = :id ORDER BY n.dateHeure DESC";
	$query = $em->createQuery($dql);
	$query->setParameter('id', $entity->getId());

	$paginator = $this->get('knp_paginator');
	$pagination = $paginator->paginate(
	    $query,
	    $request->query->getInt('page', 1)/*page number*/,
	    10/*limit per page*/
	);

        return array(
            'pagination' => $pagination,
            'entity'      => $entity,
            'edit_form'   => $editForm->createView()
        );
    }

    /**
    * Creates a form to edit a Mairie entity.
    *
    * @param Mairie $entity The entity
    *
    * @return \Symfony\Component\Form\Form The form
    */
    private function createEditForm(Mairie $entity)
    {
        $form = $this->createForm(new MairieType(), $entity, array(
            'action' => $this->generateUrl('mairie_update', array('id' => $entity->getId())),
            'method' => 'PUT',
        ));

        $form->add('submit', 'submit', array('label' => 'Update'));

        return $form;
    }
    /**
     * Edits an existing Mairie entity.
     *
     * @Route("/{id}", name="mairie_update")
     * @Method("PUT")
     * @Template("MairieBOMairieImportBundle:Mairie:edit.html.twig")
     */
    public function updateAction(Request $request, $id)
    {
        $em = $this->getDoctrine()->getManager();

        $entity = $em->getRepository('MairieBOMairieImportBundle:Mairie')->find($id);

        if (!$entity) {
            throw $this->createNotFoundException('Unable to find Mairie entity.');
        }

        $deleteForm = $this->createDeleteForm($id);
        $editForm = $this->createEditForm($entity);
        $editForm->handleRequest($request);

        if ($editForm->isValid()) {
            $em->flush();
	    
	    $this->get('session')->getFlashBag()->add(
		'notice',
		'Votre fiche a bien été mise à jour!'
	    );


            return $this->redirect($this->generateUrl('mairie_edit', array('id' => $id)));
        }
	
	$dql = "SELECT n FROM MairieBOMairieImportBundle:Note n WHERE n.mairie = :id ORDER BY n.dateHeure DESC";
	$query = $em->createQuery($dql);
	$query->setParameter('id', $entity->getId());

	$paginator = $this->get('knp_paginator');
	$pagination = $paginator->paginate(
	    $query,
	    $request->query->getInt('page', 1)/*page number*/,
	    10/*limit per page*/
	);

        return array(
	    'pagination' => $pagination,
            'entity'      => $entity,
            'edit_form'   => $editForm->createView(),
            'delete_form' => $deleteForm->createView(),
        );
    }
    /**
     * Deletes a Mairie entity.
     *
     * @Route("/{id}", name="mairie_delete")
     * @Method("DELETE")
     */
    public function deleteAction(Request $request, $id)
    {
        return $this->redirect($this->generateUrl('mairie'));
	
        $form = $this->createDeleteForm($id);
        $form->handleRequest($request);

        if ($form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $entity = $em->getRepository('MairieBOMairieImportBundle:Mairie')->find($id);

            if (!$entity) {
                throw $this->createNotFoundException('Unable to find Mairie entity.');
            }

            $em->remove($entity);
            $em->flush();
        }

        return $this->redirect($this->generateUrl('mairie'));
    }

    /**
     * Creates a form to delete a Mairie entity by id.
     *
     * @param mixed $id The entity id
     *
     * @return \Symfony\Component\Form\Form The form
     */
    private function createDeleteForm($id)
    {
        return $this->createFormBuilder()
            ->setAction($this->generateUrl('mairie_delete', array('id' => $id)))
            ->setMethod('DELETE')
            ->add('submit', 'submit', array('label' => 'Delete'))
            ->getForm()
        ;
    }
}
