<?php

namespace MairieBO\MairieImportBundle\Controller;

use Symfony\Component\HttpFoundation\Request;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Method;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use MairieBO\MairieImportBundle\Entity\Note;
use MairieBO\MairieImportBundle\Form\NoteType;

/**
 * Note controller.
 *
 * @Route("/note")
 */
class NoteController extends Controller
{
    /**
     * Creates a new Note entity.
     *
     * @Route("/", name="note_create")
     * @Method("POST")
     * @Template("MairieBOMairieImportBundle:Note:new.html.twig")
     */
    public function createAction(Request $request)
    {
        $entity = new Note();
        $form = $this->createCreateForm($entity);
        $form->handleRequest($request);

        if ($form->isValid()) {
            $em = $this->getDoctrine()->getManager();
	    $mairie_id = $entity->getMairie();
	    $entity->setDateHeure(new \DateTime());
	    $entity->setMairie($em->getRepository('MairieBOMairieImportBundle:Mairie')->find($mairie_id));
            $em->persist($entity);
            $em->flush();

            return $this->redirect($this->generateUrl('mairie_edit', array('id' => $entity->getMairie()->getId())));
        }

        return array(
            'entity' => $entity,
            'form'   => $form->createView(),
        );
    }

    /**
     * Creates a form to create a Note entity.
     *
     * @param Note $entity The entity
     *
     * @return \Symfony\Component\Form\Form The form
     */
    private function createCreateForm(Note $entity)
    {
        $form = $this->createForm(new NoteType(), $entity, array(
            'action' => $this->generateUrl('note_create'),
            'method' => 'POST',
        ));

        $form->add('submit', 'submit', array('label' => 'Create'));

        return $form;
    }

    /**
     * Displays a form to create a new Note entity.
     *
     * @Route("/new/{mairie_id}", name="note_new")
     * @Method("GET")
     * @Template()
     */
    public function newAction($mairie_id)
    {
        $entity = new Note();
	$entity->setMairie($mairie_id);
	
        $form = $this->createCreateForm($entity);

        return array(
            'entity' => $entity,
            'form'   => $form->createView(),
        );
    }
}
