<?php

namespace MairieGestion\MairieBundle\Command;

use Symfony\Bundle\FrameworkBundle\Command\ContainerAwareCommand;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use MairieGestion\UserBundle\Entity\User;
use MairieGestion\MairieBundle\Entity\Mairie;
use MairieGestion\PageBundle\Entity\Page;

class CreateDomaineCommand extends ContainerAwareCommand
{
    /**
     * @see Command
     */
    protected function configure()
    {
        $this
            ->setName('mairiegestion:domaine:create')
            ->setDescription('Creation d\'un domaine.')
            ->setDefinition(array(
                new InputArgument('domaine', InputArgument::REQUIRED, 'Domaine'),
            ))
            ->setHelp(<<<EOT
The <info>fos:user:create</info> command creates a user:

  <info>php app/console fos:user:create matthieu</info>

This interactive shell will ask you for an email and then a password.

You can alternatively specify the email and password as the second and third arguments:

  <info>php app/console fos:user:create matthieu matthieu@example.com mypassword</info>

You can create a super admin via the super-admin flag:

  <info>php app/console fos:user:create admin --super-admin</info>

You can create an inactive user (will not be able to log in):

  <info>php app/console fos:user:create thibault --inactive</info>

EOT
            );
    }

    /**
     * @see Command
     */
    protected function execute(InputInterface $input, OutputInterface $output)
    {
        $domaine = $input->getArgument('domaine');

        $em = $this->getContainer()->get('doctrine')->getManager();
        
        $path_a = '/etc/apache2/sites-available/';
        $path_e = '/etc/apache2/sites-enabled/';
        $tab = explode('.',$domaine);
        $filename = $tab[1].'.'.$tab[2];
        $file_a = $path_a.$filename;
        $file_e = $path_e.$filename;
        if (!file_exists($file_a))
        {
            $output->writeln(sprintf('Creation du fichier <comment>%s</comment>', $file_a));
            $fp = fopen($file_a,'w');
            fwrite($fp,$this->generateVirtualHost($domaine,true));
            exec('ln -s ../sites-available/'.$filename.' '.$file_e);
            fclose($fp);
        }
        else
        {
            $fp = fopen($file_a,'a+');
            fwrite($fp,$this->generateVirtualHost($domaine,false));
            fclose($fp);
        }
        $output->writeln(sprintf('Creation du site pour le domaine <comment>%s</comment>', $domaine));
        $output->write(sprintf('<comment>Redemarage apache2...</comment> '));
        $output->writeln(sprintf('%s', exec('service apache2 restart')));
    }
    
    private function generateVirtualHost($domaine,$new_file=false)
    {
        $tab = explode('.',$domaine);
        return ($new_file?
'<VirtualHost *:80>
    ServerName '.$tab[1].'.'.$tab[2].'
    Options +FollowSymlinks
    RewriteEngine on
    RewriteCond %{HTTP_HOST} ^'.$tab[1].'.'.$tab[2].'$
    RewriteRule ^(.*) http://'.$domaine.'$1 [QSA,L,R=301]
</VirtualHost>'."\n":'').
'<VirtualHost *:80>
    ServerAdmin webmaster@localhost
    ServerName '.$domaine.'

    DocumentRoot /var/www/mairiegestion_prod/web
    <Directory /var/www/mairiegestion_prod/web/>
        Options Indexes FollowSymLinks MultiViews
        AllowOverride All
        Order allow,deny
        allow from all
        <IfModule mod_rewrite.c>
            RewriteEngine On
            RewriteCond %{REQUEST_FILENAME} !-f
            RewriteRule ^(.*)$ /app.php [QSA,L]
        </IfModule>
        <IfModule mod_rewrite.c>
            RewriteEngine On
            RewriteCond %{HTTP_HOST} ^'.$tab[1].'.'.$tab[2].'$
            RewriteRule ^(.*) http://'.$domaine.'/$1 [QSA,L,R=301]
        </IfModule>
    </Directory>
</VirtualHost>'."\n";
    }

    /**
     * @see Command
     */
    protected function interact(InputInterface $input, OutputInterface $output)
    {
        if (!$input->getArgument('domaine')) {
            $domaine = $this->getHelper('dialog')->askAndValidate(
                $output,
                'Domaine:',
                function($domaine) {
                    if (empty($domaine)) {
                        throw new \Exception('Domaine can not be empty');
                    }

                    return $domaine;
                }
            );
            $input->setArgument('domaine', $domaine);
        }
    }
}
