<?php

namespace MairieGestion\MairieBundle\Command;

use Symfony\Bundle\FrameworkBundle\Command\ContainerAwareCommand;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use MairieGestion\UserBundle\Entity\User;
use MairieGestion\MairieBundle\Entity\Mairie;
use MairieGestion\PageBundle\Entity\Page;

class CreateMairieCommand extends ContainerAwareCommand
{
    /**
     * @see Command
     */
    protected function configure()
    {
        $this
            ->setName('mairiegestion:mairie:create')
            ->setDescription('Creation d\'une mairie.')
            ->setDefinition(array(
                new InputArgument('mairie_name', InputArgument::REQUIRED, 'Nom de la mairie'),
                new InputArgument('domaine', InputArgument::REQUIRED, 'Domaine'),
                new InputArgument('email', InputArgument::REQUIRED, 'Email du compte admin'),
                new InputArgument('mairie_email', InputArgument::REQUIRED, 'mairie_email'),
                new InputArgument('name', InputArgument::REQUIRED, 'Nom'),
                new InputArgument('first_name', InputArgument::REQUIRED, 'Prnom'),
                new InputArgument('birthday', InputArgument::REQUIRED, 'Date de naissance (ex 1989-01-27)'),
                new InputArgument('sexe', InputArgument::REQUIRED, 'Sexe (m ou f)'),
                new InputArgument('password', InputArgument::REQUIRED, 'Mot de passe'),
                new InputOption('super-admin', null, InputOption::VALUE_NONE, 'Set the user as super admin'),
                new InputOption('inactive', null, InputOption::VALUE_NONE, 'Set the user as inactive'),
            ))
            ->setHelp(<<<EOT
The <info>fos:user:create</info> command creates a user:

  <info>php app/console fos:user:create matthieu</info>

This interactive shell will ask you for an email and then a password.

You can alternatively specify the email and password as the second and third arguments:

  <info>php app/console fos:user:create matthieu matthieu@example.com mypassword</info>

You can create a super admin via the super-admin flag:

  <info>php app/console fos:user:create admin --super-admin</info>

You can create an inactive user (will not be able to log in):

  <info>php app/console fos:user:create thibault --inactive</info>

EOT
            );
    }

    /**
     * @see Command
     */
    protected function execute(InputInterface $input, OutputInterface $output)
    {
        $mairie_name = $input->getArgument('mairie_name');
        $domaine = $input->getArgument('domaine');
        $email = $input->getArgument('email');
        $mairie_email = $input->getArgument('mairie_email');
        $name = $input->getArgument('name');
        $first_name = $input->getArgument('first_name');
        $birthday = $input->getArgument('birthday');
        $sexe = $input->getArgument('sexe');
        $password = $input->getArgument('password');
        $mairie_name = $input->getArgument('mairie_name');
        $inactive = $input->getOption('inactive');
        $superadmin = $input->getOption('super-admin');

        $em = $this->getContainer()->get('doctrine')->getManager();
        
        $mairie = new Mairie();
        $mairie->setName($mairie_name);
        $mairie->setDomaine($domaine);
        $mairie->setEmail($mairie_email);
        $em->persist($mairie);
        
        $user = new User();
        
        $user->setMairie($mairie);
        $user->setUsername(uniqid());
        $user->setEmail($email);
        $user->setName($name);
        $user->setFirstName($first_name);
        $user->setBirthday(new \DateTime($birthday));
        $user->setSexe($sexe='m'?0:1);
        $user->setPlainPassword($password);
        $user->setRoles(array('ROLE_ADMIN'));
        
        $em->persist($user);
        
        $page = new Page();
        $page->setMairie($mairie);
        $page->setName('Accueil');
        $page->setPath('');
        $page->setOnline(true);
        $page->setInMenu(true);
        $page->setHome(true);
        $page->setPosition(1);
        
        $em->persist($page);
        
        $em->flush();
        
        $output->writeln(sprintf('Creation en BDD du site pour le domaine <comment>%s</comment>', $domaine));
        $path_a = '/etc/apache2/sites-available/';
        $path_e = '/etc/apache2/sites-enabled/';
        $tab = explode('.',$domaine);
        $filename = $tab[1].'.'.$tab[2];
        $file_a = $path_a.$filename;
        $file_e = $path_e.$filename;
        if (!file_exists($file_a))
        {
            $output->writeln(sprintf('Creation du fichier <comment>%s</comment>', $file_a));
            $fp = fopen($file_a,'w');
            fwrite($fp,$this->generateVirtualHost($domaine,true));
            exec('ln -s ../sites-available/'.$filename.' '.$file_e);
            fclose($fp);
        }
        else
        {
            $fp = fopen($file_a,'a+');
            fwrite($fp,$this->generateVirtualHost($domaine,false));
            fclose($fp);
        }
        $output->writeln(sprintf('Creation du site pour le domaine <comment>%s</comment>', $domaine));
        $output->write(sprintf('<comment>Redemarage apache2...</comment> '));
        $output->writeln(sprintf('%s', exec('service apache2 restart')));
    }

    private function generateVirtualHost($domaine,$new_file=false)
    {
        $tab = explode('.',$domaine);
        return ($new_file?
'<VirtualHost *:80>
    ServerName '.$tab[1].'.'.$tab[2].'
    Options +FollowSymlinks
    RewriteEngine on
    RewriteCond %{HTTP_HOST} ^'.$tab[1].'.'.$tab[2].'$
    RewriteRule ^(.*) http://'.$domaine.'$1 [QSA,L,R=301]
</VirtualHost>'."\n":'').
'<VirtualHost *:80>
    ServerAdmin webmaster@localhost
    ServerName '.$domaine.'

    DocumentRoot /var/www/mairiegestion_prod/web
    <Directory /var/www/mairiegestion_prod/web/>
        Options Indexes FollowSymLinks MultiViews
        AllowOverride All
        Order allow,deny
        allow from all
        <IfModule mod_rewrite.c>
            RewriteEngine On
            RewriteCond %{REQUEST_FILENAME} !-f
            RewriteRule ^(.*)$ /app.php [QSA,L]
        </IfModule>
        <IfModule mod_rewrite.c>
            RewriteEngine On
            RewriteCond %{HTTP_HOST} ^'.$tab[1].'.'.$tab[2].'$
            RewriteRule ^(.*) http://'.$domaine.'/$1 [QSA,L,R=301]
        </IfModule>
    </Directory>
</VirtualHost>'."\n";
    }
    
    /**
     * @see Command
     */
    protected function interact(InputInterface $input, OutputInterface $output)
    {
        if (!$input->getArgument('mairie_name')) {
            $mairie_name = $this->getHelper('dialog')->askAndValidate(
                $output,
                'Nom de la mairie:',
                function($mairie_name) {
                    if (empty($mairie_name)) {
                        throw new \Exception('Mairie name can not be empty');
                    }
                    return $mairie_name;
                }
            );
            $input->setArgument('mairie_name', $mairie_name);
        }
        if (!$input->getArgument('domaine')) {
            $domaine = $this->getHelper('dialog')->askAndValidate(
                $output,
                'Domaine:',
                function($domaine) {
                    if (empty($domaine)) {
                        throw new \Exception('Domaine can not be empty');
                    }

                    return $domaine;
                }
            );
            $input->setArgument('domaine', $domaine);
        }
        
        if (!$input->getArgument('email')) {
            $email = $this->getHelper('dialog')->askAndValidate(
                $output,
                'Email:',
                function($email) {
                    if (empty($email)) {
                        throw new \Exception('Email can not be empty');
                    }

                    return $email;
                }
            );
            $input->setArgument('email', $email);
        }
        
        if (!$input->getArgument('mairie_email')) {
            $mairie_email = $this->getHelper('dialog')->askAndValidate(
                $output,
                'Email de contact de la mairie:',
                function($mairie_email) {
                    return $mairie_email;
                }
            );
            $input->setArgument('mairie_email', $mairie_email);
        }
        if (!$input->getArgument('name')) {
            $name = $this->getHelper('dialog')->askAndValidate(
                $output,
                'Nom:',
                function($name) {
                    return $name;
                }
            );
            $input->setArgument('name', $name);
        }
        
        if (!$input->getArgument('first_name')) {
            $first_name = $this->getHelper('dialog')->askAndValidate(
                $output,
                'Prenom:',
                function($first_name) {
                    return $first_name;
                }
            );
            $input->setArgument('first_name', $first_name);
        }
        
        if (!$input->getArgument('birthday')) {
            $birthday = $this->getHelper('dialog')->askAndValidate(
                $output,
                'Date de naissance (ex 1989-01-27):',
                function($birthday) {
                    return $birthday;
                }
            );
            $input->setArgument('birthday', $birthday);
        }
        
        if (!$input->getArgument('sexe')) {
            $sexe = $this->getHelper('dialog')->askAndValidate(
                $output,
                'Sexe (m or f):',
                function($sexe) {
                    return $sexe;
                }
            );
            $input->setArgument('sexe', $sexe);
        }

        if (!$input->getArgument('password')) {
            $password = $this->getHelper('dialog')->askAndValidate(
                $output,
                'Mot de passe:',
                function($password) {
                    if (empty($password)) {
                        throw new \Exception('Password can not be empty');
                    }

                    return $password;
                }
            );
            $input->setArgument('password', $password);
        }
    }
}
