<?php

namespace MairieGestion\PageBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;

use MairieGestion\PlanningBundle\Util\DateTools;

use MairieGestion\PlanningBundle\Entity\Event;
use MairieGestion\PlanningBundle\Form\EventType;
use MairieGestion\PlanningBundle\Entity\CategoryEvent;
use MairieGestion\PlanningBundle\Form\CategoryEventType;
class AgendaController extends Controller
{
    /**
     * @Route("/agenda/semaine", requirements={"year" = "\d+"}, name="agenda_liste")
     * @Template()
     */
    public function listeAgendaAction($filter='actifs')
    {
        $em = $this->getDoctrine()->getManager();
        $user = $this->container->get('security.context')->getToken()->getUser();
        $events = $em->getRepository('MairieGestionPlanningBundle:Event')->getEventsFilter($user,$filter);
        $planning = $em->getRepository('MairieGestionPlanningBundle:Event')->getFormatedEventsSemaine($events,$year,$week);
        $dateTools = new DateTools();
        $dates = $dateTools->getDatesBySemaine($year,$week);

        $filters = array(
            'tous'=> 'Tous',
            'actifs'=> 'Actifs',
            'inactifs'=> 'Inactifs',
        );
        return $this->render('MairieGestionPlanningBundle:Default:showSemaine.html.twig', array(
            'begin' => $dates['begin'],
            'end' => $dates['end'],
            'year'=>$year,
            'week'=>$week,
            'planning'=>$planning,
            'events'=>$events,
            'filter'=>$filter,
            'filters'=>$filters,
        ));
    }
    
    /**
     * @Route("/agenda/semaine", requirements={"year" = "\d+"}, name="agenda_semaine")
     * @Template()
     */
    public function showSemaineAction($filter='actifs')
    {
        return $this->showSemaineDateAction($filter,date('Y'),date('W'));
    }
    
    /**
     * @Route("/agenda/semaine/{year}/{week}", requirements={"year" = "\d+"}, name="agenda_semaine_date")
     * @Template()
     */
    public function showSemaineDateAction($filter='actifs',$year,$week)
    {
        $em = $this->getDoctrine()->getManager();
        $user = $this->container->get('security.context')->getToken()->getUser();
        $events = $em->getRepository('MairieGestionPlanningBundle:Event')->getEventsFilter($user,$filter);
        $planning = $em->getRepository('MairieGestionPlanningBundle:Event')->getFormatedEventsSemaine($events,$year,$week);
        $dateTools = new DateTools();
        $dates = $dateTools->getDatesBySemaine($year,$week);

        $filters = array(
            'tous'=> 'Tous',
            'actifs'=> 'Actifs',
            'inactifs'=> 'Inactifs',
        );
        return $this->render('MairieGestionPlanningBundle:Default:showSemaine.html.twig', array(
            'begin' => $dates['begin'],
            'end' => $dates['end'],
            'year'=>$year,
            'week'=>$week,
            'planning'=>$planning,
            'events'=>$events,
            'filter'=>$filter,
            'filters'=>$filters,
        ));
    }
    
    /**
     * @Route("/agenda/nouveau", name="agenda_new")
     * @Template()
     */
    public function newEventAction($id=null)
    {
        $user = $this->container->get('security.context')->getToken()->getUser();
        $em = $this->getDoctrine()->getManager();
        if ($id)
            $event = $em->getRepository('MairieGestionPlanningBundle:Event')->find($id);
        else
            $event = new Event();        
        $form       = $this->createForm(new EventType($event), $event);
        
        $request = $this->getRequest();
        
        if ($request->getMethod() == 'POST') {
        
            $form       = $this->createForm(new EventType($event), $event);
            $form->bind($request);
            
            if($form->isValid()) {
                if (!$id)
                    $event->setUser($user);
                $em->persist($event);
                $em->flush();
                return $this->redirect($this->generateUrl('agenda_semaine'));
           }
        }
        
        return $this->render('MairieGestionPlanningBundle:Default:newEvent.html.twig', array(
            'event'    => $event,
            'form'       => $form->createView(),
            'type'       => 'new',
        ));
    }
    
    /**
     * @Route("/agenda/categorie/nouveau", name="agenda_category_new")
     * @Template()
     */
    public function newCategoryAction($id=null)
    {
        $user = $this->container->get('security.context')->getToken()->getUser();
        $em = $this->getDoctrine()->getManager();
        if ($id)
            $category = $em->getRepository('MairieGestionPlanningBundle:CategoryEvent')->find($id);
        else
            $category = new CategoryEvent();
        $form       = $this->createForm(new CategoryEventType($category), $category);
        
        $request = $this->getRequest();
        
        if ($request->getMethod() == 'POST') {
            $form       = $this->createForm(new CategoryEventType($category), $category);
            $form->bind($request);
            
            
            
            if($form->isValid() && isset($category->getCodeColors()[$category->getColor()])) {
                if (!$id)
                    $category->setUser($user);
                $em->persist($category);
                $em->flush();
                return $this->redirect($this->generateUrl('agenda_semaine'));
           }
        }
        
        return $this->render('MairieGestionPlanningBundle:Default:newCategory.html.twig', array(
            'category'    => $category,
            'form'       => $form->createView(),
            'type'       => 'new',
        ));
    }
    
    /**
     * @Route("/agenda/modification/{id}", name="agenda_edit")
     * @Template()
     */
    public function editEventAction($id)
    {
        return $this->newEventAction($id);
    }
}
