<?php

namespace MairieGestion\PageBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use Symfony\Component\Security\Core\Exception\AccessDeniedException;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Form\FormError;

use MairieGestion\PageBundle\Entity\Archive;
use MairieGestion\MainBundle\Entity\Photos;
use MairieGestion\PageBundle\Form\ArchiveType;
use MairieGestion\UserBundle\Entity\User as User;

class ArchiveController extends Controller
{
    public function checkObj($obj)
    {
        $base_url = $this->getRequest()->getUriForPath('');
        $em = $this->getDoctrine()->getManager();
        $mairie = $em->getRepository('MairieGestionMairieBundle:Mairie')->getMairieByDomaine($base_url);
        if (is_object($obj) && $mairie != $obj->getMairie() && $obj->getMairie())
            throw new \Symfony\Component\Security\Core\Exception\AccessDeniedException ();
    }
    
    /**
     * @Route("/admin/archive/comptes-rendus", name="archive_liste_comptes_rendus")
     * @Template()
     */
    public function listeComptesRendusAction()
    {
        $user = $this->container->get('security.context')->getToken()->getUser();
        $mairie = $user->getMairie();
        $em = $this->getDoctrine()->getEntityManager();
        $archives = $em->getRepository('MairieGestionPageBundle:Archive')->getComptesRendus($mairie);
        return array(
            'archives' => $archives,
        );
    }
    
    /**
     * @Route("/admin/archive/comptes-rendus/nouveau", name="archive_new_comptes_rendus")
     * @Template()
     */
    public function newComptesRendusAction($id=null)
    {
        $user = $this->container->get('security.context')->getToken()->getUser();
        $mairie = $user->getMairie();
        $request = $this->getRequest();
        $em = $this->getDoctrine()->getEntityManager();
        $more_options = false;
        if ($id && (is_numeric($id) || strlen($id) != 13))
            $archive = $em->getRepository('MairieGestionPageBundle:Archive')->find($id);
        else
            $archive = new Archive();
        $this->checkObj($archive);
        $form       = $this->createForm(new ArchiveType(), $archive);
        if ($request->getMethod() == 'POST') {
            $form->bind($request);
            if(($id && !is_numeric($id) && strlen($id) == 13) || $request->get('id_temp'))
            {
                $photos = $em->getRepository('MairieGestionMainBundle:Photos')->getPhotosByIdTemp($request->get('id_temp'));
                if (count($photos) == 0)
                    $form->addError(new FormError('Veuillez joindre un pdf'));
                foreach($photos as $photo)
                    $photo->setArchive($archive);
            }
            if($form->isValid()) {
                $archive->setCategory($em->getRepository('MairieGestionPageBundle:ArchiveCategory')->find(2));
                if (!$id)
                {
                    $archive->setMairie($user->getMairie());
                    $archive->setUser($user);
                }
                if (!$archive->getId())
                {
                    $photos = $em->getRepository('MairieGestionMainBundle:Photos')->getPhotosByIdTemp($request->get('id_temp'));
                    foreach($photos as $photo)
                    {
                        $photo->setIdTemp(null);
                        $em->persist($photo);
                        $photo->setArchive($archive);
                    }
                }
                $em->persist($archive);
                $em->flush();
                return $this->redirect($this->generateUrl('archive_liste_comptes_rendus'));
           }
        }
        return $this->render('MairieGestionPageBundle:Archive:newComptesRendus.html.twig', array(
            'uniqid' => $request->get('id_temp')?$request->get('id_temp'):uniqid(),
            'archive'    => $archive,
            'form'       => $form->createView(),
            'type'       => 'new',
        ));
    }
    
    /**
     * @Route("/admin/archive/comptes-rendus/modification/{id}", name="archive_edit_comptes_rendus")
     * @Template()
     */
    public function editComptesRendusAction($id)
    {
        return $this->newComptesRendusAction($id);
    }
    
    /**
     * @Route("/admin/archive/bulletins-municipaux", name="archive_liste_bulletins_municipaux")
     * @Template()
     */
    public function listeBulletinsMunicipauxAction()
    {
        $user = $this->container->get('security.context')->getToken()->getUser();
        $mairie = $user->getMairie();
        $em = $this->getDoctrine()->getEntityManager();
        $archives = $em->getRepository('MairieGestionPageBundle:Archive')->getBulletinsMunicipaux($mairie);
        return array(
            'archives' => $archives,
        );
    }
    
    /**
     * @Route("/admin/archive/bulletins-municipaux/nouveau", name="archive_new_bulletins_municipaux")
     * @Template()
     */
    public function newBulletinsMunicipauxAction($id=null)
    {
        $user = $this->container->get('security.context')->getToken()->getUser();
        $mairie = $user->getMairie();
        $request = $this->getRequest();
        $em = $this->getDoctrine()->getEntityManager();
        $more_options = false;
        if ($id && (is_numeric($id) || strlen($id) != 13))
            $archive = $em->getRepository('MairieGestionPageBundle:Archive')->find($id);
        else
            $archive = new Archive();
        $this->checkObj($archive);
        $form       = $this->createForm(new ArchiveType(), $archive);
        if ($request->getMethod() == 'POST') {
            $form->bind($request);
            if(($id && !is_numeric($id) && strlen($id) == 13) || $request->get('id_temp'))
            {
                $photos = $em->getRepository('MairieGestionMainBundle:Photos')->getPhotosByIdTemp($request->get('id_temp'));
                if (count($photos) == 0)
                    $form->addError(new FormError('Veuillez joindre un pdf'));
                foreach($photos as $photo)
                    $photo->setArchive($archive);
            }
            if($form->isValid()) {
                $archive->setCategory($em->getRepository('MairieGestionPageBundle:ArchiveCategory')->find(1));
                if (!$id)
                {
                    $archive->setMairie($user->getMairie());
                    $archive->setUser($user);
                }
                if (!$archive->getId())
                {
                    $photos = $em->getRepository('MairieGestionMainBundle:Photos')->getPhotosByIdTemp($request->get('id_temp'));
                    foreach($photos as $photo)
                    {
                        $photo->setIdTemp(null);
                        $em->persist($photo);
                        $photo->setArchive($archive);
                    }
                }
                $em->persist($archive);
                $em->flush();
                return $this->redirect($this->generateUrl('archive_liste_bulletins_municipaux'));
           }
        }
        
        return $this->render('MairieGestionPageBundle:Archive:newBulletinsMunicipaux.html.twig', array(
            'uniqid' => $request->get('id_temp')?$request->get('id_temp'):uniqid(),
            'archive'    => $archive,
            'form'       => $form->createView(),
            'type'       => 'new',
        ));
    }
    
    /**
     * @Route("/admin/archive/bulletins-municipaux/modification/{id}", name="archive_edit_bulletins_municipaux")
     * @Template()
     */
    public function editBulletinsMunicipauxAction($id)
    {
        return $this->newBulletinsMunicipauxAction($id);
    }
    
    /**
     * @Route("/admin/archive/delete/{id}", name="archive_delete")
     * @Template()
     */
    public function deleteArchiveAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $archive = $em->getRepository('MairieGestionPageBundle:Archive')->find($id);
        $this->checkObj($archive);
        if ($archive->getCategory()->getId() == 1)
            $route = 'archive_liste_bulletins_municipaux';
        else
            $route = 'archive_liste_comptes_rendus';
        $em->remove($archive);
        $em->flush();
        return $this->redirect($this->generateUrl($route));
    }
    
    /**
     * @Route("/admin/archive/desactive/{id}", name="archive_desactive")
     * @Template()
     */
    public function desactiveArchiveAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $archive = $em->getRepository('MairieGestionPageBundle:Archive')->find($id);
        $this->checkObj($archive);
        $archive->setActive(0);
        $em->flush();
        return $this->redirect($this->generateUrl('archive_liste_bulletins_municipaux'));
    }
    
    /**
     * @Route("/admin/archive/active/{id}", name="archive_active")
     * @Template()
     */
    public function activeArchiveAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $archive = $em->getRepository('MairieGestionPageBundle:Archive')->find($id);
        $this->checkObj($archive);
        if ($archive->getPhoto())
            $archive->setActive(1);
        $em->flush();
        return $this->redirect($this->generateUrl('archive_liste_bulletins_municipaux'));
    }
}
