<?php

namespace MairieGestion\PageBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use Symfony\Component\Security\Core\Exception\AccessDeniedException;
use Symfony\Component\HttpFoundation\Response;

use MairieGestion\PageBundle\Entity\Carte;
use MairieGestion\PageBundle\Entity\Lieu;
use MairieGestion\UserBundle\Entity\User as User;
use MairieGestion\PageBundle\Form\CarteType;
use MairieGestion\PageBundle\Form\LieuType;
class CarteController extends Controller
{
    public function checkObj($obj)
    {
        $base_url = $this->getRequest()->getUriForPath('');
        $em = $this->getDoctrine()->getManager();
        $mairie = $em->getRepository('MairieGestionMairieBundle:Mairie')->getMairieByDomaine($base_url);
        if (is_object($obj) && $mairie != $obj->getMairie() && $obj->getMairie())
            throw new \Symfony\Component\Security\Core\Exception\AccessDeniedException ();
    }
    
    /**
     * @Route("/admin/carte/archives", name="carte_archive")
     * @Template()
     */
    public function archiveCarteAction()
    {
        return $this->render('MairieGestionMainBundle:Default:bientot.html.twig', array(
        ));
    }
    
    /**
     * @Route("/admin/carte", name="carte_liste")
     * @Template()
     */
    public function listeCarteAction()
    {
        $em = $this->getDoctrine()->getManager();
        $user = $this->container->get('security.context')->getToken()->getUser();
        $cartes = $em->getRepository('MairieGestionPageBundle:Carte')->getCartes($user->getMairie());
        return array(
            'cartes'=>$cartes,
        );
    }
    
    /**
     * @Route("/admin/carte/nouveau", name="carte_new")
     * @Template()
     */
    public function newCarteAction($id=null)
    {
        $user = $this->container->get('security.context')->getToken()->getUser();
        $mairie = $user->getMairie();
        $em = $this->getDoctrine()->getEntityManager();
        if ($id)
            $carte = $em->getRepository('MairieGestionPageBundle:Carte')->find($id);
        else
            $carte = new Carte();
        $this->checkObj($carte);
        $form = $this->createForm(new CarteType(), $carte);
        $lieu = new Lieu($mairie);
        $formLieu = $this->createForm(new LieuType($lieu), $lieu);
        $request = $this->getRequest();
        if ($request->getMethod() == 'POST') {
            $form       = $this->createForm(new CarteType(), $carte);
            $form->bind($request);
            if($form->isValid()) {
                if (!$carte->getId())
                {
                    $carte->setMairie($user->getMairie());
                    $carte->setUser($user);
                    $lieux = $em->getRepository('MairieGestionPageBundle:Lieu')->getLieuxByIdTemp($mairie, $request->get('id_temp'));
                    foreach($lieux as $lieu)
                    {
                        $lieu->setCarte($carte);
                        $lieu->setIdTemp(null);
                    }
                }
                $em->persist($carte);
                $em->flush();
                if (!count($carte->getLieux()))
                    return $this->redirect($this->generateUrl('carte_edit',array('id'=>$carte->getId())));
                return $this->redirect($this->generateUrl('carte_liste'));
           }
        }
        $uniqid = $request->get('id_temp')?$request->get('id_temp'):uniqid();
        if ($carte->getId())
        {
            $lieux = $carte->getLieux();
            $lieux_active = $carte->getLieuxActive();
        }
        else
        {
            $lieux = $em->getRepository('MairieGestionPageBundle:Lieu')->getLieuxByIdTemp($mairie, $request->get('id_temp'));
            $lieux_active = $em->getRepository('MairieGestionPageBundle:Lieu')->getLieuxActiveByIdTemp($mairie, $request->get('id_temp'));
        }
        return $this->render('MairieGestionPageBundle:Carte:newCarte.html.twig', array(
            'carte_id' => $carte->getId()?$carte->getId():$uniqid,
            'lieu' => $lieu,
            'lieux_active' => $lieux_active,
            'uniqid' => $uniqid,
            'lieux' => $lieux,
            'carte'    => $carte,
            'form'       => $form->createView(),
            'formLieu' => $formLieu->createView(),
            'type'       => 'new',
        ));
    }
    
    
    /**
     * @Route("/admin/carte/modification/{id}", name="carte_edit")
     * @Template()
     */
    public function editCarteAction($id)
    {
        return $this->newCarteAction($id);
    }
    
    /**
     * @Route("/admin/carte/nouveau/{carte_id}", name="page_lieu_new")
     * @Template()
     */
    public function newLieuAction($carte_id,$id=null)
    {
        $user = $this->container->get('security.context')->getToken()->getUser();
        $mairie = $user->getMairie();
        $em = $this->getDoctrine()->getEntityManager();
        if (is_numeric($carte_id) || strlen($carte_id) != 13)
            $carte = $em->getRepository('MairieGestionPageBundle:Carte')->find($carte_id);
        else
            $carte = new Carte();
        $this->checkObj($carte);
        $form = $this->createForm(new CarteType(), $carte);
        if (!$id)
            $lieu = new Lieu($mairie);        
        else
            $lieu = $em->getRepository('MairieGestionPageBundle:Lieu')->find($id);
        $this->checkObj($lieu);
        $formLieu = $this->createForm(new LieuType($lieu), $lieu);
        $request = $this->getRequest();
        if ($request->getMethod() == 'POST') {
            $formLieu = $this->createForm(new LieuType($lieu), $lieu);
            $formLieu->bind($request);
            if($formLieu->isValid()) {
                if (is_numeric($carte_id) || strlen($carte_id) != 13)
                    $lieu->setCarte($carte);
                else
                    $lieu->setIdTemp($carte_id);
                if (!$id)
                    $lieu->setPosition($lieu->getCarte()?count($lieu->getCarte()->getLieux())+1:count($em->getRepository('MairieGestionPageBundle:Lieu')->getLieuxByIdTemp($user->getMairie(),$carte_id))+1);
                $lieu->setMairie($mairie);
                $em->persist($lieu);
                $em->flush();
                $formLieu = $this->createForm(new LieuType($lieu), new Lieu($mairie));
                return $this->redirect($this->generateUrl('page_lieu_new',array('carte_id'=>$carte_id)));
           }
        }
        if (is_numeric($carte_id) || strlen($carte_id) != 13)
        {
            $lieux = $carte->getLieux();
            $lieux_active = $carte->getLieuxActive();
        }
        else
        {
            $lieux = $em->getRepository('MairieGestionPageBundle:Lieu')->getLieuxByIdTemp($mairie, $carte_id);
            $lieux_active = $em->getRepository('MairieGestionPageBundle:Lieu')->getLieuxActiveByIdTemp($mairie, $carte_id);
        }
        return $this->render('MairieGestionPageBundle:Carte:newCarte.html.twig', array(
            'carte_id' => $carte_id,
            'lieu' => $lieu,
            'uniqid' => ($request->get('id_temp')?$request->get('id_temp'):((is_numeric($carte_id) || strlen($carte_id) != 13)?uniqid():$carte_id)),
            'lieux' => $lieux,
            'lieux_active' => $lieux_active,
            'carte'    => $carte,
            'formLieu'       => $formLieu->createView(),
            'form' => $form->createView(),
            'type'       => 'new',
        ));
    }
    
    /**
     * @Route("/admin/carte/modification/{carte_id}/{id}", name="page_lieu_edit")
     * @Template()
     */
    public function editLieuAction($carte_id, $id)
    {
        return $this->newLieuAction($carte_id, $id);
    }
    
    /**
     * @Route("/admin/carte/delete/{id}", name="carte_delete")
     * @Template()
     */
    public function deleteCarteAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $carte = $em->getRepository('MairieGestionPageBundle:Carte')->find($id);
        $this->checkObj($carte);
        $em->remove($carte);
        $em->flush();
        return $this->redirect($this->generateUrl('carte_liste'));
    }
    
    /**
     * @Route("/admin/lieu/delete/{id}", name="page_lieu_delete")
     * @Template()
     */
    public function deleteLieuAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $lieu = $em->getRepository('MairieGestionPageBundle:Lieu')->find($id);
        $this->checkObj($lieu);
        $carte_id = $lieu->getCarte()?$lieu->getCarte()->getId():$lieu->getIdTemp();
        $em->remove($lieu);
        $em->flush();
	$em->getRepository('MairieGestionPageBundle:Lieu')->resetPosition($lieu->getMairie(), $lieu->getCarte());
	
        return $this->redirect($this->generateUrl('page_lieu_new',array('carte_id'=>$carte_id)));
    }
    
    /**
     * @Route("/admin/lieu/active/{id}", name="lieu_active")
     * @Template()
     */
    public function activeLieuAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $lieu = $em->getRepository('MairieGestionPageBundle:Lieu')->find($id);
        $this->checkObj($lieu);
        $carte_id = $lieu->getCarte()?$lieu->getCarte()->getId():$lieu->getIdTemp();
        $lieu->setActive(true);
        $em->flush();
        return $this->redirect($this->generateUrl('page_lieu_new',array('carte_id'=>$carte_id)));
    }
    
    /**
     * @Route("/admin/lieu/desactive/{id}", name="lieu_desactive")
     * @Template()
     */
    public function desactiveLieuAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $lieu = $em->getRepository('MairieGestionPageBundle:Lieu')->find($id);
        $this->checkObj($lieu);
        $carte_id = $lieu->getCarte()?$lieu->getCarte()->getId():$lieu->getIdTemp();
        $lieu->setActive(false);
        $em->flush();
        return $this->redirect($this->generateUrl('page_lieu_new',array('carte_id'=>$carte_id)));
    }
    
    /**
     * @Route("/admin/lieu/switchPosition/{id}/{brother_id}", name="lieu_switch_position")
     * @Template()
     */
    public function switchPositionLieuAction($id,$brother_id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $lieu = $em->getRepository('MairieGestionPageBundle:Lieu')->find($id);
        $lieuBrother = $em->getRepository('MairieGestionPageBundle:Lieu')->find($brother_id);
        $this->checkObj($lieu);
        $this->checkObj($lieuBrother);
	
	if ($lieu->getPosition() == $lieuBrother->getPosition()) {
		$em->getRepository('MairieGestionPageBundle:Lieu')->resetPosition($lieu->getMairie(), $lieu->getCarte());
		$lieu = $em->getRepository('MairieGestionPageBundle:Lieu')->find($id);
		$lieuBrother = $em->getRepository('MairieGestionPageBundle:Lieu')->find($brother_id);
		$this->checkObj($lieu);
		$this->checkObj($lieuBrother);
	}
	
        $position = $lieu->getPosition();
        $lieu->setPosition($lieuBrother->getPosition());
        $lieuBrother->setPosition($position);
        $em->flush();
        $carte_id = $lieu->getCarte()?$lieu->getCarte()->getId():$lieu->getIdTemp();
        return $this->redirect($this->generateUrl('page_lieu_new',array('carte_id'=>$carte_id)));
    }
}
