<?php

namespace MairieGestion\PageBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use Symfony\Component\Security\Core\Exception\AccessDeniedException;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Form\FormError;

use MairieGestion\PageBundle\Entity\Conseil;
use MairieGestion\PageBundle\Entity\ConseilMembre;
use MairieGestion\UserBundle\Entity\User as User;
use MairieGestion\PageBundle\Form\ConseilType;
use MairieGestion\PageBundle\Form\ConseilMembreType;
class ConseilController extends Controller
{
    public function checkObj($obj)
    {
        $base_url = $this->getRequest()->getUriForPath('');
        $em = $this->getDoctrine()->getManager();
        $mairie = $em->getRepository('MairieGestionMairieBundle:Mairie')->getMairieByDomaine($base_url);
        if (is_object($obj) && $mairie != $obj->getMairie() && $obj->getMairie())
            throw new \Symfony\Component\Security\Core\Exception\AccessDeniedException ();
    }
    
    /**
     * @Route("/admin/conseils-municipaux/liste", name="conseil_liste")
     * @Template()
     */
    public function listeConseilAction()
    {
        $em = $this->getDoctrine()->getManager();
        $user = $this->container->get('security.context')->getToken()->getUser();
        $conseils = $em->getRepository('MairieGestionPageBundle:Conseil')->getConseilsAdmin($user->getMairie());
        return array(
            'conseils'=>$conseils,
        );
    }
    
    /**
     * @Route("/admin/conseils-municipaux/nouveau", name="conseil_new")
     * @Template()
     */
    public function newConseilAction($id=null)
    {
        $user = $this->container->get('security.context')->getToken()->getUser();
        $mairie = $user->getMairie();
        $em = $this->getDoctrine()->getEntityManager();
        if ($id)
            $conseil = $em->getRepository('MairieGestionPageBundle:Conseil')->find($id);
        else
            $conseil = new Conseil();
        $this->checkObj($conseil);
        $form = $this->createForm(new ConseilType(), $conseil);
        $membre = new ConseilMembre();
        $formMembre = $this->createForm(new ConseilMembreType(), $membre);
        $request = $this->getRequest();
        if ($request->getMethod() == 'POST') {
            $form->bind($request);
            if ($conseil->getAnneeBegin() > $conseil->getAnneeEnd() && $conseil->getAnneeEnd())
                $form->get('anneeBegin')->addError(new FormError('L\'année de début doit être antérieure ou égale à l\'année de fin'));
            elseif ($conseil && $conseil->getAnneeBegin())
            {
                foreach($mairie->getConseils() as $conseil_temp)
                {
                    if ($conseil->getId() != $conseil_temp->getId() &&
                       ((!$conseil->getAnneeEnd() && !$conseil_temp->getAnneeEnd()) ||
                       ($conseil->getAnneeBegin() < $conseil_temp->getAnneeEnd() && $conseil->getAnneeEnd() >= $conseil_temp->getAnneeEnd()) ||
                       ($conseil->getAnneeEnd() > $conseil_temp->getAnneeBegin() && $conseil->getAnneeBegin() < $conseil_temp->getAnneeEnd()) ||
                       ($conseil->getAnneeEnd() > $conseil_temp->getAnneeBegin() && !$conseil_temp->getAnneeEnd())
                       ))
                    {
                        $form->get('anneeBegin')->addError(new FormError('Un autre conseil commence en '.$conseil_temp->getAnneeBegin().($conseil_temp->getAnneeEnd()?' et fini en '.$conseil_temp->getAnneeEnd():' jusqu\'à aujourd\'hui')));
                        break;
                    }
                }
            }
            if($form->isValid()) {
                if (!$conseil->getId())
                {
                    $conseil->setMairie($user->getMairie());
                    $conseil->setUser($user);
                }
                $em->persist($conseil);
                $em->flush();
                if (!count($conseil->getMembres()))
                    return $this->redirect($this->generateUrl('conseil_edit',array('id'=>$conseil->getId())));
                return $this->redirect($this->generateUrl('conseil_liste'));
           }
        }
        $uniqid = $request->get('id_temp')?$request->get('id_temp'):uniqid();
        $membres = array();
        if ($conseil->getId())
            $membres = $em->getRepository('MairieGestionPageBundle:ConseilMembre')->getMembresAdmin($conseil);
        return $this->render('MairieGestionPageBundle:Conseil:newConseil.html.twig', array(
            'conseil_id' => $conseil->getId(),
            'membre' => $membre,
            'membres' => $membres,
            'conseil'    => $conseil,
            'form'       => $form->createView(),
            'formMembre' => $formMembre->createView(),
            'type'       => 'new',
            'membre_id' => $membre->getId()?$membre->getId():$uniqid,
        ));
    }
    
    /**
     * @Route("/admin/conseils-municipaux/modification/{id}", name="conseil_edit")
     * @Template()
     */
    public function editConseilAction($id)
    {
        return $this->newConseilAction($id);
    }
    
    /**
     * @Route("/admin/conseils-municipaux/membre/nouveau/{conseil_id}", name="conseil_membre_new")
     * @Template()
     */
    public function newConseilMembreAction($conseil_id,$id=null)
    {
        $user = $this->container->get('security.context')->getToken()->getUser();
        $mairie = $user->getMairie();
        $em = $this->getDoctrine()->getEntityManager();
        $conseil = $em->getRepository('MairieGestionPageBundle:Conseil')->find($conseil_id);
        $form = $this->createForm(new ConseilType(), $conseil);
        if (!$id)
            $membre = new ConseilMembre();        
        else
            $membre = $em->getRepository('MairieGestionPageBundle:ConseilMembre')->find($id);
        $this->checkObj($membre->getConseil());
        $formMembre = $this->createForm(new ConseilMembreType(), $membre);
        $request = $this->getRequest();
        if ($request->getMethod() == 'POST') {
            $formMembre = $this->createForm(new ConseilMembreType(), $membre);
            $formMembre->bind($request);
            if($formMembre->isValid()) {
                if (!$membre->getId())
                {
                    $photos = $em->getRepository('MairieGestionMainBundle:Photos')->getPhotosByIdTemp($request->get('id_temp'));
                    foreach($photos as $photo)
                    {
                        $photo->setMembre($membre);
                        $photo->setIdTemp(null);
                    }
                }
                $membre->setConseil($conseil);
                $em->persist($membre);
                var_dump($membre->getStatut()->getId());
                if ($membre->getStatut()->getId() != 2)
                    $membre->setNumAdjoint(1);
                $em->flush();
                $formMembre = $this->createForm(new ConseilMembreType(), new ConseilMembre());
                return $this->redirect($this->generateUrl('conseil_membre_new',array('conseil_id'=>$conseil_id)));
           }
        }
        $uniqid = $request->get('id_temp')?$request->get('id_temp'):uniqid();
        $membres = $em->getRepository('MairieGestionPageBundle:ConseilMembre')->getMembresAdmin($conseil);
        return $this->render('MairieGestionPageBundle:Conseil:newConseil.html.twig', array(
            'conseil_id' => $conseil_id,
            'membre' => $membre,
            'membres' => $membres,
            'conseil'    => $conseil,
            'formMembre'       => $formMembre->createView(),
            'form' => $form->createView(),
            'type'       => 'new',
            'membre_id' => $membre->getId()?$membre->getId():$uniqid,
        ));
    }
    
    /**
     * @Route("/admin/conseils-municipaux/membre/modification/{conseil_id}/{id}", name="conseil_membre_edit")
     * @Template()
     */
    public function editConseilMembreAction($conseil_id, $id)
    {
        return $this->newConseilMembreAction($conseil_id, $id);
    }
    
    /**
     * @Route("/admin/conseils-municipaux/delete/{id}", name="conseil_delete")
     * @Template()
     */
    public function deleteConseilAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $conseil = $em->getRepository('MairieGestionPageBundle:Conseil')->find($id);
        $this->checkObj($conseil);
        $em->remove($conseil);
        $em->flush();
        return $this->redirect($this->generateUrl('conseil_liste'));
    }
    
    /**
     * @Route("/admin/conseils-municipaux/membre/delete/{id}", name="conseil_membre_delete")
     * @Template()
     */
    public function deleteConseilMembreAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $membre = $em->getRepository('MairieGestionPageBundle:ConseilMembre')->find($id);
        $this->checkObj($membre->getConseil());
        $conseil_id = $membre->getConseil()->getId();
        $em->remove($membre);
        $em->flush();
        return $this->redirect($this->generateUrl('conseil_membre_new',array('conseil_id'=>$conseil_id)));
    }
    
    /**
     * @Route("/admin/conseils-municipaux/membre/active/{id}", name="conseil_membre_active")
     * @Template()
     */
    public function activeConseilMembreAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $membre = $em->getRepository('MairieGestionPageBundle:ConseilMembre')->find($id);
        $this->checkObj($membre->getConseil());
        $conseil_id = $membre->getConseil()->getId();
        $membre->setActive(true);
        $em->flush();
        return $this->redirect($this->generateUrl('conseil_membre_new',array('conseil_id'=>$conseil_id)));
    }
    
    /**
     * @Route("/admin/conseils-municipaux/membre/desactive/{id}", name="conseil_membre_desactive")
     * @Template()
     */
    public function desactiveConseilMembreAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $membre = $em->getRepository('MairieGestionPageBundle:ConseilMembre')->find($id);
        $this->checkObj($membre->getConseil());
        $conseil_id = $membre->getConseil()->getId();
        $membre->setActive(false);
        $em->flush();
        return $this->redirect($this->generateUrl('conseil_membre_new',array('conseil_id'=>$conseil_id)));
    }
}
