<?php

namespace MairieGestion\PageBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use Symfony\Component\Security\Core\Exception\AccessDeniedException;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Form\FormError;

use MairieGestion\MainBundle\Helper\Utils;

use Imagine\Gd\Imagine;
use Imagine\Image\Box;
use Imagine\Image\ImageInterface;

use MairieGestion\PageBundle\Entity\Page;
use MairieGestion\MainBundle\Entity\Photos;
use MairieGestion\PageBundle\Form\PageType;
use MairieGestion\UserBundle\Entity\User as User;

class PageController extends Controller
{
    public function checkObj($obj)
    {
        $base_url = $this->getRequest()->getUriForPath('');
        $em = $this->getDoctrine()->getManager();
        $mairie = $em->getRepository('MairieGestionMairieBundle:Mairie')->getMairieByDomaine($base_url);
        if (is_object($obj) && $mairie != $obj->getMairie() && $obj->getMairie())
            throw new \Symfony\Component\Security\Core\Exception\AccessDeniedException ();
    }
    
    /**
     * @Route("/admin", name="admin")
     * @Template()
     */
    public function adminAction()
    {
        return $this->redirect($this->generateUrl('page_arborescence'));
    }
    
    /**
     * @Route("/admin/page/tree/{filter}", name="page_arborescence")
     * @Template()
     */
    public function arborescencePageAction($filter='tous')
    {
        $em = $this->getDoctrine()->getManager();
        $user = $this->container->get('security.context')->getToken()->getUser();
        $pages = $em->getRepository('MairieGestionPageBundle:Page')->getPagesMasterFilter($user->getMairie(),$filter);
        $filters = array(
            'tous'=> 'Tous',
            'online'=> 'En ligne',
            'offline'=> 'Hors ligne',
        );
        return array(
            'pages'=>$pages,
            'filter'=>$filter,
            'filters'=>$filters,
        );
    }
    
    /**
     * @Route("/admin/page/nouveau/", name="page_new")
     * @Template()
     */
    public function newPageAction($id=null)
    {
        $user = $this->container->get('security.context')->getToken()->getUser();
        $mairie = $user->getMairie();
        $em = $this->getDoctrine()->getEntityManager();
        $more_options = false;
        $utils = new Utils();
        if ($id)
            $page = $em->getRepository('MairieGestionPageBundle:Page')->find($id);
        else
            $page = new Page();
        $this->checkObj($page);
        $form       = $this->createForm(new PageType($user->getMairie(),$page,$em), $page);
        $request = $this->getRequest();
        if ($request->getMethod() == 'POST') {
            $form       = $this->createForm(new PageType($user->getMairie(),$page,$em), $page);
            $form->bind($request);
            
            $page->setPathAuto($utils->slug($page->getName()));
            $pages_same_url = $em->getRepository('MairieGestionPageBundle:Page')->getPageByPath($mairie,$page->getPath());
            foreach($pages_same_url as $page_same_url)
                if ($page->getId() != $page_same_url->getId())
                {
                    $form->get('path')->addError(new FormError('Cette URL existe déjà'));
                    $more_options = true;
                }
            if($form->isValid()) {
                if ($page->getPath() == $page->getPathAuto())
                    $page->setPath(null);
                if ($page->getMetaTitle() == $page->getName())
                    $page->setMetaTitle(null);
                if (!$id)
                {
                    $page->setMairie($user->getMairie());
                    $page->setUser($user);
                    $page->setPosition($page->getFreePosition());
                }
                elseif (!$page->hasFreePosition())
                    $page->setPosition($page->getFreePosition());
                if (!$page->getId())
                {
                    $photos = $em->getRepository('MairieGestionMainBundle:Photos')->getPhotosByIdTemp($request->get('id_temp'));
                    foreach($photos as $photo)
                    {
                        $photo->setPage($page);
                        $photo->setIdTemp(null);
                    }
                }
                $em->persist($page);
                $em->flush();
                return $this->redirect($this->generateUrl('page_arborescence'));
           }
        }
        
        return $this->render('MairieGestionPageBundle:Page:newPage.html.twig', array(
            'more_options' => $more_options,
            'uniqid' => $request->get('id_temp')?$request->get('id_temp'):uniqid(),
            'page'    => $page,
            'form'       => $form->createView(),
            'type'       => 'new',
        ));
    }
    
    /**
     * @Route("/admin/page/modification/{id}", name="page_edit")
     * @Template()
     */
    public function editPageAction($id)
    {
        return $this->newPageAction($id);
    }
    
    /**
     * @Route("/admin/page/delete/{id}", name="page_delete")
     * @Template()
     */
    public function deletePageAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $page = $em->getRepository('MairieGestionPageBundle:Page')->find($id);
        $this->checkObj($page);
        $em->remove($page);
        $em->flush();
        return $this->redirect($this->generateUrl('page_arborescence'));
    }
    
    /**
     * @Route("/admin/page/desactive/{id}", name="page_desactive")
     * @Template()
     */
    public function desactivePageAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $page = $em->getRepository('MairieGestionPageBundle:Page')->find($id);
        $this->checkObj($page);
        $page->setOnline(0);
        $em->flush();
        return $this->redirect($this->generateUrl('page_arborescence'));
    }
    
    /**
     * @Route("/admin/page/active/{id}", name="page_active")
     * @Template()
     */
    public function activePageAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $page = $em->getRepository('MairieGestionPageBundle:Page')->find($id);
        $this->checkObj($page);
        $page->setOnline(1);
        $em->flush();
        return $this->redirect($this->generateUrl('page_arborescence'));
    }
    
    /**
     * @Route("/admin/page/in-menu/{id}", name="page_in_menu")
     * @Template()
     */
    public function inMenuPageAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $page = $em->getRepository('MairieGestionPageBundle:Page')->find($id);
        $this->checkObj($page);
        $page->setInMenu(1);
        $em->flush();
        return $this->redirect($this->generateUrl('page_arborescence'));
    }
    
    /**
     * @Route("/admin/page/out-menu/{id}", name="page_out_menu")
     * @Template()
     */
    public function outMenuPageAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $page = $em->getRepository('MairieGestionPageBundle:Page')->find($id);
        $this->checkObj($page);
        $page->setInMenu(0);
        $em->flush();
        return $this->redirect($this->generateUrl('page_arborescence'));
    }
    
    /**
     * @Route("/admin/page/switchPosition/{id}/{brother_id}", name="page_switch_position")
     * @Template()
     */
    public function switchPositionPageAction($id,$brother_id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $page = $em->getRepository('MairieGestionPageBundle:Page')->find($id);
        $pageBrother = $em->getRepository('MairieGestionPageBundle:Page')->find($brother_id);
        $this->checkObj($page);
        $this->checkObj($pageBrother);
        $position = $page->getPosition();
        $page->setPosition($pageBrother->getPosition());
        $pageBrother->setPosition($position);
        $em->flush();
        return $this->redirect($this->generateUrl('page_arborescence'));
    }
}
