<?php

namespace MairieGestion\PageBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use Symfony\Component\Security\Core\Exception\AccessDeniedException;
use Symfony\Component\HttpFoundation\Response;

use MairieGestion\PageBundle\Form\SiteParamType;
use MairieGestion\PageBundle\Form\ApparenceParamType;
use MairieGestion\PageBundle\Form\ParamReferencementType;
use MairieGestion\PageBundle\Form\ReseauxSociauxType;

class ParamController extends Controller
{ 
    /**
     * @Route("/admin/parametre/apparence/", name="param_apparence")
     * @Template()
     */
    public function apparenceParamAction()
    {
        $user = $this->container->get('security.context')->getToken()->getUser();
        $em = $this->getDoctrine()->getEntityManager(); 
        $mairie = $user->getMairie();
        $form = $this->createForm(new ApparenceParamType($mairie,$em), $mairie);
        $request = $this->getRequest();
        if ($request->getMethod() == 'POST') {
            $form->bind($request);
            if($form->isValid()) {    
                $em->persist($mairie);
                $em->flush();
           }
        }
        
        return array(
            'mairie' => $mairie,
            'photos' => $mairie->getPhotos(),
            'form' => $form->createView(),
        );
    }
    /**
     * @Route("/admin/parametre/informations-generales/", name="param_generale")
     * @Template()
     */
    public function siteParamAction()
    {
        $user = $this->container->get('security.context')->getToken()->getUser();
        $em = $this->getDoctrine()->getEntityManager(); 
        $mairie = $user->getMairie();
        $form = $this->createForm(new SiteParamType($mairie,$em), $mairie);
        $request = $this->getRequest();
        
        if ($request->getMethod() == 'POST') {
            $form = $this->createForm(new SiteParamType($mairie,$em), $mairie);
            $form->bind($request);
            if($form->isValid()) {    
                $em->persist($mairie);
                $em->flush();
           }
        }
        
        return array(
            'mairie' => $mairie,
            'photos' => $mairie->getPhotos(),
            'form' => $form->createView(),
        );
    }
    
    /**
     * @Route("/admin/parametres/reseaux-sociaux", name="param_reseaux_sociaux")
     * @Template()
     */
    public function reseauxSociauxAction()
    {
	$request = $this->getRequest();
	$user = $this->container->get('security.context')->getToken()->getUser();
        $mairie = $user->getMairie();
	$em = $this->getDoctrine()->getManager();
	
	if ($request->getMethod() == 'POST') {
            $form = $this->createForm(new ReseauxSociauxType());
            $form->bind($request);
	    
            if ($form->isValid()) {
		$_configs = $form->getData();
		
		foreach ($_configs as $key => $value) {
		    $_config = $em->getRepository('MairieGestionPageBundle:Config')->findOneBy(array(
			'name' => $key,
		        'mairie' => $mairie
		    ));
			
		    $_config->setValue($value);
		    $em->persist($_config);
		}
		
                $em->flush();
           }
        }
	
        $configs = $em->getRepository('MairieGestionPageBundle:Config')->getReseauxSociauxConfigsByMairie($mairie);
        
        $form = $this->createForm(new ReseauxSociauxType(), array(
	    'facebook_enabled' => (bool) $configs['facebook_enabled'],
	    'facebook_page_url' => $configs['facebook_page_url'],
	    'facebook_show_friends_faces' => (bool) $configs['facebook_show_friends_faces'],
	    'facebook_small_header' => (bool) $configs['facebook_small_header'],
	    'facebook_hide_cover_photo' => (bool) $configs['facebook_hide_cover_photo'],
	    'facebook_show_page_posts' => (bool) $configs['facebook_show_page_posts'],
	    'facebook_height' => (integer) $configs['facebook_height']
	));
	
	return array(
	    'form' => $form->createView()
	);
    }
    
    /**
     * @Route("/admin/parametres/restrictions", name="param_restriction")
     * @Template()
     */
    public function restrictionParamAction()
    {
        return $this->render('MairieGestionMainBundle:Default:bientot.html.twig', array(
        ));
    }

    /**
     * @Route("/admin/parametres/referencement", name="param_referencement")
     * @Template()
     */
    public function referencementParamAction()
    {
        $user = $this->container->get('security.context')->getToken()->getUser();
        $em = $this->getDoctrine()->getEntityManager(); 
        $mairie = $user->getMairie();
        $form = $this->createForm(new ParamReferencementType(), $mairie);
        $request = $this->getRequest();
        
        if ($request->getMethod() == 'POST') {
            $form = $this->createForm(new ParamReferencementType(), $mairie);
            $form->bind($request);
            if($form->isValid()) {    
                $em->persist($mairie);
                $em->flush();
           }
        }
        
        return array(
            'mairie' => $mairie,
            'form' => $form->createView(),
        );
    }
    
    /**
     * @Route("/admin/parametres/avences", name="param_avance")
     * @Template()
     */
    public function avanceParamAction()
    {
        return $this->render('MairieGestionMainBundle:Default:bientot.html.twig', array(
        ));
    }
}