<?php

namespace MairieGestion\PageBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use Symfony\Component\Security\Core\Exception\AccessDeniedException;
use Symfony\Component\HttpFoundation\Response;

use Imagine\Gd\Imagine;
use Imagine\Image\Box;
use Imagine\Image\ImageInterface;

use MairieGestion\PageBundle\Entity\Page;
use MairieGestion\PageBundle\Entity\Album;
use MairieGestion\MainBundle\Entity\Photos;
use MairieGestion\PageBundle\Form\PageType;
use MairieGestion\PageBundle\Form\AlbumType;
use MairieGestion\UserBundle\Entity\User as User;

class PhotoController extends Controller
{
    public function checkObj($obj)
    {
        $base_url = $this->getRequest()->getUriForPath('');
        $em = $this->getDoctrine()->getManager();
        $mairie = $em->getRepository('MairieGestionMairieBundle:Mairie')->getMairieByDomaine($base_url);
        if (is_object($obj) && $mairie != $obj->getMairie() && $obj->getMairie())
            throw new \Symfony\Component\Security\Core\Exception\AccessDeniedException ();
    }
    
    /**
     * @Route("/admin/photo/url", name="photo_url")
     * @Template()
     */
    public function urlPhotoAction()
    {
        return array(
        );
    }
    
    /**
     * @Route("/admin/photo/archive", name="photo_archive")
     * @Template()
     */
    public function archivePhotoAction()
    {
        // return new Response('ok');
        return array(
        );
    }
    
    /**
     * @Route("/admin/photo/albums", name="photo_albums")
     * @Template()
     */
    public function listeAlbumsAction()
    {
        $user = $this->container->get('security.context')->getToken()->getUser();
        $mairie = $user->getMairie();
        $albums = $mairie->getAlbums();
        return array('albums'=>$albums);
    }
    
    /**
     * @Route("/admin/photo/album/nouveau", name="photo_album_new")
     * @Template()
     */
    public function newAlbumAction($id=null)
    {
        $user = $this->container->get('security.context')->getToken()->getUser();
        $mairie = $user->getMairie();
        $em = $this->getDoctrine()->getEntityManager();
        if ($id)
            $album = $em->getRepository('MairieGestionPageBundle:Album')->find($id);
        else
            $album = new Album();
        $this->checkObj($album);
        $form = $this->createForm(new AlbumType(), $album);
        $request = $this->getRequest();
        if ($request->getMethod() == 'POST') {
            $form->bind($request);
            if($form->isValid()) {
                if (!$album->getId())
                {
                    $album->setMairie($user->getMairie());
                    $album->setUser($user);
                }
                $em->persist($album);
                $em->flush();
                return $this->redirect($this->generateUrl('photo_albums'));
           }
        }
        return $this->render('MairieGestionPageBundle:Photo:newAlbum.html.twig',array(
            'album' => $album,
            'form' => $form->createView()
        ));
    }
    
    /**
     * @Route("/admin/photo/album/modification/{id}", name="photo_album_edit")
     * @Template()
     */
    public function editAlbumAction($id)
    {
        return $this->newAlbumAction($id);
    }
    
    /**
     * @Route("/admin/photo/album/delete/{id}", name="photo_album_delete")
     * @Template()
     */
    public function deleteAlbumAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $album = $em->getRepository('MairieGestionPageBundle:Album')->find($id);
        $this->checkObj($album);
        $em->remove($album);
        $em->flush();
        return $this->redirect($this->generateUrl('photo_albums'));
    }
    
    /**
     * @Route("/admin/photo/album/images", name="photo_album_photo")
     * @Template()
     */
    public function listeAlbumPhotosAction()
    {
        $user = $this->container->get('security.context')->getToken()->getUser();
        $mairie = $user->getMairie();
        $albums = $mairie->getAlbums();
        return array('albums'=>$albums);
    }
    
    public function saveImageByHeightAndMawWidth($image, $filename, $width, $height)
    {
        $oldRatio = $image->getSize()->getWidth()/$image->getSize()->getHeight();
        $newRatio = $width/$height;
        if ($oldRatio > $newRatio)
        {
            $newRatio = $oldRatio;
            $height = $width/$newRatio;
        }
        if ($oldRatio > $newRatio) {
            $image
                ->thumbnail(new Box($newRatio*$image->getSize()->getHeight(), $image->getSize()->getHeight()), ImageInterface::THUMBNAIL_OUTBOUND)
                ->resize(new Box($width, $height))
                ->save($filename, array('jpeg_quality' => 100))
            ;
        }
        elseif ($oldRatio < $newRatio) {
            $image
                ->thumbnail(new Box($image->getSize()->getWidth(), $image->getSize()->getWidth()/$newRatio), ImageInterface::THUMBNAIL_OUTBOUND)
                ->resize(new Box($width, $height))
                ->save($filename, array('jpeg_quality' => 100))
            ;
        }
        else
        {
            $image
                ->resize(new Box($width, $height))
                ->save($filename, array('jpeg_quality' => 100))
            ;
        }
        return $height;
    }
    
    public function saveImageBySize($image, $filename, $width, $height)
    {
        $oldRatio = $image->getSize()->getWidth()/$image->getSize()->getHeight();
        $newRatio = $width/$height;
        if ($oldRatio > $newRatio) {
            $image
                ->thumbnail(new Box($newRatio*$image->getSize()->getHeight(), $image->getSize()->getHeight()), ImageInterface::THUMBNAIL_OUTBOUND)
                ->resize(new Box($width, $height))
                ->save($filename, array('jpeg_quality' => 100))
            ;
        }
        elseif ($oldRatio < $newRatio) {
            $image
                ->thumbnail(new Box($image->getSize()->getWidth(), $image->getSize()->getWidth()/$newRatio), ImageInterface::THUMBNAIL_OUTBOUND)
                ->resize(new Box($width, $height))
                ->save($filename, array('jpeg_quality' => 100))
            ;
        }
        else
        {
            $image
                ->resize(new Box($width, $height))
                ->save($filename, array('jpeg_quality' => 100))
            ;
        }
    }
    
    /**
     * @Route("/ajax/upload-photo", name="ajax_upload_photo", options={"expose"=true})
     */
    public function ajaxUploadPhotoAction()
    {
        $request = $this->getRequest();
        $user = $this->container->get('security.context')->getToken()->getUser();
        if (!is_object($user) || !$user instanceof User) {
            die(var_dump($user instanceof User));
    		throw new AccessDeniedException('This user does not have access to this section.');
    	}
        $mairie = $user->getMairie();
        $path_base = $this->container->get('kernel')->getRootDir() . '/../web/';
        $path = 'MairieGestion/uploads/mairies/'.$mairie->getId().'/';
        $full_path = $path_base.$path;
        
        if (!is_dir($full_path)) {
            @mkdir($full_path, 0777, true);
        }
        
        $tab_filename = explode('.',$_FILES['files']['name'][0]);
        
        $name = $_FILES['files']['name'][0];
        $size = $_FILES['files']['size'][0];
        $type = $_FILES['files']['type'][0];
        $filename = uniqid().'.'.$tab_filename[count($tab_filename)-1];
        $filename1 = 't1_'.$filename;
        $filename2 = 't2_'.$filename;
        $filename3 = 't3_'.$filename;
        
        if ((isset($_FILES['files']['tmp_name'][0])&&($_FILES['files']['error'][0] == UPLOAD_ERR_OK)))
            move_uploaded_file($_FILES['files']['tmp_name'][0], $full_path.$filename);     

        $imagine = new Imagine();
        $image = $imagine->open($full_path.$filename);
     
        $width1 = 100;
        $height1 = 50;
        $width2 = 400;
        $height2 = 200;
        $width3 = 840;
        $height3 = 420;
        
        if ($image->getSize()->getWidth() == $width3 && $image->getSize()->getHeight() == $height3)
        {
            $this->saveImageBySize($image, $full_path.$filename2, $width2, $height2);
            $this->saveImageBySize($image, $full_path.$filename1, $width1, $height1);
            if (file_exists($full_path.$filename))
            {
                $photo = new Photos();
                $photo->setType($type);
                $photo->setTag('photo_mairie');
                $photo->setName($name);
                $photo->setPath($path.$filename);
                $photo->setThumb1($path.$filename1);
                $photo->setThumb2($path.$filename2);
                $photo->setWidth($image->getSize()->getHeight());
                $photo->setHeight($image->getSize()->getWidth());
                $photo->setWidthThumb1($width1);
                $photo->setHeightThumb1($height1);
                $photo->setWidthThumb2($width2);
                $photo->setHeightThumb2($height2);
                $photo->setSize($size);
                $photo->setTitle('Photo de la mairie '.$mairie->getName());
                $photo->setMairie($mairie);

                $em = $this->getDoctrine()->getManager();
                $em->persist($photo);
                $em->flush();
            }
            return new Response(json_encode(array(
                'files' => array(
                    0 => array(
                        'id' => $photo->getId(),
                        'deleteType' => 'DELETE',
                        'deleteUrl' => $this->container->get('router')->generate('photo_delete',array('id'=>$photo->getId())),
                        'name' => $name,
                        'size' => $size,
                        'thumbnailUrl' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb1()),
                        'type' => $type,
                        'url' => $this->container->get('templating.helper.assets')->getUrl($photo->getPath()),
                    )
                ),
            )));
        }
        else
            return new Response(json_encode(array(
                'files' => array(
                    0 => array(
                        'error'=> ('L\'image doit être dimensionnée en '.$width3.'x'.$height3.' pixels'),
                        'deleteType' => 'DELETE',
                        'deleteUrl' => '',
                        'name' => $name,
                        'size' => $size,
                        'thumbnailUrl' => '',
                        'type' => $type,
                        'url' => '',
                    )
                ),
            )));
    }
    
    /**
     * @Route("/ajax/get-photos", name="ajax_get_photos", options={"expose"=true})
     */
    public function ajaxGetPhotosAction()
    {
        $request = $this->getRequest();
        $user = $this->container->get('security.context')->getToken()->getUser();
        if (!is_object($user) || !$user instanceof User) {
            die(var_dump($user instanceof User));
    		throw new AccessDeniedException('This user does not have access to this section.');
    	}
        $mairie = $user->getMairie();
        
        $files = array();
        foreach($mairie->getPhotos() as $photo)
        {
            $files[] = array(
                'archivable' => true,
                'id' => $photo->getId(),
                'deleteType' => 'DELETE',
                'deleteUrl' => $this->container->get('router')->generate('photo_delete',array('id'=>$photo->getId())),
                'name' => $photo->getName(),
                'size' => $photo->getSize(),
                'thumbnailUrl' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb1()),
                'type' => $photo->getType(),
                'url' => $this->container->get('templating.helper.assets')->getUrl($photo->getPath()),
            );
        }
        return new Response(json_encode(array(
            'files' => $files,
        )));
    }
    
    /**
     * @Route("/ajax/upload-pdf-page/{id}", name="ajax_upload_pdf_page", options={"expose"=true})
     */
    public function ajaxUploadPdfPageAction($id)
    {
        $request = $this->getRequest();
        $user = $this->container->get('security.context')->getToken()->getUser();
        if (!is_object($user) || !$user instanceof User) {
            die(var_dump($user instanceof User));
    		throw new AccessDeniedException('This user does not have access to this section.');
    	}
        $em = $this->getDoctrine()->getManager();
        $page = false;
        if (is_numeric($id) || strlen($id) != 13)
            $page = $em->getRepository('MairieGestionPageBundle:Page')->find($id);
        $this->checkObj($page);
        $mairie = $user->getMairie();
        $path_base = $this->container->get('kernel')->getRootDir() . '/../web/';
        $path = 'MairieGestion/uploads/mairies/'.$mairie->getId().'/';
        $full_path = $path_base.$path;
        
        if (!is_dir($full_path)) {
            @mkdir($full_path, 0777, true);
        }
        
        $tab_filename = explode('.',$_FILES['files']['name'][0]);
        
        $name = $_FILES['files']['name'][0];
        $size = $_FILES['files']['size'][0];
        $type = $_FILES['files']['type'][0];
        $filename = uniqid().'.'.$tab_filename[count($tab_filename)-1];
        $filename1 = 't1_'.$filename;
        $filename2 = 't2_'.$filename;
        $filename3 = 't3_'.$filename;
        $filename4 = 't4_'.$filename;
        $filename5 = 't5_'.$filename;
        
        if ((isset($_FILES['files']['tmp_name'][0])&&($_FILES['files']['error'][0] == UPLOAD_ERR_OK)))
            move_uploaded_file($_FILES['files']['tmp_name'][0], $full_path.$filename);
        
        if (file_exists($full_path.$filename))
        {
            $photo = new Photos();
            $photo->setType($type);
            $photo->setTag('pdf_page');
            $photo->setName($name);
            $photo->setPath($path.$filename);
            $photo->setSize($size);
            $photo->setTitle('Pdf de la mairie '.$mairie->getName());
            $photo->setMairie($mairie);
            if (is_numeric($id) || strlen($id) != 13)
                $photo->setPage($page);
            else
                $photo->setIdTemp($id);
            $em->persist($photo);
            $em->flush();
        }
        
        return new Response(json_encode(array(
            'files' => array(
                0 => array(
                    'id' => $photo->getId(),
                    'deleteType' => 'DELETE',
                    'deleteUrl' => $this->container->get('router')->generate('photo_delete',array('id'=>$photo->getId())),
                    'name' => $name,
                    'size' => $size,
                    'thumbnailUrl' => '/bundles/mairiegestionmain/images/pdf_icone_small.png',
                    'type' => $type,
                    'url' => $this->container->get('templating.helper.assets')->getUrl($photo->getPath()),
                )
            ),
        )));
    }
    
    /**
     * @Route("/ajax/get-pdfs-page/{id}", name="ajax_get_pdfs_page", options={"expose"=true})
     */
    public function ajaxGetPdfsPageAction($id)
    {
        $request = $this->getRequest();
        
        $user = $this->container->get('security.context')->getToken()->getUser();
        if (!is_object($user) || !$user instanceof User) {
            die(var_dump($user instanceof User));
    		throw new AccessDeniedException('This user does not have access to this section.');
    	}
        $em = $this->getDoctrine()->getManager();
        $page = $em->getRepository('MairieGestionPageBundle:Page')->find($id);
        $this->checkObj($page);
        $mairie = $user->getMairie();
        
        $files = array();
        if (is_numeric($id) || strlen($id) != 13)
            $photos = $page->getPdfs();
        else
            $photos = $em->getRepository('MairieGestionMainBundle:Photos')->getPhotosByIdTemp($id);
        foreach($photos as $photo)
        {
            $files[] = array(
                'id' => $photo->getId(),
                'deleteType' => 'DELETE',
                'deleteUrl' => $this->container->get('router')->generate('photo_delete',array('id'=>$photo->getId())),
                'name' => $this->getRequest()->getUriForPath('/'.$photo->getPath()),
                'size' => $photo->getSize(),
                'thumbnailUrl' => '/bundles/mairiegestionmain/images/pdf_icone_small.png',
                'type' => $photo->getType(),
                'url' => $this->container->get('templating.helper.assets')->getUrl($photo->getPath()),
            );
        }
        return new Response(json_encode(array(
            'files' => $files,
        )));
    }
    
    /**
     * @Route("/ajax/upload-photo-page/{id}", name="ajax_upload_photo_page", options={"expose"=true})
     */
    public function ajaxUploadPhotoPageAction($id)
    {
        $request = $this->getRequest();
        $user = $this->container->get('security.context')->getToken()->getUser();
        if (!is_object($user) || !$user instanceof User) {
            die(var_dump($user instanceof User));
    		throw new AccessDeniedException('This user does not have access to this section.');
    	}
        $em = $this->getDoctrine()->getManager();
        $page = false;
        if (is_numeric($id) || strlen($id) != 13)
            $page = $em->getRepository('MairieGestionPageBundle:Page')->find($id);
        $this->checkObj($page);
        $mairie = $user->getMairie();
        $path_base = $this->container->get('kernel')->getRootDir() . '/../web/';
        $path = 'MairieGestion/uploads/mairies/'.$mairie->getId().'/';
        $full_path = $path_base.$path;
        
        if (!is_dir($full_path)) {
            @mkdir($full_path, 0777, true);
        }
        
        $tab_filename = explode('.',$_FILES['files']['name'][0]);
        
        $name = $_FILES['files']['name'][0];
        $size = $_FILES['files']['size'][0];
        $type = $_FILES['files']['type'][0];
        $filename = uniqid().'.'.$tab_filename[count($tab_filename)-1];
        $filename1 = 't1_'.$filename;
        $filename2 = 't2_'.$filename;
        $filename3 = 't3_'.$filename;
        $filename4 = 't4_'.$filename;
        $filename5 = 't5_'.$filename;
        
        if ((isset($_FILES['files']['tmp_name'][0])&&($_FILES['files']['error'][0] == UPLOAD_ERR_OK)))
            move_uploaded_file($_FILES['files']['tmp_name'][0], $full_path.$filename);     

        $imagine = new Imagine();
        $image = $imagine->open($full_path.$filename);
     
        $width1 = 75;
        $height1 = 50;
        $width2 = 300;
        $height2 = 200;
        $width3 = 570;
        $height3 = 380;
        $width4 = 930;
        $height4 = 465;
        $width5 = 1170;
        $height5 = 585;
        
        $this->saveImageBySize($image, $full_path.$filename5, $width5, $height5);
        $this->saveImageBySize($image, $full_path.$filename4, $width4, $height4);
        $this->saveImageBySize($image, $full_path.$filename3, $width3, $height3);
        $this->saveImageBySize($image, $full_path.$filename2, $width2, $height2);
        $this->saveImageBySize($image, $full_path.$filename1, $width1, $height1);
        
        if (file_exists($full_path.$filename))
        {
            $photo = new Photos();
            $photo->setType($type);
            $photo->setTag('photo_page');
            $photo->setName($name);
            $photo->setPath($path.$filename);
            $photo->setThumb1($path.$filename1);
            $photo->setThumb2($path.$filename2);
            $photo->setThumb3($path.$filename3);
            $photo->setThumb4($path.$filename4);
            $photo->setThumb5($path.$filename5);
            $photo->setWidth($image->getSize()->getHeight());
            $photo->setHeight($image->getSize()->getWidth());
            $photo->setWidthThumb1($width1);
            $photo->setHeightThumb1($height1);
            $photo->setWidthThumb2($width2);
            $photo->setHeightThumb2($height2);
            $photo->setWidthThumb3($width3);
            $photo->setHeightThumb3($height3);
            $photo->setWidthThumb4($width4);
            $photo->setHeightThumb4($height4);
            $photo->setWidthThumb5($width5);
            $photo->setHeightThumb5($height5);
            $photo->setSize($size);
            $photo->setTitle('Photo de la mairie '.$mairie->getName());
            $photo->setMairie($mairie);
            if (is_numeric($id) || strlen($id) != 13)
                $photo->setPage($page);
            else
                $photo->setIdTemp($id);
            $em->persist($photo);
            $em->flush();
        }
        
        return new Response(json_encode(array(
            'files' => array(
                0 => array(
                    'id' => $photo->getId(),
                    'deleteType' => 'DELETE',
                    'deleteUrl' => $this->container->get('router')->generate('photo_delete',array('id'=>$photo->getId())),
                    'name' => $name,
                    'size' => $size,
                    'thumbnailUrl' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb1()),
                    'type' => $type,
                    'url' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb3()),
                )
            ),
        )));
    }
    
    /**
     * @Route("/ajax/get-photos-page/{id}", name="ajax_get_photos_page", options={"expose"=true})
     */
    public function ajaxGetPhotosPageAction($id)
    {
        $request = $this->getRequest();
        
        $user = $this->container->get('security.context')->getToken()->getUser();
        if (!is_object($user) || !$user instanceof User) {
            die(var_dump($user instanceof User));
    		throw new AccessDeniedException('This user does not have access to this section.');
    	}
        $em = $this->getDoctrine()->getManager();
        $page = $em->getRepository('MairieGestionPageBundle:Page')->find($id);
        $this->checkObj($page);
        $mairie = $user->getMairie();
        
        $files = array();
        if (is_numeric($id) || strlen($id) != 13)
            $photos = $page->getPhotos();
        else
            $photos = $em->getRepository('MairieGestionMainBundle:Photos')->getPhotosByIdTemp($id);
        foreach($photos as $photo)
        {
            $files[] = array(
                'id' => $photo->getId(),
                'deleteType' => 'DELETE',
                'deleteUrl' => $this->container->get('router')->generate('photo_delete',array('id'=>$photo->getId())),
                'name' => $photo->getName(),
                'size' => $photo->getSize(),
                'thumbnailUrl' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb1()),
                'type' => $photo->getType(),
                'url' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb3()),
            );
        }
        return new Response(json_encode(array(
            'files' => $files,
        )));
    }
    
    /**
     * @Route("/ajax/upload-photo-event/{id}", name="ajax_upload_photo_event", options={"expose"=true})
     */
    public function ajaxUploadPhotoEventAction($id)
    {
        $request = $this->getRequest();
        $user = $this->container->get('security.context')->getToken()->getUser();
        if (!is_object($user) || !$user instanceof User) {
            die(var_dump($user instanceof User));
    		throw new AccessDeniedException('This user does not have access to this section.');
    	}
        $em = $this->getDoctrine()->getManager();
        $event = false;
        if (is_numeric($id) || strlen($id) != 13)
            $event = $em->getRepository('MairieGestionPlanningBundle:Event')->find($id);
        $this->checkObj($event);
        $mairie = $user->getMairie();
        $path_base = $this->container->get('kernel')->getRootDir() . '/../web/';
        $path = 'MairieGestion/uploads/mairies/'.$mairie->getId().'/';
        $full_path = $path_base.$path;
        
        if (!is_dir($full_path)) {
            @mkdir($full_path, 0777, true);
        }
        
        $tab_filename = explode('.',$_FILES['files']['name'][0]);
        
        $name = $_FILES['files']['name'][0];
        $size = $_FILES['files']['size'][0];
        $type = $_FILES['files']['type'][0];
        $filename = uniqid().'.'.$tab_filename[count($tab_filename)-1];
        $filename1 = 't1_'.$filename;
        $filename2 = 't2_'.$filename;
        $filename3 = 't3_'.$filename;
        $filename4 = 't4_'.$filename;
        $filename5 = 't5_'.$filename;
        
        if ((isset($_FILES['files']['tmp_name'][0])&&($_FILES['files']['error'][0] == UPLOAD_ERR_OK)))
            move_uploaded_file($_FILES['files']['tmp_name'][0], $full_path.$filename);     

        $imagine = new Imagine();
        $image = $imagine->open($full_path.$filename);
     
        $width1 = 75;
        $height1 = 50;
        $width2 = 300;
        $height2 = 200;
        $width3 = 570;
        $height3 = 380;
        $width4 = 930;
        $height4 = 465;
        $width5 = 1170;
        $height5 = 585;
        
        $this->saveImageBySize($image, $full_path.$filename5, $width5, $height5);
        $this->saveImageBySize($image, $full_path.$filename4, $width4, $height4);
        $this->saveImageBySize($image, $full_path.$filename3, $width3, $height3);
        $this->saveImageBySize($image, $full_path.$filename2, $width2, $height2);
        $this->saveImageBySize($image, $full_path.$filename1, $width1, $height1);
        
        if (file_exists($full_path.$filename))
        {
            $photo = new Photos();
            $photo->setType($type);
            $photo->setTag('photo_evenement');
            $photo->setName($name);
            $photo->setPath($path.$filename);
            $photo->setThumb1($path.$filename1);
            $photo->setThumb2($path.$filename2);
            $photo->setThumb3($path.$filename3);
            $photo->setThumb4($path.$filename4);
            $photo->setThumb5($path.$filename5);
            $photo->setWidth($image->getSize()->getHeight());
            $photo->setHeight($image->getSize()->getWidth());
            $photo->setWidthThumb1($width1);
            $photo->setHeightThumb1($height1);
            $photo->setWidthThumb2($width2);
            $photo->setHeightThumb2($height2);
            $photo->setWidthThumb3($width3);
            $photo->setHeightThumb3($height3);
            $photo->setWidthThumb4($width4);
            $photo->setHeightThumb4($height4);
            $photo->setWidthThumb5($width5);
            $photo->setHeightThumb5($height5);
            $photo->setSize($size);
            $photo->setTitle('Photo de l\'un événement de la mairie'.$mairie->getName());
            $photo->setMairie($mairie);
            if (is_numeric($id) || strlen($id) != 13)
                $photo->setEvent($event);
            else
                $photo->setIdTemp($id);
            $em->persist($photo);
            $em->flush();
        }
        
        return new Response(json_encode(array(
            'files' => array(
                0 => array(
                    'id' => $photo->getId(),
                    'deleteType' => 'DELETE',
                    'deleteUrl' => $this->container->get('router')->generate('photo_delete',array('id'=>$photo->getId())),
                    'name' => $name,
                    'size' => $size,
                    'thumbnailUrl' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb1()),
                    'type' => $type,
                    'url' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb3()),
                )
            ),
        )));
    }
    
    /**
     * @Route("/ajax/get-photos-event/{id}", name="ajax_get_photos_event", options={"expose"=true})
     */
    public function ajaxGetPhotosEventAction($id)
    {
        $request = $this->getRequest();
        
        $user = $this->container->get('security.context')->getToken()->getUser();
        if (!is_object($user) || !$user instanceof User) {
            die(var_dump($user instanceof User));
    		throw new AccessDeniedException('This user does not have access to this section.');
    	}
        $em = $this->getDoctrine()->getManager();
        $event = $em->getRepository('MairieGestionPlanningBundle:Event')->find($id);
        $mairie = $user->getMairie();
        
        $files = array();
        if (is_numeric($id) || strlen($id) != 13)
            $photos = $event->getPhotos();
        else
            $photos = $em->getRepository('MairieGestionMainBundle:Photos')->getPhotosByIdTemp($id);
        $this->checkObj($photos);
        foreach($photos as $photo)
        {
            $files[] = array(
                'id' => $photo->getId(),
                'deleteType' => 'DELETE',
                'deleteUrl' => $this->container->get('router')->generate('photo_delete',array('id'=>$photo->getId())),
                'name' => $photo->getName(),
                'size' => $photo->getSize(),
                'thumbnailUrl' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb1()),
                'type' => $photo->getType(),
                'url' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb3()),
            );
        }
        return new Response(json_encode(array(
            'files' => $files,
        )));
    }
    
    /**
     * @Route("/ajax/upload-archive/{id}", name="ajax_upload_archive", options={"expose"=true})
     */
    public function ajaxUploadArchiveAction($id)
    {
        $request = $this->getRequest();
        $user = $this->container->get('security.context')->getToken()->getUser();
        if (!is_object($user) || !$user instanceof User) {
            die(var_dump($user instanceof User));
    		throw new AccessDeniedException('This user does not have access to this section.');
    	}
        $em = $this->getDoctrine()->getManager();
        $archive = false;
        if (is_numeric($id) || strlen($id) != 13)
            $archive = $em->getRepository('MairieGestionPageBundle:Archive')->find($id);
        $this->checkObj($archive);
        $mairie = $user->getMairie();
        $path_base = $this->container->get('kernel')->getRootDir() . '/../web/';
        $path = 'MairieGestion/uploads/mairies/'.$mairie->getId().'/';
        $full_path = $path_base.$path;
        
        if (!is_dir($full_path)) {
            @mkdir($full_path, 0777, true);
        }
        
        $tab_filename = explode('.',$_FILES['files']['name'][0]);
        
        $name = $_FILES['files']['name'][0];
        $size = $_FILES['files']['size'][0];
        $type = $_FILES['files']['type'][0];
        $filename = uniqid().'.'.$tab_filename[count($tab_filename)-1];
        
        if ((isset($_FILES['files']['tmp_name'][0])&&($_FILES['files']['error'][0] == UPLOAD_ERR_OK)))
            move_uploaded_file($_FILES['files']['tmp_name'][0], $full_path.$filename);     
                
        if (file_exists($full_path.$filename))
        {
            $photo = new Photos();
            $photo->setType($type);
            $photo->setTag('bulletins_municipaux');
            $photo->setName($name);
            $photo->setPath($path.$filename);
            $photo->setSize($size);
            $photo->setTitle('Pdf de la mairie '.$mairie->getName());
            $photo->setMairie($mairie);
            if (is_numeric($id) || strlen($id) != 13)
                $photo->setArchive($archive);
            else
                $photo->setIdTemp($id);
            $em->persist($photo);
            $em->flush();
        }
        
        return new Response(json_encode(array(
            'files' => array(
                0 => array(
                    'id' => $photo->getId(),
                    'deleteType' => 'DELETE',
                    'deleteUrl' => $this->container->get('router')->generate('photo_delete',array('id'=>$photo->getId())),
                    'name' => $name,
                    'size' => $size,
                    'thumbnailUrl' => '/bundles/mairiegestionmain/images/pdf_icone_small.png',
                    'type' => $type,
                    'url' => $this->container->get('templating.helper.assets')->getUrl($photo->getPath()),
                )
            ),
        )));
    }
    
    /**
     * @Route("/ajax/get-archives/{id}", name="ajax_get_archive", options={"expose"=true})
     */
    public function ajaxGetArchivesAction($id)
    {
        $request = $this->getRequest();
        $user = $this->container->get('security.context')->getToken()->getUser();
        if (!is_object($user) || !$user instanceof User) {
            die(var_dump($user instanceof User));
    		throw new AccessDeniedException('This user does not have access to this section.');
    	}
        
        $em = $this->getDoctrine()->getManager();
        $mairie = $user->getMairie();
        $archive = false;
        if (is_numeric($id) || strlen($id) != 13)
        {
            $archive = $em->getRepository('MairieGestionPageBundle:Archive')->find($id);
            if (!$request->isXmlHttpRequest()
               || !$archive
               || (($archive->getMairie() && !$archive->getMairie()->getId() == $mairie->getId()))
               && !$this->get('security.context')->isGranted('ROLE_ADMIN')
            ) {
                return new Response('ko');
            }
        }
        $this->checkObj($archive);
        $files = array();
        if (is_numeric($id) || strlen($id) != 13)
            $photos = array($archive->getPhoto());
        else
            $photos = $em->getRepository('MairieGestionMainBundle:Photos')->getPhotosByIdTemp($id);
        foreach($photos as $photo)
        {
            $files[] = array(
                'id' => $photo->getId(),
                'deleteType' => 'DELETE',
                'deleteUrl' => $this->container->get('router')->generate('photo_delete',array('id'=>$photo->getId())),
                'name' => $this->getRequest()->getUriForPath('/'.$photo->getPath()),
                'size' => $photo->getSize(),
                'thumbnailUrl' => '/bundles/mairiegestionmain/images/pdf_icone_small.png',
                'type' => $photo->getType(),
                'url' => $this->container->get('templating.helper.assets')->getUrl($photo->getPath()),
            );
        }
        return new Response(json_encode(array(
            'files' => $files,
        )));
    }
    
    /**
     * @Route("/ajax/upload-plu/{id}", name="ajax_upload_plu", options={"expose"=true})
     */
    public function ajaxUploadPluAction($id)
    {
        $request = $this->getRequest();
        $user = $this->container->get('security.context')->getToken()->getUser();
        if (!is_object($user) || !$user instanceof User) {
    		throw new AccessDeniedException('This user does not have access to this section.');
    	}
        $em = $this->getDoctrine()->getManager();
        $plu = false;
        if (is_numeric($id) || strlen($id) != 13)
            $plu = $em->getRepository('MairieGestionPageBundle:Plu')->find($id);
        $this->checkObj($plu);
        $mairie = $user->getMairie();
        $path_base = $this->container->get('kernel')->getRootDir() . '/../web/';
        $path = 'MairieGestion/uploads/mairies/'.$mairie->getId().'/';
        $full_path = $path_base.$path;
        
        if (!is_dir($full_path)) {
            @mkdir($full_path, 0777, true);
        }
        
        $tab_filename = explode('.',$_FILES['files']['name'][0]);
        
        $name = $_FILES['files']['name'][0];
        $size = $_FILES['files']['size'][0];
        $type = $_FILES['files']['type'][0];
        $filename = uniqid().'.'.$tab_filename[count($tab_filename)-1];
        $filename1 = 't1_'.$filename;
        if ((isset($_FILES['files']['tmp_name'][0])&&($_FILES['files']['error'][0] == UPLOAD_ERR_OK)))
            move_uploaded_file($_FILES['files']['tmp_name'][0], $full_path.$filename);     
        $imagine = new Imagine();
        $image = $imagine->open($full_path.$filename);
        $width = $image->getSize()->getWidth();
        $height = $image->getSize()->getHeight();
        $width1 = 80;
        $height1 = 300;
        $height1 = $this->saveImageByHeightAndMawWidth($image, $full_path.$filename1, $width1, $height1);
        
        if (file_exists($full_path.$filename))
        {
            $photo = new Photos();
            $photo->setType($type);
            $photo->setTag('plu');
            $photo->setName($name);
            $photo->setPath($path.$filename);
            $photo->setThumb1($path.$filename1);
            $photo->setSize($size);
            $photo->setWidth($width);
            $photo->setHeight($height);
            $photo->setWidthThumb1($width1);
            $photo->setHeightThumb1($height1);
            $photo->setTitle('P.L.U de la mairie '.$mairie->getName());
            $photo->setMairie($mairie);
            if (is_numeric($id) || strlen($id) != 13)
                $photo->setPlu($plu);
            else
                $photo->setIdTemp($id);
            $em->persist($photo);
            $em->flush();
        }
        
        return new Response(json_encode(array(
            'files' => array(
                0 => array(
                    'id' => $photo->getId(),
                    'deleteType' => 'DELETE',
                    'deleteUrl' => $this->container->get('router')->generate('photo_delete',array('id'=>$photo->getId())),
                    'name' => $name,
                    'size' => $size,
                    'thumbnailUrl' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb1()),
                    'type' => $type,
                    'url' => $this->container->get('templating.helper.assets')->getUrl($photo->getPath()),
                )
            ),
        )));
    }
    
    /**
     * @Route("/ajax/get-plus/{id}", name="ajax_get_plu", options={"expose"=true})
     */
    public function ajaxGetPlusAction($id)
    {
        $request = $this->getRequest();
        $user = $this->container->get('security.context')->getToken()->getUser();
        if (!is_object($user) || !$user instanceof User) {
    		throw new AccessDeniedException('This user does not have access to this section.');
    	}
        
        $em = $this->getDoctrine()->getManager();
        $mairie = $user->getMairie();
        $plu = false;
        if (is_numeric($id) || strlen($id) != 13)
        {
            $plu = $em->getRepository('MairieGestionPageBundle:Plu')->find($id);
            if (!$request->isXmlHttpRequest()
               || !$plu
               || (($plu->getMairie() && !$plu->getMairie()->getId() == $mairie->getId()))
               && !$this->get('security.context')->isGranted('ROLE_ADMIN')
            ) {
                return new Response('ko');
            }
        }
        $this->checkObj($plu);
        $files = array();
        if (is_numeric($id) || strlen($id) != 13)
            $photos = array($plu->getPhoto());
        else
            $photos = $em->getRepository('MairieGestionMainBundle:Photos')->getPhotosByIdTemp($id);
        foreach($photos as $photo)
        {
            $files[] = array(
                'id' => $photo->getId(),
                'deleteType' => 'DELETE',
                'deleteUrl' => $this->container->get('router')->generate('photo_delete',array('id'=>$photo->getId())),
                'name' => $this->getRequest()->getUriForPath('/'.$photo->getPath()),
                'size' => $photo->getSize(),
                'thumbnailUrl' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb1()),
                'type' => $photo->getType(),
                'url' => $this->container->get('templating.helper.assets')->getUrl($photo->getPath()),
            );
        }
        return new Response(json_encode(array(
            'files' => $files,
        )));
    }
    
    /**
     * @Route("/ajax/upload-conseil/{id}", name="ajax_upload_conseil", options={"expose"=true})
     */
    public function ajaxUploadConseilAction($id)
    {
        $request = $this->getRequest();
        $user = $this->container->get('security.context')->getToken()->getUser();
        if (!is_object($user) || !$user instanceof User) {
            die(var_dump($user instanceof User));
    		throw new AccessDeniedException('This user does not have access to this section.');
    	}
        $em = $this->getDoctrine()->getManager();
        $conseil = $em->getRepository('MairieGestionPageBundle:Conseil')->find($id);
        $this->checkObj($conseil);
        $mairie = $user->getMairie();
        $path_base = $this->container->get('kernel')->getRootDir() . '/../web/';
        $path = 'MairieGestion/uploads/mairies/'.$mairie->getId().'/';
        $full_path = $path_base.$path;
        
        if (!is_dir($full_path)) {
            @mkdir($full_path, 0777, true);
        }
        
        $tab_filename = explode('.',$_FILES['files']['name'][0]);
        
        $name = $_FILES['files']['name'][0];
        $size = $_FILES['files']['size'][0];
        $type = $_FILES['files']['type'][0];
        $filename = uniqid().'.'.$tab_filename[count($tab_filename)-1];
        $filename1 = 't1_'.$filename;
        $filename2 = 't2_'.$filename;
        $filename3 = 't3_'.$filename;
        $filename4 = 't4_'.$filename;
        $filename5 = 't5_'.$filename;
        
        if ((isset($_FILES['files']['tmp_name'][0])&&($_FILES['files']['error'][0] == UPLOAD_ERR_OK)))
            move_uploaded_file($_FILES['files']['tmp_name'][0], $full_path.$filename);     

        $imagine = new Imagine();
        $image = $imagine->open($full_path.$filename);
     
        $width1 = 75;
        $height1 = 50;
        $width2 = 300;
        $height2 = 200;
        $width3 = 570;
        $height3 = 380;
        $width4 = 930;
        $height4 = 465;
        $width5 = 1170;
        $height5 = 585;
        
        $width_obligatoire = 840;
        
        if ($image->getSize()->getWidth() == $width_obligatoire)
        {
            $this->saveImageBySize($image, $full_path.$filename5, $width5, $height5);
            $this->saveImageBySize($image, $full_path.$filename4, $width4, $height4);
            $this->saveImageBySize($image, $full_path.$filename3, $width3, $height3);
            $this->saveImageBySize($image, $full_path.$filename2, $width2, $height2);
            $this->saveImageBySize($image, $full_path.$filename1, $width1, $height1);
            if (file_exists($full_path.$filename))
            {
                $photo = new Photos();
                $photo->setType($type);
                $photo->setTag('conseil');
                $photo->setName($name);
                $photo->setPath($path.$filename);
                $photo->setThumb1($path.$filename1);
                $photo->setThumb2($path.$filename2);
                $photo->setThumb3($path.$filename3);
                $photo->setThumb4($path.$filename4);
                $photo->setThumb5($path.$filename5);
                $photo->setWidth($image->getSize()->getHeight());
                $photo->setHeight($image->getSize()->getWidth());
                $photo->setWidthThumb1($width1);
                $photo->setHeightThumb1($height1);
                $photo->setWidthThumb2($width2);
                $photo->setHeightThumb2($height2);
                $photo->setWidthThumb3($width3);
                $photo->setHeightThumb3($height3);
                $photo->setWidthThumb4($width4);
                $photo->setHeightThumb4($height4);
                $photo->setWidthThumb5($width5);
                $photo->setHeightThumb5($height5);
                $photo->setSize($size);
                $photo->setTitle('Photo de la mairie '.$mairie->getName());
                $photo->setMairie($mairie);
                $photo->setConseil($conseil);
                $em->persist($photo);
                $em->flush();
            }
            
            return new Response(json_encode(array(
                'files' => array(
                    0 => array(
                        'id' => $photo->getId(),
                        'deleteType' => 'DELETE',
                        'deleteUrl' => $this->container->get('router')->generate('photo_delete',array('id'=>$photo->getId())),
                        'name' => $name,
                        'size' => $size,
                        'thumbnailUrl' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb1()),
                        'type' => $type,
                        'url' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb3()),
                    )
                ),
            )));
        }
        else
            return new Response(json_encode(array(
                'files' => array(
                    0 => array(
                        'error'=> ('L\'image doit avoir une largeur '.$width_obligatoire.' pixels'),
                        'deleteType' => 'DELETE',
                        'deleteUrl' => '',
                        'name' => $name,
                        'size' => $size,
                        'thumbnailUrl' => '',
                        'type' => $type,
                        'url' => '',
                    )
                ),
            )));
    }
    
    /**
     * @Route("/ajax/get-conseils/{id}", name="ajax_get_conseil", options={"expose"=true})
     */
    public function ajaxGetConseilsAction($id)
    {
        $request = $this->getRequest();
        $user = $this->container->get('security.context')->getToken()->getUser();
        if (!is_object($user) || !$user instanceof User) {
            die(var_dump($user instanceof User));
    		throw new AccessDeniedException('This user does not have access to this section.');
    	}
        
        $em = $this->getDoctrine()->getManager();
        $mairie = $user->getMairie();
        $conseil = false;
        if (is_numeric($id) || strlen($id) != 13)
        {
            $conseil = $em->getRepository('MairieGestionPageBundle:Conseil')->find($id);
            if (!$request->isXmlHttpRequest()
               || !$conseil
               || (($conseil->getMairie() && !$conseil->getMairie()->getId() == $mairie->getId()))
               && !$this->get('security.context')->isGranted('ROLE_ADMIN')
            ) {
                return new Response('ko');
            }
        }
        $this->checkObj($conseil);
        
        $files = array();
        $photos = array($conseil->getPhoto());
        foreach($photos as $photo)
        {
            if (is_object($photo))
            {
                $files[] = array(
                    'id' => $photo->getId(),
                    'deleteType' => 'DELETE',
                    'deleteUrl' => $this->container->get('router')->generate('photo_delete',array('id'=>$photo->getId())),
                    'name' => $photo->getName(),
                    'size' => $photo->getSize(),
                    'thumbnailUrl' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb1()),
                    'type' => $photo->getType(),
                    'url' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb3()),
                );
            }
        }
        return new Response(json_encode(array(
            'files' => $files,
        )));
    }
    
    /**
     * @Route("/ajax/upload-conseil-membres/{id}", name="ajax_upload_conseil_membre", options={"expose"=true})
     */
    public function ajaxUploadConseilMembreAction($id)
    {
        $request = $this->getRequest();
        $user = $this->container->get('security.context')->getToken()->getUser();
        if (!is_object($user) || !$user instanceof User) {
            die(var_dump($user instanceof User));
    		throw new AccessDeniedException('This user does not have access to this section.');
    	}
        $em = $this->getDoctrine()->getManager();
        $membre = $em->getRepository('MairieGestionPageBundle:ConseilMembre')->find($id);
        if ($membre) {
            $this->checkObj($membre->getConseil());
        }
        $mairie = $user->getMairie();
        $path_base = $this->container->get('kernel')->getRootDir() . '/../web/';
        $path = 'MairieGestion/uploads/mairies/'.$mairie->getId().'/';
        $full_path = $path_base.$path;
        
        if (!is_dir($full_path)) {
            @mkdir($full_path, 0777, true);
        }
        
        $tab_filename = explode('.',$_FILES['files']['name'][0]);
        
        $name = $_FILES['files']['name'][0];
        $size = $_FILES['files']['size'][0];
        $type = $_FILES['files']['type'][0];
        $filename = uniqid().'.'.$tab_filename[count($tab_filename)-1];
        $filename1 = 't1_'.$filename;
        $filename2 = 't2_'.$filename;
        $filename3 = 't3_'.$filename;
        $filename4 = 't4_'.$filename;
        $filename5 = 't5_'.$filename;
        
        if ((isset($_FILES['files']['tmp_name'][0])&&($_FILES['files']['error'][0] == UPLOAD_ERR_OK)))
            move_uploaded_file($_FILES['files']['tmp_name'][0], $full_path.$filename);     

        $imagine = new Imagine();
        $image = $imagine->open($full_path.$filename);
     
        $width_required = 230;
        $height_max_required = 296;
        
        $width1 = 75;
        $height1 = 50;
        $width2 = 300;
        $height2 = 200;
        $width3 = 570;
        $height3 = 380;
        $width4 = 930;
        $height4 = 465;
        $width5 = 1170;
        $height5 = 585;
        
        if ($image->getSize()->getWidth() == $width_required && $image->getSize()->getHeight() <= $height_max_required)
        {
            $this->saveImageBySize($image, $full_path.$filename5, $width5, $height5);
            $this->saveImageBySize($image, $full_path.$filename4, $width4, $height4);
            $this->saveImageBySize($image, $full_path.$filename3, $width3, $height3);
            $this->saveImageBySize($image, $full_path.$filename2, $width2, $height2);
            $this->saveImageBySize($image, $full_path.$filename1, $width1, $height1);
            
            if (file_exists($full_path.$filename))
            {
                $photo = new Photos();
                $photo->setType($type);
                $photo->setTag('conseil_membre');
                $photo->setName($name);
                $photo->setPath($path.$filename);
                $photo->setThumb1($path.$filename1);
                $photo->setThumb2($path.$filename2);
                $photo->setThumb3($path.$filename3);
                $photo->setThumb4($path.$filename4);
                $photo->setThumb5($path.$filename5);
                $photo->setWidth($image->getSize()->getHeight());
                $photo->setHeight($image->getSize()->getWidth());
                $photo->setWidthThumb1($width1);
                $photo->setHeightThumb1($height1);
                $photo->setWidthThumb2($width2);
                $photo->setHeightThumb2($height2);
                $photo->setWidthThumb3($width3);
                $photo->setHeightThumb3($height3);
                $photo->setWidthThumb4($width4);
                $photo->setHeightThumb4($height4);
                $photo->setWidthThumb5($width5);
                $photo->setHeightThumb5($height5);
                $photo->setSize($size);
                $photo->setTitle('Photo de la mairie '.$mairie->getName());
                $photo->setMairie($mairie);
                if (is_numeric($id) || strlen($id) != 13)
                    $photo->setMembre($membre);
                else
                    $photo->setIdTemp($id);
                $em->persist($photo);
                $em->flush();
            }
            
            return new Response(json_encode(array(
                'files' => array(
                    0 => array(
                        'id' => $photo->getId(),
                        'deleteType' => 'DELETE',
                        'deleteUrl' => $this->container->get('router')->generate('photo_delete',array('id'=>$photo->getId())),
                        'name' => $name,
                        'size' => $size,
                        'thumbnailUrl' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb1()),
                        'type' => $type,
                        'url' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb3()),
                    )
                ),
            )));
        }
        else
            return new Response(json_encode(array(
                'files' => array(
                    0 => array(
                        'error'=> ('L\'image doit avoir une hauteur de '.$height_max_required.' pixels maximum et une largeur de '.$width_required.' pixels'),
                        'deleteType' => 'DELETE',
                        'deleteUrl' => '',
                        'name' => $name,
                        'size' => $size,
                        'thumbnailUrl' => '',
                        'type' => $type,
                        'url' => '',
                    )
                ),
            )));
    }
    
    /**
     * @Route("/ajax/get-conseil-membres/{id}", name="ajax_get_conseil_membre", options={"expose"=true})
     */
    public function ajaxGetConseilMembresAction($id)
    {
        $request = $this->getRequest();
        $user = $this->container->get('security.context')->getToken()->getUser();
        if (!is_object($user) || !$user instanceof User) {
            die(var_dump($user instanceof User));
    		throw new AccessDeniedException('This user does not have access to this section.');
    	}
        
        $em = $this->getDoctrine()->getManager();
        $mairie = $user->getMairie();
        $membre = false;
        if (is_numeric($id) || strlen($id) != 13)
        {
            $membre = $em->getRepository('MairieGestionPageBundle:ConseilMembre')->find($id);
            if (!$request->isXmlHttpRequest()
               || !$membre
               || (($membre->getConseil()->getMairie() && !$membre->getConseil()->getMairie()->getId() == $mairie->getId()))
               && !$this->get('security.context')->isGranted('ROLE_ADMIN')
            ) {
                return new Response('ko');
            }
        }
        $this->checkObj($membre->getConseil());
        $files = array();
        if (is_numeric($id) || strlen($id) != 13)
            $photos = array($membre->getPhoto());
        else
            $photos = $em->getRepository('MairieGestionMainBundle:Photos')->getPhotosByIdTemp($id);
        foreach($photos as $photo)
        {
            if (is_object($photo))
            {
                $files[] = array(
                    'id' => $photo->getId(),
                    'deleteType' => 'DELETE',
                    'deleteUrl' => $this->container->get('router')->generate('photo_delete',array('id'=>$photo->getId())),
                    'name' => $photo->getName(),
                    'size' => $photo->getSize(),
                    'thumbnailUrl' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb1()),
                    'type' => $photo->getType(),
                    'url' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb3()),
                );
            }
        }
        return new Response(json_encode(array(
            'files' => $files,
        )));
    }
    
    /**
     * @Route("/ajax/upload-img-header", name="ajax_upload_imgHeader", options={"expose"=true})
     */
    public function ajaxUploadImgHeaderAction()
    {
        $request = $this->getRequest();
        $user = $this->container->get('security.context')->getToken()->getUser();
        if (!is_object($user) || !$user instanceof User) {
            die(var_dump($user instanceof User));
    		throw new AccessDeniedException('This user does not have access to this section.');
    	}
        $mairie = $user->getMairie();
        $path_base = $this->container->get('kernel')->getRootDir() . '/../web/';
        $path = 'MairieGestion/uploads/mairies/'.$mairie->getId().'/';
        $full_path = $path_base.$path;
        
        if (!is_dir($full_path)) {
            @mkdir($full_path, 0777, true);
        }
        
        $tab_filename = explode('.',$_FILES['files']['name'][0]);
        
        $name = $_FILES['files']['name'][0];
        $size = $_FILES['files']['size'][0];
        $type = $_FILES['files']['type'][0];
        $filename = uniqid().'.'.$tab_filename[count($tab_filename)-1];
        $filename1 = 't1_'.$filename;
        $filename2 = 't2_'.$filename;
        $filename3 = 't3_'.$filename;
        
        if ((isset($_FILES['files']['tmp_name'][0])&&($_FILES['files']['error'][0] == UPLOAD_ERR_OK)))
            move_uploaded_file($_FILES['files']['tmp_name'][0], $full_path.$filename);     

        $imagine = new Imagine();
        $image = $imagine->open($full_path.$filename);
     
        $width_origin = $image->getSize()->getWidth();
        $height_origin = $image->getSize()->getHeight();
        $width1 = 150;
        $height1 = 21;
        $width2 = 950;
        $height2 = 130;
        $width3 = 1220;
        $height3 = 160;
     
        
        if ($image->getSize()->getWidth() == $width3)
        {
            $height2 = $this->saveImageByHeightAndMawWidth($image, $full_path.$filename2, $width2, $height2);
            $height1 = $this->saveImageByHeightAndMawWidth($image, $full_path.$filename1, $width1, $height1);
            
            if (file_exists($full_path.$filename))
            {
                $photo = new Photos();
                $photo->setType($type);
                $photo->setTag('photo_mairie_header');
                $photo->setName($name);
                $photo->setPath($path.$filename);
                $photo->setThumb1($path.$filename1);
                $photo->setThumb2($path.$filename2);
                $photo->setHeight($height_origin);
                $photo->setWidth($width_origin);
                $photo->setWidthThumb1($width1);
                $photo->setHeightThumb1($height1);
                $photo->setWidthThumb2($width2);
                $photo->setHeightThumb2($height2);
                $photo->setSize($size);
                $photo->setTitle('Photo de la mairie '.$mairie->getName());
                $photo->setMairie($mairie);
                
                $mairie->setImgHeader($photo);
                $em = $this->getDoctrine()->getManager();
                $em->persist($photo);
                $em->persist($mairie);
                $em->flush();
            }
            
            return new Response(json_encode(array(
                'files' => array(
                    0 => array(
                        'id' => $photo->getId(),
                        'deleteType' => 'DELETE',
                        'deleteUrl' => $this->container->get('router')->generate('photo_delete',array('id'=>$photo->getId())),
                        'name' => $name,
                        'size' => $size,
                        'thumbnailUrl' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb1()),
                        'type' => $type,
                        'url' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb3()),
                    )
                ),
            )));
        }
        else
            return new Response(json_encode(array(
                'files' => array(
                    0 => array(
                        'error'=> ('L\'image doit avoir une largeur de '.$width3.' pixels'),
                        'deleteType' => 'DELETE',
                        'deleteUrl' => '',
                        'name' => $name,
                        'size' => $size,
                        'thumbnailUrl' => '',
                        'type' => $type,
                        'url' => '',
                    )
                ),
            )));
    }
    
    /**
     * @Route("/ajax/get-img-headers", name="ajax_get_imgHeaders", options={"expose"=true})
     */
    public function ajaxGetImgHeadersAction()
    {
        $request = $this->getRequest();
        $user = $this->container->get('security.context')->getToken()->getUser();
        if (!is_object($user) || !$user instanceof User) {
            die(var_dump($user instanceof User));
    		throw new AccessDeniedException('This user does not have access to this section.');
    	}
        $mairie = $user->getMairie();
        
        $files = array();
        $photo = $mairie->getImgHeader();
        $files[] = array(
            'id' => $photo->getId(),
            'deleteType' => 'DELETE',
            'deleteUrl' => $this->container->get('router')->generate('photo_delete',array('id'=>$photo->getId())),
            'name' => $photo->getName(),
            'size' => $photo->getSize(),
            'thumbnailUrl' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb1()),
            'type' => $photo->getType(),
            'url' => $this->container->get('templating.helper.assets')->getUrl($photo->getPath()),
        );
        return new Response(json_encode(array(
            'files' => $files,
        )));
    }
    
    /**
     * @Route("/ajax/upload-img-url", name="ajax_upload_photo_url", options={"expose"=true})
     */
    public function ajaxUploadImgUrlAction()
    {
        $request = $this->getRequest();
        $user = $this->container->get('security.context')->getToken()->getUser();
        if (!is_object($user) || !$user instanceof User) {
            die(var_dump($user instanceof User));
    		throw new AccessDeniedException('This user does not have access to this section.');
    	}
        $mairie = $user->getMairie();
        $path_base = $this->container->get('kernel')->getRootDir() . '/../web/';
        $path = 'MairieGestion/uploads/mairies/'.$mairie->getId().'/';
        $full_path = $path_base.$path;
        
        if (!is_dir($full_path)) {
            @mkdir($full_path, 0777, true);
        }
        
        $tab_filename = explode('.',$_FILES['files']['name'][0]);
        
        $name = $_FILES['files']['name'][0];
        $size = $_FILES['files']['size'][0];
        $type = $_FILES['files']['type'][0];
        $filename = uniqid().'.'.$tab_filename[count($tab_filename)-1];
        $filename1 = 't1_'.$filename;
        $filename2 = 't2_'.$filename;
        $filename3 = 't3_'.$filename;
        
        if ((isset($_FILES['files']['tmp_name'][0])&&($_FILES['files']['error'][0] == UPLOAD_ERR_OK)))
            move_uploaded_file($_FILES['files']['tmp_name'][0], $full_path.$filename);     

        $imagine = new Imagine();
        $image = $imagine->open($full_path.$filename);
     
        $width1 = 150;
        $height1 = 3000;
        $width2 = 950;
        $height2 = 3000;
        $width3 = 1170;
        $height3 = 3000;
     
        $width_obligatoire = 1170;
        if ($image->getSize()->getWidth() <= $width_obligatoire)
        {
            $height3 = $this->saveImageByHeightAndMawWidth($image, $full_path.$filename3, $width3, $height3);
            $height2 = $this->saveImageByHeightAndMawWidth($image, $full_path.$filename2, $width2, $height2);
            $height1 = $this->saveImageByHeightAndMawWidth($image, $full_path.$filename1, $width1, $height1);
            
            if (file_exists($full_path.$filename))
            {
                $photo = new Photos();
                $photo->setType($type);
                $photo->setTag('photo_url');
                $photo->setName($name);
                $photo->setPath($path.$filename);
                $photo->setThumb1($path.$filename1);
                $photo->setThumb2($path.$filename2);
                $photo->setThumb3($path.$filename3);
                $photo->setHeight($image->getSize()->getWidth());
                $photo->setWidth($image->getSize()->getHeight());
                $photo->setWidthThumb1($width1);
                $photo->setHeightThumb1($height1);
                $photo->setWidthThumb2($width2);
                $photo->setHeightThumb2($height2);
                $photo->setWidthThumb3($width3);
                $photo->setHeightThumb3($height3);
                $photo->setSize($size);
                $photo->setTitle('Photo de la mairie '.$mairie->getName());
                $photo->setMairie($mairie);
                
                $em = $this->getDoctrine()->getManager();
                $em->persist($photo);
                $em->flush();
            }
            
            return new Response(json_encode(array(
                'files' => array(
                    0 => array(
                        'id' => $photo->getId(),
                        'deleteType' => 'DELETE',
                        'deleteUrl' => $this->container->get('router')->generate('photo_delete',array('id'=>$photo->getId())),
                        'name' => $this->getRequest()->getUriForPath('/'.$photo->getPath()),
                        'size' => $size,
                        'thumbnailUrl' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb1()),
                        'type' => $type,
                        'url' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb3()),
                    )
                ),
            )));
        }
        else
            return new Response(json_encode(array(
                'files' => array(
                    0 => array(
                        'error'=> ('L\'image doit avoir une largeur maximale de '.$width_obligatoire.' pixels'),
                        'deleteType' => 'DELETE',
                        'deleteUrl' => '',
                        'name' => $name,
                        'size' => $size,
                        'thumbnailUrl' => '',
                        'type' => $type,
                        'url' => '',
                    )
                ),
            )));
    }
    
    /**
     * @Route("/ajax/get-img-archive", name="ajax_get_photos_archive", options={"expose"=true})
     */
    public function ajaxGetImgArchiveAction()
    {
        $request = $this->getRequest();
        $user = $this->container->get('security.context')->getToken()->getUser();
        if (!is_object($user) || !$user instanceof User) {
    		throw new AccessDeniedException('This user does not have access to this section.');
    	}
        $mairie = $user->getMairie();
        
        $files = array();
        $photos = $mairie->getPhotosArchives();
        foreach($photos as $photo)
        {
            $files[] = array(
                'id' => $photo->getId(),
                'deleteType' => 'DELETE',
                'deleteUrl' => $this->container->get('router')->generate('photo_delete',array('id'=>$photo->getId())),
                'name' => $this->getRequest()->getUriForPath('/'.$photo->getPath()),
                'size' => $photo->getSize(),
                'thumbnailUrl' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb1()),
                'type' => $photo->getType(),
                'url' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb3()),
            );
        }
        return new Response(json_encode(array(
            'files' => $files,
        )));
    }
    
    /**
     * @Route("/ajax/get-img-url", name="ajax_get_photos_url", options={"expose"=true})
     */
    public function ajaxGetImgUrlAction()
    {
        $request = $this->getRequest();
        $user = $this->container->get('security.context')->getToken()->getUser();
        if (!is_object($user) || !$user instanceof User) {
            die(var_dump($user instanceof User));
    		throw new AccessDeniedException('This user does not have access to this section.');
    	}
        $mairie = $user->getMairie();
        
        $files = array();
        $photos = $mairie->getPhotosUrl();
        foreach($photos as $photo)
        {
            $files[] = array(
                'id' => $photo->getId(),
                'deleteType' => 'DELETE',
                'deleteUrl' => $this->container->get('router')->generate('photo_delete',array('id'=>$photo->getId())),
                'name' => $this->getRequest()->getUriForPath('/'.$photo->getPath()),
                'size' => $photo->getSize(),
                'thumbnailUrl' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb1()),
                'type' => $photo->getType(),
                'url' => $this->container->get('templating.helper.assets')->getUrl($photo->getThumb3()),
            );
        }
        return new Response(json_encode(array(
            'files' => $files,
        )));
    }
    
    /**
     * @Route("/ajax/delete-photo/{id}", name="photo_delete", options={"expose"=true})
     */
    public function ajaxDeletePhotoAction($id)
    {
        $request = $this->getRequest();
        $em = $this->getDoctrine()->getManager();
        $photo = $em->getRepository('MairieGestionMainBundle:Photos')->find($id);
        $this->checkObj($photo);
        if (!$request->isXmlHttpRequest()
           || !$photo
           || (($photo->getMairie() && !$photo->getMairie()->getId() == $this->getUser()->getMairie()->getId()))
           && !$this->get('security.context')->isGranted('ROLE_ADMIN')
        ) {
            return new Response('ko');
        }
        if ($photo->getTag() == 'bulletins_municipaux')
        {
            $archive = $photo->getArchive();
            if (is_object($archive))
            {
                $archive->setActive(0);
                $em->persist($archive);
            }
        }
        $em->remove($photo);
        $em->flush();

        return new Response(json_encode(array('ok')));
    }
    
    
    /**
     * @Route("/ajax/position-photo/{str}", name="ajax_position_photos", options={"expose"=true})
     */
    public function ajaxPositionPhotoAction($str)
    {
        $tab_photo = explode(';', $str);
        $return = '';
        $em = $this->getDoctrine()->getManager();
        foreach($tab_photo as $key => $photos_id)
        {
            if (is_numeric($photos_id))
                $photo = $em->getRepository('MairieGestionMainBundle:Photos')->find($photos_id);
            $this->checkObj($photo);
            $photo->setPosition($key);
            $em->persist($photo);
        }
        // var_dump($tab_photo);
        $em->flush();
        return new Response('ok');
    }
    
    /**
     * @Route("/ajax/archive-photo/{id}", name="ajax_archive_photos", options={"expose"=true})
     */
    public function ajaxArchivePhotoAction($id)
    {
        $em = $this->getDoctrine()->getManager();
        $photo = $em->getRepository('MairieGestionMainBundle:Photos')->find($id);
        $this->checkObj($photo);
        $photo->setPublished(false);
        $em->persist($photo);
        $em->flush();
        return new Response('ok');
    }
    
    /**
     * @Route("/ajax/desarchive-photo/{id}", name="ajax_desarchive_photos", options={"expose"=true})
     */
    public function ajaxDesarchivePhotoAction($id)
    {
        $em = $this->getDoctrine()->getManager();
        $photo = $em->getRepository('MairieGestionMainBundle:Photos')->find($id);
        $photo->setPublished(true);
        $this->checkObj($photo);
        $em->persist($photo);
        $em->flush();
        return new Response('ok');
    }
}
