<?php

namespace MairieGestion\PageBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use Symfony\Component\Security\Core\Exception\AccessDeniedException;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Form\FormError;

use MairieGestion\PageBundle\Entity\Plu;
use MairieGestion\UserBundle\Entity\User as User;
use MairieGestion\PageBundle\Form\PluType;
class PluController extends Controller
{
    public function checkObj($obj)
    {
        $base_url = $this->getRequest()->getUriForPath('');
        $em = $this->getDoctrine()->getManager();
        $mairie = $em->getRepository('MairieGestionMairieBundle:Mairie')->getMairieByDomaine($base_url);
        if (is_object($obj) && $mairie != $obj->getMairie() && $obj->getMairie())
            throw new \Symfony\Component\Security\Core\Exception\AccessDeniedException ();
    }
    
    /**
     * @Route("/admin/plu/liste", name="carte_plu_liste")
     * @Template()
     */
    public function listePluAction()
    {
        $em = $this->getDoctrine()->getManager();
        $user = $this->container->get('security.context')->getToken()->getUser();
        $plus = $em->getRepository('MairieGestionPageBundle:Plu')->getPlusAdmin($user->getMairie());
        return array(
            'plus'=>$plus,
        );
    }
    
    /**
     * @Route("/admin/plu/nouveau", name="carte_plu_new")
     * @Template()
     */
    public function newPluAction($id=null)
    {
        $user = $this->container->get('security.context')->getToken()->getUser();
        $mairie = $user->getMairie();
        $request = $this->getRequest();
        $em = $this->getDoctrine()->getEntityManager();
        $more_options = false;
        if ($id && (is_numeric($id) || strlen($id) != 13))
            $plu = $em->getRepository('MairieGestionPageBundle:Plu')->find($id);
        else
            $plu = new Plu();
        $this->checkObj($plu);
        $form       = $this->createForm(new PluType(), $plu);
        if ($request->getMethod() == 'POST')
        {
            $form->bind($request);
            if(($id && !is_numeric($id) && strlen($id) == 13) || $request->get('id_temp'))
            {
                $photos = $em->getRepository('MairieGestionMainBundle:Photos')->getPhotosByIdTemp($request->get('id_temp'));
                if (count($photos) == 0)
                    $form->addError(new FormError('Veuillez joindre un P.L.U'));
                foreach($photos as $photo)
                    $photo->setPlu($plu);
            }
            if($form->isValid()) {
                if (!$id)
                {
                    $plu->setMairie($user->getMairie());
                    $plu->setUser($user);
                }
                if (!$plu->getId())
                {
                    $photos = $em->getRepository('MairieGestionMainBundle:Photos')->getPhotosByIdTemp($request->get('id_temp'));
                    foreach($photos as $photo)
                    {
                        $photo->setIdTemp(null);
                        $em->persist($photo);
                        $photo->setPlu($plu);
                    }
                }
                $em->persist($plu);
                $em->flush();
                return $this->redirect($this->generateUrl('carte_plu_liste'));
           }
        }
        return $this->render('MairieGestionPageBundle:Plu:newPlu.html.twig', array(
            'uniqid' => $request->get('id_temp')?$request->get('id_temp'):uniqid(),
            'plu'    => $plu,
            'form'       => $form->createView(),
            'type'       => 'new',
        ));
    }
    
    /**
     * @Route("/admin/plu/modification/{id}", name="carte_plu_edit")
     * @Template()
     */
    public function editPluAction($id)
    {
        return $this->newPluAction($id);
    }
    
    /**
     * @Route("/admin/plu/delete/{id}", name="carte_plu_delete")
     * @Template()
     */
    public function deletePluAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $plu = $em->getRepository('MairieGestionPageBundle:Plu')->find($id);
        $this->checkObj($plu);
        $em->remove($plu);
        $em->flush();
        return $this->redirect($this->generateUrl('carte_plu_liste'));
    }
    
    /**
     * @Route("/admin/plu/active/{id}", name="carte_plu_active")
     * @Template()
     */
    public function activePluAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $plu = $em->getRepository('MairieGestionPageBundle:Plu')->find($id);
        $this->checkObj($plu);
        $plu->setActive(true);
        $em->flush();
        return $this->redirect($this->generateUrl('carte_plu_liste'));
    }
    
    /**
     * @Route("/admin/plu/desactive/{id}", name="carte_plu_desactive")
     * @Template()
     */
    public function desactivePluAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $plu = $em->getRepository('MairieGestionPageBundle:Plu')->find($id);
        $this->checkObj($plu);
        $plu->setActive(false);
        $em->flush();
        return $this->redirect($this->generateUrl('carte_plu_liste'));
    }
}
