<?php

namespace MairieGestion\PageBundle\Entity;

use Doctrine\ORM\Mapping as ORM;

/**
 * AlbumPhoto
 *
 * @ORM\Table()
 * @ORM\Entity(repositoryClass="MairieGestion\PageBundle\Entity\AlbumPhotoRepository")
 */
class AlbumPhoto
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $id;

    /**
     * @var string
     *
     * @ORM\Column(name="name", type="string", length=255)
     */
    private $name;

    /**
     * @var integer
     *
     * @ORM\Column(name="annee", type="integer")
     */
    private $annee;

    /**
     * @var integer
     *
     * @ORM\Column(name="mois", type="integer")
     */
    private $mois;
    
    /**
     * @var datetime $createdAt
     *
     * @ORM\Column(name="createdAt", type="datetime", nullable=true)
     */
    private $createdAt;

    /**
     * @ORM\ManyToMany(targetEntity="MairieGestion\PageBundle\Entity\Album", inversedBy="albumPhotos")
     */
    private $albums;
    
    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\MairieBundle\Entity\Mairie", inversedBy="albumPhotos")
     */
    private $mairie;
    
    /**
     * @ORM\OneToMany(targetEntity="MairieGestion\MainBundle\Entity\Photos", mappedBy="albumPhoto", cascade={"persist", "remove"})
     */
    private $photos;

    public function __construct()
    {
        $this->createdAt = new \DateTime();
    }
    
    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set name
     *
     * @param string $name
     * @return AlbumPhoto
     */
    public function setName($name)
    {
        $this->name = $name;
    
        return $this;
    }

    /**
     * Get name
     *
     * @return string 
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     * Set annee
     *
     * @param integer $annee
     * @return AlbumPhoto
     */
    public function setAnnee($annee)
    {
        $this->annee = $annee;
    
        return $this;
    }

    /**
     * Get annee
     *
     * @return integer 
     */
    public function getAnnee()
    {
        return $this->annee;
    }

    /**
     * Set mois
     *
     * @param integer $mois
     * @return AlbumPhoto
     */
    public function setMois($mois)
    {
        $this->mois = $mois;
    
        return $this;
    }

    /**
     * Get mois
     *
     * @return integer 
     */
    public function getMois()
    {
        return $this->mois;
    }

    /**
     * Set createdAt
     *
     * @param \DateTime $createdAt
     * @return AlbumPhoto
     */
    public function setCreatedAt($createdAt)
    {
        $this->createdAt = $createdAt;
    
        return $this;
    }

    /**
     * Get createdAt
     *
     * @return \DateTime 
     */
    public function getCreatedAt()
    {
        return $this->createdAt;
    }

    /**
     * Add albums
     *
     * @param \MairieGestion\PageBundle\Entity\Album $albums
     * @return AlbumPhoto
     */
    public function addAlbum(\MairieGestion\PageBundle\Entity\Album $albums)
    {
        $this->albums[] = $albums;
    
        return $this;
    }

    /**
     * Remove albums
     *
     * @param \MairieGestion\PageBundle\Entity\Album $albums
     */
    public function removeAlbum(\MairieGestion\PageBundle\Entity\Album $albums)
    {
        $this->albums->removeElement($albums);
    }

    /**
     * Get albums
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getAlbums()
    {
        return $this->albums;
    }

    /**
     * Set mairie
     *
     * @param \MairieGestion\MairieBundle\Entity\Mairie $mairie
     * @return AlbumPhoto
     */
    public function setMairie(\MairieGestion\MairieBundle\Entity\Mairie $mairie = null)
    {
        $this->mairie = $mairie;
    
        return $this;
    }

    /**
     * Get mairie
     *
     * @return \MairieGestion\MairieBundle\Entity\Mairie 
     */
    public function getMairie()
    {
        return $this->mairie;
    }

    /**
     * Add photos
     *
     * @param \MairieGestion\MainBundle\Entity\Photos $photos
     * @return AlbumPhoto
     */
    public function addPhoto(\MairieGestion\MainBundle\Entity\Photos $photos)
    {
        $this->photos[] = $photos;
    
        return $this;
    }

    /**
     * Remove photos
     *
     * @param \MairieGestion\MainBundle\Entity\Photos $photos
     */
    public function removePhoto(\MairieGestion\MainBundle\Entity\Photos $photos)
    {
        $this->photos->removeElement($photos);
    }

    /**
     * Get photos
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getPhotos()
    {
        return $this->photos;
    }
}