<?php

namespace MairieGestion\PageBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * Archive
 *
 * @ORM\Table()
 * @ORM\Entity(repositoryClass="MairieGestion\PageBundle\Entity\ArchiveRepository")
 */
class Archive
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $id;

    /**
     * @var string
     *
     * @ORM\Column(name="name", type="string", length=255)
     * @Assert\NotBlank(message="Veuillez renseigner le nom")
     */
    private $name;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="date", type="datetime")
     * @Assert\NotBlank(message="Veuillez renseigner la date")
     */
    private $date;

    /**
     * @var string
     *
     * @ORM\Column(name="description", type="text", nullable=true)
     */
    private $description;

    /**
     * @var boolean
     *
     * @ORM\Column(name="active", type="boolean")
     */
    private $active;

    /**
     * @ORM\OneToMany(targetEntity="MairieGestion\MainBundle\Entity\Photos", mappedBy="archive", cascade={"persist", "remove"})
     * @Assert\NotBlank(message="Veuillez joindre un pdf")
     */
    private $photos;

    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\MairieBundle\Entity\Mairie", inversedBy="archives")
     */
    private $mairie;
    
    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\PageBundle\Entity\ArchiveCategory", inversedBy="archives")
     */
    private $category;
    
    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\UserBundle\Entity\User", inversedBy="archives")
     */
    private $user;
    
    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set name
     *
     * @param string $name
     * @return Archive
     */
    public function setName($name)
    {
        $this->name = $name;
    
        return $this;
    }

    /**
     * Get name
     *
     * @return string 
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     * Set date
     *
     * @param \DateTime $date
     * @return Archive
     */
    public function setDate($date)
    {
        $this->date = $date;
    
        return $this;
    }

    /**
     * Get date
     *
     * @return \DateTime 
     */
    public function getDate()
    {
        return $this->date;
    }

    /**
     * Set description
     *
     * @param string $description
     * @return Archive
     */
    public function setDescription($description)
    {
        $this->description = $description;
    
        return $this;
    }

    /**
     * Get description
     *
     * @return string 
     */
    public function getDescription()
    {
        return $this->description;
    }

    /**
     * Set active
     *
     * @param boolean $active
     * @return Archive
     */
    public function setActive($active)
    {
        $this->active = $active;
    
        return $this;
    }

    /**
     * Get active
     *
     * @return boolean 
     */
    public function getActive()
    {
        return $this->active;
    }

    /**
     * Set mairie
     *
     * @param \MairieGestion\MairieBundle\Entity\Mairie $mairie
     * @return Archive
     */
    public function setMairie(\MairieGestion\MairieBundle\Entity\Mairie $mairie = null)
    {
        $this->mairie = $mairie;
    
        return $this;
    }

    /**
     * Get mairie
     *
     * @return \MairieGestion\MairieBundle\Entity\Mairie 
     */
    public function getMairie()
    {
        return $this->mairie;
    }

    /**
     * Set user
     *
     * @param \MairieGestion\UserBundle\Entity\User $user
     * @return Archive
     */
    public function setUser(\MairieGestion\UserBundle\Entity\User $user = null)
    {
        $this->user = $user;
    
        return $this;
    }

    /**
     * Get user
     *
     * @return \MairieGestion\UserBundle\Entity\User 
     */
    public function getUser()
    {
        return $this->user;
    }
    /**
     * Constructor
     */
    public function __construct()
    {
        $this->photos = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Add photos
     *
     * @param \MairieGestion\MainBundle\Entity\Photos $photos
     * @return Archive
     */
    public function addPhoto(\MairieGestion\MainBundle\Entity\Photos $photos)
    {
        $this->photos[] = $photos;
    
        return $this;
    }

    /**
     * Remove photos
     *
     * @param \MairieGestion\MainBundle\Entity\Photos $photos
     */
    public function removePhoto(\MairieGestion\MainBundle\Entity\Photos $photos)
    {
        $this->photos->removeElement($photos);
    }

    /**
     * Get photos
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getPhotos()
    {
        return $this->photos;
    }
    
    public function getPhoto()
    {
        return $this->photos?$this->photos[0]:null;
    }

    /**
     * Set category
     *
     * @param \MairieGestion\PageBundle\Entity\ArchiveCategory $category
     * @return Archive
     */
    public function setCategory(\MairieGestion\PageBundle\Entity\ArchiveCategory $category = null)
    {
        $this->category = $category;
    
        return $this;
    }

    /**
     * Get category
     *
     * @return \MairieGestion\PageBundle\Entity\ArchiveCategory 
     */
    public function getCategory()
    {
        return $this->category;
    }
}