<?php

namespace MairieGestion\PageBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * Carte
 *
 * @ORM\Table()
 * @ORM\Entity(repositoryClass="MairieGestion\PageBundle\Entity\CarteRepository")
 */
class Carte
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $id;

    /**
     * @var string
     *
     * @ORM\Column(name="name", type="string", length=255)
     * @Assert\NotBlank(message="Veuillez saisir le titre de la carte")
     */
    private $name;

    /**
     * @var integer
     *
     * @ORM\Column(name="width", type="smallint")
     * @Assert\NotBlank(message="Veuillez saisir la largeur de la carte")
     */
    private $width;

    /**
     * @var integer
     *
     * @ORM\Column(name="height", type="smallint")
     * @Assert\NotBlank(message="Veuillez saisir la hauteur de la carte")
     */
    private $height;
    
    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\UserBundle\Entity\User", inversedBy="cartes")
     */
    private $user;
    
    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\MairieBundle\Entity\Mairie", inversedBy="cartes")
     */
    private $mairie;
    
    /**
     * @ORM\OneToMany(targetEntity="MairieGestion\PageBundle\Entity\Lieu", mappedBy="carte", cascade={"persist", "remove"})
     * @ORM\OrderBy({"position" = "ASC"})
     */
    private $lieux;
    
    /**
     * @ORM\OneToMany(targetEntity="MairieGestion\PageBundle\Entity\Page", mappedBy="carte")
     */
    private $pages;

    /**
     * Constructor
     */
    public function __construct()
    {
        $this->lieux = new \Doctrine\Common\Collections\ArrayCollection();
        $this->width = 400;
        $this->height = 400;
    }
    
    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set name
     *
     * @param string $name
     * @return Carte
     */
    public function setName($name)
    {
        $this->name = $name;
    
        return $this;
    }

    /**
     * Get name
     *
     * @return string 
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     * Set width
     *
     * @param integer $width
     * @return Carte
     */
    public function setWidth($width)
    {
        $this->width = $width;
    
        return $this;
    }

    /**
     * Get width
     *
     * @return integer 
     */
    public function getWidth()
    {
        return $this->width;
    }

    /**
     * Set height
     *
     * @param integer $height
     * @return Carte
     */
    public function setHeight($height)
    {
        $this->height = $height;
    
        return $this;
    }

    /**
     * Get height
     *
     * @return integer 
     */
    public function getHeight()
    {
        return $this->height;
    }
    
    /**
     * Add lieux
     *
     * @param \MairieGestion\PageBundle\Entity\Lieu $lieux
     * @return Carte
     */
    public function addLieux(\MairieGestion\PageBundle\Entity\Lieu $lieux)
    {
        $this->lieux[] = $lieux;
    
        return $this;
    }

    /**
     * Remove lieux
     *
     * @param \MairieGestion\PageBundle\Entity\Lieu $lieux
     */
    public function removeLieux(\MairieGestion\PageBundle\Entity\Lieu $lieux)
    {
        $this->lieux->removeElement($lieux);
    }

    /**
     * Get lieux
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getLieux()
    {
        return $this->lieux;
    }
    
    public function getLieuxActive()
    {
        $lieux = array();
        foreach($this->lieux as $lieu)
            if ($lieu->getActive())
                $lieux[] = $lieu;
        return $lieux;
    }

    /**
     * Set user
     *
     * @param \MairieGestion\UserBundle\Entity\User $user
     * @return Carte
     */
    public function setUser(\MairieGestion\UserBundle\Entity\User $user = null)
    {
        $this->user = $user;
    
        return $this;
    }

    /**
     * Get user
     *
     * @return \MairieGestion\UserBundle\Entity\User 
     */
    public function getUser()
    {
        return $this->user;
    }

    /**
     * Set mairie
     *
     * @param \MairieGestion\MairieBundle\Entity\Mairie $mairie
     * @return Carte
     */
    public function setMairie(\MairieGestion\MairieBundle\Entity\Mairie $mairie = null)
    {
        $this->mairie = $mairie;
    
        return $this;
    }

    /**
     * Get mairie
     *
     * @return \MairieGestion\MairieBundle\Entity\Mairie 
     */
    public function getMairie()
    {
        return $this->mairie;
    }

    /**
     * Add pages
     *
     * @param \MairieGestion\PageBundle\Entity\Page $pages
     * @return Carte
     */
    public function addPage(\MairieGestion\PageBundle\Entity\Page $pages)
    {
        $this->pages[] = $pages;
    
        return $this;
    }

    /**
     * Remove pages
     *
     * @param \MairieGestion\PageBundle\Entity\Page $pages
     */
    public function removePage(\MairieGestion\PageBundle\Entity\Page $pages)
    {
        $this->pages->removeElement($pages);
    }

    /**
     * Get pages
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getPages()
    {
        return $this->pages;
    }
}