<?php

namespace MairieGestion\PageBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * Conseil
 *
 * @ORM\Table()
 * @ORM\Entity(repositoryClass="MairieGestion\PageBundle\Entity\ConseilRepository")
 */
class Conseil
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $id;

    /**
     * @var integer
     *
     * @ORM\Column(name="annee_begin", type="integer")
     * @Assert\NotBlank(message="Veuillez saisir l'année de début")
     */
    private $anneeBegin;

    /**
     * @var integer
     *
     * @ORM\Column(name="annee_end", type="integer", nullable=true)
     */
    private $anneeEnd;

    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\MairieBundle\Entity\Mairie", inversedBy="conseils")
     */
    private $mairie;
    
    /**
     * @ORM\OneToMany(targetEntity="MairieGestion\PageBundle\Entity\ConseilMembre", mappedBy="conseil", cascade={"persist", "remove"})
     */
    private $membres;
    
    /**
     * @ORM\OneToMany(targetEntity="MairieGestion\MainBundle\Entity\Photos", mappedBy="conseil", cascade={"persist", "remove"})
     */
    private $photos;
    
    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\UserBundle\Entity\User", inversedBy="conseils")
     */
    private $user;

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set anneeBegin
     *
     * @param integer $anneeBegin
     * @return Conseil
     */
    public function setAnneeBegin($anneeBegin)
    {
        $this->anneeBegin = $anneeBegin;
    
        return $this;
    }

    /**
     * Get anneeBegin
     *
     * @return integer 
     */
    public function getAnneeBegin()
    {
        return $this->anneeBegin;
    }

    /**
     * Set anneeEnd
     *
     * @param integer $anneeEnd
     * @return Conseil
     */
    public function setAnneeEnd($anneeEnd)
    {
        $this->anneeEnd = $anneeEnd;
    
        return $this;
    }

    /**
     * Get anneeEnd
     *
     * @return integer 
     */
    public function getAnneeEnd()
    {
        return $this->anneeEnd;
    }
    /**
     * Constructor
     */
    public function __construct()
    {
        $this->membres = new \Doctrine\Common\Collections\ArrayCollection();
        $this->photos = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Set mairie
     *
     * @param \MairieGestion\MairieBundle\Entity\Mairie $mairie
     * @return Conseil
     */
    public function setMairie(\MairieGestion\MairieBundle\Entity\Mairie $mairie = null)
    {
        $this->mairie = $mairie;
    
        return $this;
    }

    /**
     * Get mairie
     *
     * @return \MairieGestion\MairieBundle\Entity\Mairie 
     */
    public function getMairie()
    {
        return $this->mairie;
    }

    /**
     * Add membres
     *
     * @param \MairieGestion\PageBundle\Entity\ConseilMembre $membres
     * @return Conseil
     */
    public function addMembre(\MairieGestion\PageBundle\Entity\ConseilMembre $membres)
    {
        $this->membres[] = $membres;
    
        return $this;
    }

    /**
     * Remove membres
     *
     * @param \MairieGestion\PageBundle\Entity\ConseilMembre $membres
     */
    public function removeMembre(\MairieGestion\PageBundle\Entity\ConseilMembre $membres)
    {
        $this->membres->removeElement($membres);
    }

    /**
     * Get membres
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getMembres()
    {
        return $this->membres;
    }

    /**
     * Add photos
     *
     * @param \MairieGestion\MainBundle\Entity\Photos $photos
     * @return Conseil
     */
    public function addPhoto(\MairieGestion\MainBundle\Entity\Photos $photos)
    {
        $this->photos[] = $photos;
    
        return $this;
    }

    /**
     * Remove photos
     *
     * @param \MairieGestion\MainBundle\Entity\Photos $photos
     */
    public function removePhoto(\MairieGestion\MainBundle\Entity\Photos $photos)
    {
        $this->photos->removeElement($photos);
    }

    /**
     * Get photos
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getPhotos()
    {
        return $this->photos;
    }
    
    public function getPhoto()
    {
        return $this->photos?$this->photos[0]:null;
    }

    public function getMaire()
    {
        foreach($this->membres as $membre)
            if ($membre->getStatut()->getId() == 1)
                return $membre;
        return null;
    }
    
    /**
     * Set user
     *
     * @param \MairieGestion\UserBundle\Entity\User $user
     * @return Conseil
     */
    public function setUser(\MairieGestion\UserBundle\Entity\User $user = null)
    {
        $this->user = $user;
    
        return $this;
    }

    /**
     * Get user
     *
     * @return \MairieGestion\UserBundle\Entity\User 
     */
    public function getUser()
    {
        return $this->user;
    }
}