<?php

namespace MairieGestion\PageBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * ConseilMembre
 *
 * @ORM\Table()
 * @ORM\Entity(repositoryClass="MairieGestion\PageBundle\Entity\ConseilMembreRepository")
 */
class ConseilMembre
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $id;

    /**
     * @var string
     *
     * @ORM\Column(name="nom", type="string", length=255)
     * @Assert\NotBlank(message="Veuillez saisir le nom de famille du membre")
     */
    private $nom;

    /**
     * @var string
     *
     * @ORM\Column(name="prenom", type="string", length=255)
     * @Assert\NotBlank(message="Veuillez saisir le prénom du membre")
     */
    private $prenom;

    /**
     * @var string
     *
     * @ORM\Column(name="adresse1", type="text", nullable=true)
     */
    private $adresse1;

    /**
     * @var string
     *
     * @ORM\Column(name="adresse2", type="text", nullable=true)
     */
    private $adresse2;

    /**
     * @var string
     *
     * @ORM\Column(name="adresse3", type="text", nullable=true)
     */
    private $adresse3;

    /**
     * @var string
     *
     * @ORM\Column(name="cp", type="string", length=255, nullable=true)
     */
    private $cp;
    
    /**
     * @var string
     *
     * @ORM\Column(name="ville", type="string", length=255, nullable=true)
     */
    private $ville;

    /**
     * @var string
     *
     * @ORM\Column(name="tel_fixe", type="string", length=255, nullable=true)
     */
    private $telFixe;

    /**
     * @var string
     *
     * @ORM\Column(name="tel_portable", type="string", length=255, nullable=true)
     */
    private $telPortable;

    /**
     * @var string
     *
     * @ORM\Column(name="fax", type="string", length=255, nullable=true)
     */
    private $fax;

    /**
     * @var string
     *
     * @ORM\Column(name="email", type="string", length=255, nullable=true)
     */
    private $email;

    /**
     * @var string
     *
     * @ORM\Column(name="description", type="text", nullable=true)
     */
    private $description;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="date_naissance", type="datetime", nullable=true)
     */
    private $dateNaissance;
    
    /**
     * @var integer
     *
     * @ORM\Column(name="num_adjoint", type="integer", nullable=true)
     */
    private $numAdjoint;
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="active", type="boolean")
     */
    private $active;
    
    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\PageBundle\Entity\ConseilMembreStatut", inversedBy="membres")
     * @ORM\JoinColumn(name="statut_id", referencedColumnName="id", onDelete="CASCADE")
     * @Assert\NotBlank(message="Veuillez indiquer le statut du membre")
     */
    private $statut;
    
    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\MainBundle\Entity\Civilite", inversedBy="membres")
     * @ORM\JoinColumn(name="civilite_id", referencedColumnName="id", onDelete="CASCADE")
     */
    private $civilite;
    
    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\PageBundle\Entity\Conseil", inversedBy="membres")
     * @ORM\JoinColumn(name="conseil_id", referencedColumnName="id", onDelete="CASCADE")
     */
    private $conseil;
    
    /**
     * @ORM\OneToMany(targetEntity="MairieGestion\MainBundle\Entity\Photos", mappedBy="membre", cascade={"persist", "remove"})
     */
    private $photos;

    /**
     * Constructor
     */
    public function __construct()
    {
        $this->active = true;
    }
    
    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set nom
     *
     * @param string $nom
     * @return ConseilMembre
     */
    public function setNom($nom)
    {
        $this->nom = $nom;
    
        return $this;
    }

    /**
     * Get nom
     *
     * @return string 
     */
    public function getNom()
    {
        return $this->nom;
    }

    /**
     * Set prenom
     *
     * @param string $prenom
     * @return ConseilMembre
     */
    public function setPrenom($prenom)
    {
        $this->prenom = $prenom;
    
        return $this;
    }

    /**
     * Get prenom
     *
     * @return string 
     */
    public function getPrenom()
    {
        return $this->prenom;
    }

    /**
     * Set adresse1
     *
     * @param string $adresse1
     * @return ConseilMembre
     */
    public function setAdresse1($adresse1)
    {
        $this->adresse1 = $adresse1;
    
        return $this;
    }

    /**
     * Get adresse1
     *
     * @return string 
     */
    public function getAdresse1()
    {
        return $this->adresse1;
    }

    /**
     * Set adresse2
     *
     * @param string $adresse2
     * @return ConseilMembre
     */
    public function setAdresse2($adresse2)
    {
        $this->adresse2 = $adresse2;
    
        return $this;
    }

    /**
     * Get adresse2
     *
     * @return string 
     */
    public function getAdresse2()
    {
        return $this->adresse2;
    }

    /**
     * Set adresse3
     *
     * @param string $adresse3
     * @return ConseilMembre
     */
    public function setAdresse3($adresse3)
    {
        $this->adresse3 = $adresse3;
    
        return $this;
    }

    /**
     * Get adresse3
     *
     * @return string 
     */
    public function getAdresse3()
    {
        return $this->adresse3;
    }

    /**
     * Set cp
     *
     * @param string $cp
     * @return ConseilMembre
     */
    public function setCp($cp)
    {
        $this->cp = $cp;
    
        return $this;
    }

    /**
     * Get cp
     *
     * @return string 
     */
    public function getCp()
    {
        return $this->cp;
    }

    /**
     * Set telFixe
     *
     * @param string $telFixe
     * @return ConseilMembre
     */
    public function setTelFixe($telFixe)
    {
        $this->telFixe = $telFixe;
    
        return $this;
    }

    /**
     * Get telFixe
     *
     * @return string 
     */
    public function getTelFixe()
    {
        return $this->telFixe;
    }

    /**
     * Set telPortable
     *
     * @param string $telPortable
     * @return ConseilMembre
     */
    public function setTelPortable($telPortable)
    {
        $this->telPortable = $telPortable;
    
        return $this;
    }

    /**
     * Get telPortable
     *
     * @return string 
     */
    public function getTelPortable()
    {
        return $this->telPortable;
    }

    /**
     * Set fax
     *
     * @param string $fax
     * @return ConseilMembre
     */
    public function setFax($fax)
    {
        $this->fax = $fax;
    
        return $this;
    }

    /**
     * Get fax
     *
     * @return string 
     */
    public function getFax()
    {
        return $this->fax;
    }

    /**
     * Set email
     *
     * @param string $email
     * @return ConseilMembre
     */
    public function setEmail($email)
    {
        $this->email = $email;
    
        return $this;
    }

    /**
     * Get email
     *
     * @return string 
     */
    public function getEmail()
    {
        return $this->email;
    }

    /**
     * Set description
     *
     * @param string $description
     * @return ConseilMembre
     */
    public function setDescription($description)
    {
        $this->description = $description;
    
        return $this;
    }

    /**
     * Get description
     *
     * @return string 
     */
    public function getDescription()
    {
        return $this->description;
    }

    /**
     * Set dateNaissance
     *
     * @param \DateTime $dateNaissance
     * @return ConseilMembre
     */
    public function setDateNaissance($dateNaissance)
    {
        $this->dateNaissance = $dateNaissance;
    
        return $this;
    }

    /**
     * Get dateNaissance
     *
     * @return \DateTime 
     */
    public function getDateNaissance()
    {
        return $this->dateNaissance;
    }

    /**
     * Set numAdjoint
     *
     * @param integer $numAdjoint
     * @return ConseilMembre
     */
    public function setNumAdjoint($numAdjoint)
    {
        $this->numAdjoint = $numAdjoint;
    
        return $this;
    }

    /**
     * Get numAdjoint
     *
     * @return integer 
     */
    public function getNumAdjoint()
    {
        return $this->numAdjoint;
    }

    /**
     * Set statut
     *
     * @param \MairieGestion\PageBundle\Entity\ConseilMembreStatut $statut
     * @return ConseilMembre
     */
    public function setStatut(\MairieGestion\PageBundle\Entity\ConseilMembreStatut $statut = null)
    {
        $this->statut = $statut;
    
        return $this;
    }

    /**
     * Get statut
     *
     * @return \MairieGestion\PageBundle\Entity\ConseilMembreStatut 
     */
    public function getStatut()
    {
        return $this->statut;
    }
    
    public function getStatutLibelle()
    {
        return ($this->statut->getId()==2?$this->numAdjoint.($this->numAdjoint==1?($this->civilite->getFeminin()?'ère':'er'):'ème').' ':'').($this->civilite->getFeminin()?$this->statut->getFemininName():$this->statut->getName());
    }
    
    // public function getStatutLibelleLong()
    // {
        // $prefixe = '';
        // if ($this->statut->getId()==1)
            // $prefixe = $this->statut->getCivilite()->getShortName().' le ';
        // return $prefix.($this->statut->getId()==2?$this->numAdjoint.($this->numAdjoint==1?'er':'ème').' ':'').$this->statut->getName();
    // }

    /**
     * Set civilite
     *
     * @param \MairieGestion\MainBundle\Entity\Civilite $civilite
     * @return ConseilMembre
     */
    public function setCivilite(\MairieGestion\MainBundle\Entity\Civilite $civilite = null)
    {
        $this->civilite = $civilite;
    
        return $this;
    }

    /**
     * Get civilite
     *
     * @return \MairieGestion\MainBundle\Entity\Civilite 
     */
    public function getCivilite()
    {
        return $this->civilite;
    }

    /**
     * Set conseil
     *
     * @param \MairieGestion\PageBundle\Entity\Conseil $conseil
     * @return ConseilMembre
     */
    public function setConseil(\MairieGestion\PageBundle\Entity\Conseil $conseil = null)
    {
        $this->conseil = $conseil;
    
        return $this;
    }

    /**
     * Get conseil
     *
     * @return \MairieGestion\PageBundle\Entity\Conseil 
     */
    public function getConseil()
    {
        return $this->conseil;
    }

    /**
     * Set ville
     *
     * @param string $ville
     * @return ConseilMembre
     */
    public function setVille($ville)
    {
        $this->ville = $ville;
    
        return $this;
    }

    /**
     * Get ville
     *
     * @return string 
     */
    public function getVille()
    {
        return $this->ville;
    }

    /**
     * Set active
     *
     * @param boolean $active
     * @return ConseilMembre
     */
    public function setActive($active)
    {
        $this->active = $active;
    
        return $this;
    }

    /**
     * Get active
     *
     * @return boolean 
     */
    public function getActive()
    {
        return $this->active;
    }

    /**
     * Add photos
     *
     * @param \MairieGestion\MainBundle\Entity\Photos $photos
     * @return ConseilMembre
     */
    public function addPhoto(\MairieGestion\MainBundle\Entity\Photos $photos)
    {
        $this->photos[] = $photos;
    
        return $this;
    }

    /**
     * Remove photos
     *
     * @param \MairieGestion\MainBundle\Entity\Photos $photos
     */
    public function removePhoto(\MairieGestion\MainBundle\Entity\Photos $photos)
    {
        $this->photos->removeElement($photos);
    }

    /**
     * Get photos
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getPhotos()
    {
        return $this->photos;
    }
    
    public function getPhoto()
    {
        return $this->photos?$this->photos[0]:null;
    }
}