<?php

namespace MairieGestion\PageBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * Lieu
 *
 * @ORM\Table()
 * @ORM\Entity(repositoryClass="MairieGestion\PageBundle\Entity\LieuRepository")
 */
class Lieu
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $id;

    /**
     * @var string
     *
     * @ORM\Column(name="name", type="string", length=255)
     * @Assert\NotBlank(message="Veuillez saisir un titre du lieu")
     */
    private $name;

    /**
     * @var string
     *
     * @ORM\Column(name="description", type="text", nullable=true)
     */
    private $description;
    
    /**
     * @var string
     *
     * @ORM\Column(name="adresse1", type="text", nullable=true)
     */
    private $adresse1;

    /**
     * @var string
     *
     * @ORM\Column(name="adresse2", type="text", nullable=true)
     */
    private $adresse2;

    /**
     * @var string
     *
     * @ORM\Column(name="cp", type="string", length=255, nullable=true)
     */
    private $cp;
    
    /**
     * @var string
     *
     * @ORM\Column(name="ville", type="string", length=255, nullable=true)
     */
    private $ville;

    /**
     * @var string
     *
     * @ORM\Column(name="tel_fixe", type="string", length=255, nullable=true)
     */
    private $telFixe;

    /**
     * @var string
     *
     * @ORM\Column(name="tel_portable", type="string", length=255, nullable=true)
     */
    private $telPortable;
    
    /**
     * @var string
     *
     * @ORM\Column(name="email", type="string", length=255, nullable=true)
     */
    private $email;
    
    /**
     * @var string
     *
     * @ORM\Column(name="site_internet", type="string", length=255, nullable=true)
     */
    private $site_internet;
    
    /**
     * @var float
     *
     * @ORM\Column(name="latitude", type="float")
     * @Assert\NotBlank(message="Veuillez localiser la latitude à l'aide de la carte de droite")
     */
    private $latitude;

    /**
     * @var float
     *
     * @ORM\Column(name="longitude", type="float")
     * @Assert\NotBlank(message="Veuillez localiser la longitude à l'aide de la carte de droite")
     */
    private $longitude;
    
    /**
     * @var integer
     *
     * @ORM\Column(name="position", type="integer", nullable=true)
     */
    private $position;

    /**
     * @var string $idTemp
     *
     * @ORM\Column(name="idTemp", type="string", length=255, nullable=true)
     */
    private $idTemp;
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="active", type="boolean")
     */
    private $active;
    
    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\PageBundle\Entity\Carte", inversedBy="lieux")
     * @ORM\JoinColumn(name="carte_id", referencedColumnName="id", onDelete="CASCADE")
     */
    private $carte;
    
    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\MairieBundle\Entity\Mairie", inversedBy="lieux")
     */
    private $mairie;
    
    /**
     * Constructor
     */
    public function __construct($mairie)
    {
        $this->active = true;
        $this->mairie = $mairie;
        $this->ville = $mairie->getAdresse()->getCity();
        $this->cp = $mairie->getAdresse()->getCp();
    }
    
    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set name
     *
     * @param string $name
     * @return Lieu
     */
    public function setName($name)
    {
        $this->name = $name;
    
        return $this;
    }

    /**
     * Get name
     *
     * @return string 
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     * Set description
     *
     * @param string $description
     * @return Lieu
     */
    public function setDescription($description)
    {
        $this->description = $description;
    
        return $this;
    }

    /**
     * Get description
     *
     * @return string 
     */
    public function getDescription()
    {
        return $this->description;
    }
    
    public function getDescriptionHtml()
    {
        return str_replace('\'','\\\'',str_replace("\r\n",'<br />',$this->description));
    }

    /**
     * Set latitude
     *
     * @param float $latitude
     * @return Lieu
     */
    public function setLatitude($latitude)
    {
        $this->latitude = $latitude;
    
        return $this;
    }

    /**
     * Get latitude
     *
     * @return float 
     */
    public function getLatitude()
    {
        return $this->latitude;
    }

    /**
     * Set longitude
     *
     * @param float $longitude
     * @return Lieu
     */
    public function setLongitude($longitude)
    {
        $this->longitude = $longitude;
    
        return $this;
    }

    /**
     * Get longitude
     *
     * @return float 
     */
    public function getLongitude()
    {
        return $this->longitude;
    }

    /**
     * Set position
     *
     * @param integer $position
     * @return Lieu
     */
    public function setPosition($position)
    {
        $this->position = $position;
    
        return $this;
    }

    /**
     * Get position
     *
     * @return integer 
     */
    public function getPosition()
    {
        return $this->position;
    }

    /**
     * Set carte
     *
     * @param \MairieGestion\PageBundle\Entity\Carte $carte
     * @return Lieu
     */
    public function setCarte(\MairieGestion\PageBundle\Entity\Carte $carte = null)
    {
        $this->carte = $carte;
    
        return $this;
    }

    /**
     * Get carte
     *
     * @return \MairieGestion\PageBundle\Entity\Carte 
     */
    public function getCarte()
    {
        return $this->carte;
    }

    /**
     * Set idTemp
     *
     * @param string $idTemp
     * @return Lieu
     */
    public function setIdTemp($idTemp)
    {
        $this->idTemp = $idTemp;
    
        return $this;
    }

    /**
     * Get idTemp
     *
     * @return string 
     */
    public function getIdTemp()
    {
        return $this->idTemp;
    }

    /**
     * Set mairie
     *
     * @param \MairieGestion\MairieBundle\Entity\Mairie $mairie
     * @return Lieu
     */
    public function setMairie(\MairieGestion\MairieBundle\Entity\Mairie $mairie = null)
    {
        $this->mairie = $mairie;
    
        return $this;
    }

    /**
     * Get mairie
     *
     * @return \MairieGestion\MairieBundle\Entity\Mairie 
     */
    public function getMairie()
    {
        return $this->mairie;
    }

    /**
     * Set active
     *
     * @param boolean $active
     * @return Lieu
     */
    public function setActive($active)
    {
        $this->active = $active;
    
        return $this;
    }

    /**
     * Get active
     *
     * @return boolean 
     */
    public function getActive()
    {
        return $this->active;
    }

    /**
     * Set adresse1
     *
     * @param string $adresse1
     * @return Lieu
     */
    public function setAdresse1($adresse1)
    {
        $this->adresse1 = $adresse1;
    
        return $this;
    }

    /**
     * Get adresse1
     *
     * @return string 
     */
    public function getAdresse1()
    {
        return $this->adresse1;
    }

    /**
     * Set adresse2
     *
     * @param string $adresse2
     * @return Lieu
     */
    public function setAdresse2($adresse2)
    {
        $this->adresse2 = $adresse2;
    
        return $this;
    }

    /**
     * Get adresse2
     *
     * @return string 
     */
    public function getAdresse2()
    {
        return $this->adresse2;
    }

    /**
     * Set cp
     *
     * @param string $cp
     * @return Lieu
     */
    public function setCp($cp)
    {
        $this->cp = $cp;
    
        return $this;
    }

    /**
     * Get cp
     *
     * @return string 
     */
    public function getCp()
    {
        return $this->cp;
    }

    /**
     * Set ville
     *
     * @param string $ville
     * @return Lieu
     */
    public function setVille($ville)
    {
        $this->ville = $ville;
    
        return $this;
    }

    /**
     * Get ville
     *
     * @return string 
     */
    public function getVille()
    {
        return $this->ville;
    }

    /**
     * Set email
     *
     * @param string $email
     * @return Lieu
     */
    public function setEmail($email)
    {
        $this->email = $email;
    
        return $this;
    }

    /**
     * Get email
     *
     * @return string 
     */
    public function getEmail()
    {
        return $this->email;
    }

    /**
     * Set site_internet
     *
     * @param string $siteInternet
     * @return Lieu
     */
    public function setSiteInternet($siteInternet)
    {
        $this->site_internet = $siteInternet;
    
        return $this;
    }

    /**
     * Get site_internet
     *
     * @return string 
     */
    public function getSiteInternet()
    {
        return $this->site_internet;
    }

    /**
     * Set telFixe
     *
     * @param string $telFixe
     * @return Lieu
     */
    public function setTelFixe($telFixe)
    {
        $this->telFixe = $telFixe;
    
        return $this;
    }

    /**
     * Get telFixe
     *
     * @return string 
     */
    public function getTelFixe()
    {
        return $this->telFixe;
    }

    /**
     * Set telPortable
     *
     * @param string $telPortable
     * @return Lieu
     */
    public function setTelPortable($telPortable)
    {
        $this->telPortable = $telPortable;
    
        return $this;
    }

    /**
     * Get telPortable
     *
     * @return string 
     */
    public function getTelPortable()
    {
        return $this->telPortable;
    }
}