<?php

namespace MairieGestion\PageBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Validator\Constraints as Assert;
use Symfony\Bridge\Doctrine\Validator\Constraints\UniqueEntity;
use Doctrine\ORM\Mapping\OrderBy;

/**
 * Page
 *
 * @ORM\Table()
 * @ORM\Entity(repositoryClass="MairieGestion\PageBundle\Entity\PageRepository")
 * @UniqueEntity(fields={"mairie", "path"})
 */
class Page
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $id;

    /**
     * @var string
     *
     * @ORM\Column(name="name", type="string", length=255)
     * @Assert\NotBlank(message="Veuillez renseigner le nom de la page")
     * @Assert\Length(max=100,min=2)
     */
    private $name;

    /**
     * @var string
     *
     * @ORM\Column(name="path", type="string", length=255, nullable=true)
     */
    private $path;
    
    /**
     * @var string
     *
     * @ORM\Column(name="path_auto", type="string", length=255, nullable=true)
     */
    private $pathAuto;

    /**
     * @var string
     *
     * @ORM\Column(name="content", type="text", nullable=true)
     */
    private $content;

    /**
     * @var string
     *
     * @ORM\Column(name="meta_title", type="string", length=255,nullable=true)
     */
    private $metaTitle;

    /**
     * @var string
     *
     * @ORM\Column(name="meta_keywords", type="text",nullable=true)
     */
    private $metaKeywords;

    /**
     * @var string
     *
     * @ORM\Column(name="meta_description", type="text",nullable=true)
     */
    private $metaDescription;

    /**
     * @var boolean
     *
     * @ORM\Column(name="online", type="boolean")
     */
    private $online;

    /**
     * @var boolean
     *
     * @ORM\Column(name="in_menu", type="boolean")
     */
    private $inMenu;
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="no_index", type="boolean")
     */
    private $noIndex;
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="home", type="boolean",nullable=false)
     */
    private $home;
    
    /**
     * @var integer
     *
     * @ORM\Column(name="position", type="integer", nullable=true)
     */
    private $position;
    
    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\PageBundle\Entity\PageType", inversedBy="pages")
     */
    private $type;
    
    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\PageBundle\Entity\Carte", inversedBy="pages")
     */
    private $carte;
    
    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\PageBundle\Entity\Plu", inversedBy="pages")
     */
    private $plu;

    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\MairieBundle\Entity\Mairie", inversedBy="pages")
     */
    private $mairie;
    
    /**
     * @ORM\OneToMany(targetEntity="MairieGestion\MainBundle\Entity\Photos", mappedBy="page", cascade={"persist", "remove"})
     */
    private $photos;
    
    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\UserBundle\Entity\User", inversedBy="pages")
     */
    private $user;
    
    /**
     * @var integer
     *
     * @ORM\ManyToOne(targetEntity="MairieGestion\PageBundle\Entity\Page", inversedBy="children")
     * @ORM\JoinColumn(name="parent_id", referencedColumnName="id", onDelete="SET NULL")
     */
    private $parent;
 
     
    /**
     * @ORM\OneToMany(targetEntity="MairieGestion\PageBundle\Entity\Page", mappedBy="parent")
     * @ORM\OrderBy({"position" = "ASC"})
     */
    protected $children;

    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set name
     *
     * @param string $name
     * @return Page
     */
    public function setName($name)
    {
        $this->name = $name;
        $this->home = false;
        $this->noIndex = false;
        return $this;
    }

    /**
     * Get name
     *
     * @return string 
     */
    public function getName()
    {
        return $this->name;
    }
    
    /**
     * Get parent name
     *
     * @return string 
     */
    public function getParentName()
    {
        return $this->parent?$this->parent->name:'-';
    }

    /**
     * Set path
     *
     * @param string $path
     * @return Page
     */
    public function setPath($path)
    {
        $this->path = $path;
    
        return $this;
    }

    /**
     * Get path
     *
     * @return string 
     */
    public function getPath()
    {
        return $this->path?$this->path:$this->pathAuto;
    }

    /**
     * Set content
     *
     * @param string $content
     * @return Page
     */
    public function setContent($content)
    {
        $this->content = $content;
    
        return $this;
    }

    /**
     * Get content
     *
     * @return string 
     */
    public function getContent()
    {
        return $this->content;
    }

    /**
     * Set metaTitle
     *
     * @param string $metaTitle
     * @return Page
     */
    public function setMetaTitle($metaTitle)
    {
        $this->metaTitle = $metaTitle;
    
        return $this;
    }

    /**
     * Get metaTitle
     *
     * @return string 
     */
    public function getMetaTitle()
    {
        return $this->metaTitle?$this->metaTitle:$this->name;
    }
    
    public function getMetaTitleFront()
    {
        return $this->metaTitle?$this->metaTitle:$this->name;
    }

    /**
     * Set metaKeywords
     *
     * @param string $metaKeywords
     * @return Page
     */
    public function setMetaKeywords($metaKeywords)
    {
        $this->metaKeywords = $metaKeywords;
    
        return $this;
    }

    /**
     * Get metaKeywords
     *
     * @return string 
     */
    public function getMetaKeywords()
    {
        return $this->metaKeywords;
    }

    /**
     * Set metaDescription
     *
     * @param string $metaDescription
     * @return Page
     */
    public function setMetaDescription($metaDescription)
    {
        $this->metaDescription = $metaDescription;
    
        return $this;
    }

    /**
     * Get metaDescription
     *
     * @return string 
     */
    public function getMetaDescription()
    {
        return $this->metaDescription;
    }

    /**
     * Set online
     *
     * @param boolean $online
     * @return Page
     */
    public function setOnline($online)
    {
        $this->online = $online;
    
        return $this;
    }

    /**
     * Get online
     *
     * @return boolean 
     */
    public function getOnline()
    {
        return $this->online;
    }
    
    public function getOnlineTexte()
    {
        return $this->online?'Oui':'Non';
    }

    /**
     * Set inMenu
     *
     * @param boolean $inMenu
     * @return Page
     */
    public function setInMenu($inMenu)
    {
        $this->inMenu = $inMenu;
    
        return $this;
    }

    /**
     * Get inMenu
     *
     * @return boolean 
     */
    public function getInMenu()
    {
        return $this->inMenu;
    }
    
    public function getInMenuTexte()
    {
        return $this->inMenu?'Oui':'Non';
    }

    /**
     * Set mairie
     *
     * @param \MairieGestion\MairieBundle\Entity\Mairie $mairie
     * @return Page
     */
    public function setMairie(\MairieGestion\MairieBundle\Entity\Mairie $mairie = null)
    {
        $this->mairie = $mairie;
    
        return $this;
    }

    /**
     * Get mairie
     *
     * @return \MairieGestion\MairieBundle\Entity\Mairie 
     */
    public function getMairie()
    {
        return $this->mairie;
    }

    /**
     * Set user
     *
     * @param \MairieGestion\UserBundle\Entity\User $user
     * @return Page
     */
    public function setUser(\MairieGestion\UserBundle\Entity\User $user = null)
    {
        $this->user = $user;
    
        return $this;
    }

    /**
     * Get user
     *
     * @return \MairieGestion\UserBundle\Entity\User 
     */
    public function getUser()
    {
        return $this->user;
    }
    /**
     * Constructor
     */
    public function __construct()
    {
        $this->children = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Set parent
     *
     * @param \MairieGestion\PageBundle\Entity\Page $parent
     * @return Page
     */
    public function setParent(\MairieGestion\PageBundle\Entity\Page $parent = null)
    {
        $this->parent = $parent;
    
        return $this;
    }

    /**
     * Get parent
     *
     * @return \MairieGestion\PageBundle\Entity\Page 
     */
    public function getParent()
    {
        return $this->parent;
    }

    /**
     * Add children
     *
     * @param \MairieGestion\PageBundle\Entity\Page $children
     * @return Page
     */
    public function addChildren(\MairieGestion\PageBundle\Entity\Page $children)
    {
        $this->children[] = $children;
    
        return $this;
    }

    /**
     * Remove children
     *
     * @param \MairieGestion\PageBundle\Entity\Page $children
     */
    public function removeChildren(\MairieGestion\PageBundle\Entity\Page $children)
    {
        $this->children->removeElement($children);
    }

    /**
     * Get children
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getChildren()
    {
        return $this->children;
    }
    
    public function getChildrenMenu()
    {
        $children = array();
        foreach($this->children as $page)
            if (($page->getOnline() || $page->getChildrenMenu()) && $page->getInMenu())
                $children[] = $page;
        return $children;
    }

    /**
     * Set position
     *
     * @param integer $position
     * @return Page
     */
    public function setPosition($position)
    {
        $this->position = $position;
    
        return $this;
    }

    /**
     * Get position
     *
     * @return integer 
     */
    public function getPosition()
    {
        return $this->position;
    }
    
    public function hasFreePosition()
    {
        if ($this->parent)
        {
            $pages = $this->parent->getChildren();
            foreach($pages as $page)
                if ($this->position == $page->getPosition() && $this->id != $page->getId())
                    return false;
        }
        else
        {
            $pages = $this->mairie->getPages();
            foreach($pages as $page)
                if (!$page->getParent() && $this->position == $page->getPosition() && $this->id != $page->getId())
                    return false;
        }
        return true;
    }
    
    public function getFreePosition()
    {
        $max = 1;
        if ($this->parent)
        {
            $pages = $this->parent->getChildren();
            foreach($pages as $page)
                if ($max <= $page->getPosition())
                    $max = $page->getPosition()+1;
        }
        else
        {
            $pages = $this->mairie->getPages();
            foreach($pages as $page)
                if (!$page->getParent() && $max <= $page->getPosition())
                    $max = $page->getPosition()+1;
        }
        return $max;
    }
    
    /**
     * Get level
     *
     * @return integer 
     */
    public function getLevel()
    {
        $level = 0;
        $this->_incrementLevelRecursive($this,$level);
        return $level;
    }
    
    private function _incrementLevelRecursive($page,&$level)
    {
        if ($page->getParent())
        {
            $level++;
            $this->_incrementLevelRecursive($page->getParent(),$level);
        }
    }
    
    public function getNameArborescence()
    {
        $str = '';
        for($i=0;$i<$this->getLevel();$i++)
            $str .= '- ';
        return $str.$this->name;
    }

    /**
     * Set home
     *
     * @param boolean $home
     * @return Page
     */
    public function setHome($home)
    {
        $this->home = $home;
    
        return $this;
    }

    /**
     * Get home
     *
     * @return boolean 
     */
    public function getHome()
    {
        return $this->home;
    }

    /**
     * Set type
     *
     * @param \MairieGestion\PageBundle\Entity\PageType $type
     * @return Page
     */
    public function setType(\MairieGestion\PageBundle\Entity\PageType $type = null)
    {
        $this->type = $type;
    
        return $this;
    }

    /**
     * Get type
     *
     * @return \MairieGestion\PageBundle\Entity\PageType 
     */
    public function getType()
    {
        return $this->type;
    }

    /**
     * Set carte
     *
     * @param \MairieGestion\PageBundle\Entity\Carte $carte
     * @return Page
     */
    public function setCarte(\MairieGestion\PageBundle\Entity\Carte $carte = null)
    {
        $this->carte = $carte;
    
        return $this;
    }

    /**
     * Get carte
     *
     * @return \MairieGestion\PageBundle\Entity\Carte 
     */
    public function getCarte()
    {
        return $this->carte;
    }

    /**
     * Set noIndex
     *
     * @param boolean $noIndex
     * @return Page
     */
    public function setNoIndex($noIndex)
    {
        $this->noIndex = $noIndex;
    
        return $this;
    }

    /**
     * Get noIndex
     *
     * @return boolean 
     */
    public function getNoIndex()
    {
        return $this->noIndex;
    }

    /**
     * Set pathAuto
     *
     * @param string $pathAuto
     * @return Page
     */
    public function setPathAuto($pathAuto)
    {
        $this->pathAuto = $pathAuto;
    
        return $this;
    }

    /**
     * Get pathAuto
     *
     * @return string 
     */
    public function getPathAuto()
    {
        return $this->pathAuto;
    }

    /**
     * Add photos
     *
     * @param \MairieGestion\MainBundle\Entity\Photos $photos
     * @return Page
     */
    public function addPhoto(\MairieGestion\MainBundle\Entity\Photos $photos)
    {
        $this->photos[] = $photos;
    
        return $this;
    }

    /**
     * Remove photos
     *
     * @param \MairieGestion\MainBundle\Entity\Photos $photos
     */
    public function removePhoto(\MairieGestion\MainBundle\Entity\Photos $photos)
    {
        $this->photos->removeElement($photos);
    }

    /**
     * Get photos
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getPhotos()
    {
        $photos = array();
        foreach($this->photos as $photo)
            if ($photo->getTag() != 'pdf_page')
                $photos[] = $photo;
        return $photos;
    }
    
    public function getPdfs()
    {
        $pdfs = array();
        foreach($this->photos as $photo)
            if ($photo->getTag() == 'pdf_page')
                $pdfs[] = $photo;
        return $pdfs;
    }

    /**
     * Set plu
     *
     * @param \MairieGestion\PageBundle\Entity\Plu $plu
     * @return Page
     */
    public function setPlu(\MairieGestion\PageBundle\Entity\Plu $plu = null)
    {
        $this->plu = $plu;
    
        return $this;
    }

    /**
     * Get plu
     *
     * @return \MairieGestion\PageBundle\Entity\Plu 
     */
    public function getPlu()
    {
        return $this->plu;
    }
}