<?php

namespace MairieGestion\PageBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * Plu
 *
 * @ORM\Table()
 * @ORM\Entity(repositoryClass="MairieGestion\PageBundle\Entity\PluRepository")
 */
class Plu
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $id;

    /**
     * @var string
     *
     * @ORM\Column(name="name", type="string", length=255)
     * @Assert\NotBlank(message="Veuillez saisir le titre du PLU")
     */
    private $name;

    /**
     * @var boolean
     *
     * @ORM\Column(name="active", type="boolean")
     */
    private $active;
    
    /**
     * @ORM\OneToMany(targetEntity="MairieGestion\MainBundle\Entity\Photos", mappedBy="plu", cascade={"persist", "remove"})
     */
    private $photos;
    
    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\UserBundle\Entity\User", inversedBy="cartes")
     */
    private $user;
    
    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\MairieBundle\Entity\Mairie", inversedBy="plus")
     */
    private $mairie;
    
    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set name
     *
     * @param string $name
     * @return Plu
     */
    public function setName($name)
    {
        $this->name = $name;
    
        return $this;
    }

    /**
     * Get name
     *
     * @return string 
     */
    public function getName()
    {
        return $this->name;
    }
    
    /**
     * @ORM\OneToMany(targetEntity="MairieGestion\PageBundle\Entity\Page", mappedBy="plu")
     */
    private $pages;
    
    /**
     * Constructor
     */
    public function __construct()
    {
        $this->photos = new \Doctrine\Common\Collections\ArrayCollection();
        $this->active = true;
    }
    
    /**
     * Add photos
     *
     * @param \MairieGestion\MainBundle\Entity\Photos $photos
     * @return Plu
     */
    public function addPhoto(\MairieGestion\MainBundle\Entity\Photos $photos)
    {
        $this->photos[] = $photos;
    
        return $this;
    }

    /**
     * Remove photos
     *
     * @param \MairieGestion\MainBundle\Entity\Photos $photos
     */
    public function removePhoto(\MairieGestion\MainBundle\Entity\Photos $photos)
    {
        $this->photos->removeElement($photos);
    }

    /**
     * Get photos
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getPhotos()
    {
        return $this->photos;
    }

    public function getPhoto()
    {
        return $this->photos?$this->photos[0]:null;
    }
    
    /**
     * Set active
     *
     * @param boolean $active
     * @return Plu
     */
    public function setActive($active)
    {
        $this->active = $active;
    
        return $this;
    }

    /**
     * Get active
     *
     * @return boolean 
     */
    public function getActive()
    {
        return $this->active;
    }

    /**
     * Set user
     *
     * @param \MairieGestion\UserBundle\Entity\User $user
     * @return Plu
     */
    public function setUser(\MairieGestion\UserBundle\Entity\User $user = null)
    {
        $this->user = $user;
    
        return $this;
    }

    /**
     * Get user
     *
     * @return \MairieGestion\UserBundle\Entity\User 
     */
    public function getUser()
    {
        return $this->user;
    }

    /**
     * Set mairie
     *
     * @param \MairieGestion\MairieBundle\Entity\Mairie $mairie
     * @return Plu
     */
    public function setMairie(\MairieGestion\MairieBundle\Entity\Mairie $mairie = null)
    {
        $this->mairie = $mairie;
    
        return $this;
    }

    /**
     * Get mairie
     *
     * @return \MairieGestion\MairieBundle\Entity\Mairie 
     */
    public function getMairie()
    {
        return $this->mairie;
    }

    /**
     * Add pages
     *
     * @param \MairieGestion\PageBundle\Entity\Page $pages
     * @return Plu
     */
    public function addPage(\MairieGestion\PageBundle\Entity\Page $pages)
    {
        $this->pages[] = $pages;
    
        return $this;
    }

    /**
     * Remove pages
     *
     * @param \MairieGestion\PageBundle\Entity\Page $pages
     */
    public function removePage(\MairieGestion\PageBundle\Entity\Page $pages)
    {
        $this->pages->removeElement($pages);
    }

    /**
     * Get pages
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getPages()
    {
        return $this->pages;
    }
}