<?php

namespace MairieGestion\PageBundle\Form;

use Doctrine\ORM\EntityRepository;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;

class PageType extends AbstractType
{
	private $obj;
    
    public function __construct($mairie,$obj,$em)
    {
        $this->mairie = $mairie;
        $this->obj = $obj;
        $this->em = $em;
    }
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $pages = $this->em->getRepository('MairieGestionPageBundle:Page')->getPotentialPages($this->mairie, $this->obj);
        $page_types = $this->em->getRepository('MairieGestionPageBundle:PageType')->getPageTypes();
        $cartes = $this->em->getRepository('MairieGestionPageBundle:Carte')->getCartes($this->mairie);
        $plus = $this->em->getRepository('MairieGestionPageBundle:Plu')->getPlusFront($this->mairie);
        
        $builder
            ->add('name', 'text', array(
                'label' => 'Titre de la page',
                'attr' => array('class'=>'form-control'),
            ))
            ->add('path', 'text', array(
                'label' => 'Adresse de la page (URL)',
                'attr' => array('class'=>'form-control'),
            ))
            ->add('type', 'entity', array(
                'label' => 'Type de page',
                'class' => 'MairieGestionPageBundle:PageType',
                'property' => 'name',
                'choices' => $page_types,
                'attr' => array('class'=>'form-control')
            ))
            ->add('parent', 'entity', array(
                'label' => 'Page parent',
                'class' => 'MairieGestionPageBundle:Page',
                'property' => 'nameArborescence',
                'choices' => $pages,
                'attr' => array('class'=>'form-control')
            ))
            ->add('content', 'textarea', array('label' => 'Contenu','attr'=>array('class'=>'wiziwig'),))
            ->add('meta_title', 'text', array('label' => 'Titre de référencement de la page (Meta title)','attr' => array('class'=>'form-control')))
            ->add('meta_description', 'textarea', array('label' => 'Description au référencement de la page (Meta description)','attr' => array('class'=>'form-control')))
            ->add('carte', 'entity', array(
                'label' => 'Carte',
                'class' => 'MairieGestionPageBundle:Carte',
                'property' => 'name',
                'choices' => $cartes,
                'attr' => array('class'=>'form-control')
            ))
            ->add('plu', 'entity', array(
                'label' => 'P.L.U',
                'class' => 'MairieGestionPageBundle:Plu',
                'property' => 'name',
                'choices' => $plus,
                'attr' => array('class'=>'form-control')
            ))
            ->add('online', 'checkbox', array(
                'label' => 'Page accessible',
            ))
            ->add('in_menu', 'checkbox', array(
                'label' => 'Visible dans le menu',
            ))
            ->add('meta_keywords', 'textarea', array('label' => 'Mots clés (Meta keywords)','attr' => array('class'=>'form-control')))
            ->add('no_index', 'checkbox', array(
                'label' => 'Référencé par Google',
                'data' => true,
            ))
            ->add('Valider', 'submit',array(
                'attr'=> array('class'=>'btn', 'formnovalidate'=>true)
            ))
        ;
    }

    public function getName()
    {
        return 'pagetype';
    }
    
    public function getDefaultOptions(array $options)
    {
        return array(
            'data_class' => 'MairieGestion\PageBundle\Entity\Page',
        );
    }
}
