<?php

namespace MairieGestion\PlanningBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;

use MairieGestion\PlanningBundle\Util\DateTools;

use MairieGestion\PlanningBundle\Entity\Event;
use MairieGestion\PlanningBundle\Form\EventType;
use MairieGestion\PlanningBundle\Entity\CategoryEvent;
use MairieGestion\PlanningBundle\Form\CategoryEventType;
// use Zend\library\Zend\Gdata;

class DefaultController extends Controller
{
    public function checkEvent($event)
    {
        $base_url = $this->getRequest()->getUriForPath('');
        $em = $this->getDoctrine()->getManager();
        $mairie = $em->getRepository('MairieGestionMairieBundle:Mairie')->getMairieByDomaine($base_url);
        if ($mairie != $event->getMairie() && $event->getMairie())
            throw new \Symfony\Component\Security\Core\Exception\AccessDeniedException ();
    }
    
    /**
     * @Route("/admin/agenda/liste", name="planning_liste")
     * @Template()
     */
    public function listePlanningAction($filter='actifs')
    {
        $em = $this->getDoctrine()->getManager();
        $user = $this->container->get('security.context')->getToken()->getUser();
        $events = $em->getRepository('MairieGestionPlanningBundle:Event')->getEventsFilter($user,$filter);

        $filters = array(
            'tous'=> 'Tous',
            'actifs'=> 'Actifs',
            'inactifs'=> 'Inactifs',
        );
        return $this->render('MairieGestionPlanningBundle:Default:listePlanning.html.twig', array(
            'events'=>$events,
            'filter'=>$filter,
            'filters'=>$filters,
        ));
    }
    
    /**
     * @Route("/admin/agenda/semaine", requirements={"year" = "\d+"}, name="planning_semaine")
     * @Template()
     */
    public function showSemaineAction($filter='actifs')
    {
        return $this->showSemaineDateAction($filter,date('Y'),date('W'));
    }
    
    /**
     * @Route("/admin/agenda/semaine/{year}/{week}", requirements={"year" = "\d+"}, name="planning_semaine_date")
     * @Template()
     */
    public function showSemaineDateAction($filter='actifs',$year,$week)
    {
        $em = $this->getDoctrine()->getManager();
        $user = $this->container->get('security.context')->getToken()->getUser();
        $events = $em->getRepository('MairieGestionPlanningBundle:Event')->getEventsFilter($user,$filter);
        $planning = $em->getRepository('MairieGestionPlanningBundle:Event')->getFormatedEventsSemaine($events,$year,$week);
        $dateTools = new DateTools();
        $dates = $dateTools->getDatesBySemaine($year,$week);

        $filters = array(
            'tous'=> 'Tous',
            'actifs'=> 'Actifs',
            'inactifs'=> 'Inactifs',
        );
        return $this->render('MairieGestionPlanningBundle:Default:showSemaine.html.twig', array(
            'begin' => $dates['begin'],
            'end' => $dates['end'],
            'year'=>$year,
            'week'=>$week,
            'planning'=>$planning,
            'events'=>$events,
            'filter'=>$filter,
            'filters'=>$filters,
        ));
    }
    
    /**
     * @Route("/admin/agenda/nouveau", name="planning_new")
     * @Template()
     */
    public function newEventAction($id=null)
    {
        $user = $this->container->get('security.context')->getToken()->getUser();
        $mairie = $user->getMairie();
        $em = $this->getDoctrine()->getManager();
        if ($id && (is_numeric($id) || strlen($id) != 13))
            $event = $em->getRepository('MairieGestionPlanningBundle:Event')->find($id);
        else
            $event = new Event();
        $this->checkEvent($event);
        $form       = $this->createForm(new EventType($event), $event);
        
        $request = $this->getRequest();
        
        if ($request->getMethod() == 'POST') {
            $form->bind($request);
            if(($id && !is_numeric($id) && strlen($id) == 13) || $request->get('id_temp'))
            {
                $photos = $em->getRepository('MairieGestionMainBundle:Photos')->getPhotosByIdTemp($request->get('id_temp'));
                foreach($photos as $photo)
                    $photo->setEvent($event);
            }
            if($form->isValid()) {
                if (!$id)
                {
                    $event->setUser($user);
                    $event->setMairie($mairie);
                }
                if (!$event->getId())
                {
                    $photos = $em->getRepository('MairieGestionMainBundle:Photos')->getPhotosByIdTemp($request->get('id_temp'));
                    foreach($photos as $photo)
                    {
                        $photo->setIdTemp(null);
                        $em->persist($photo);
                        $photo->setEvent($event);
                    }
                }
                $em->persist($event);
                $em->flush();

                return $this->redirect($this->generateUrl('planning_liste'));
           }
        }
        
        return $this->render('MairieGestionPlanningBundle:Default:newEvent.html.twig', array(
            'uniqid' => $request->get('id_temp')?$request->get('id_temp'):uniqid(),
            'event'    => $event,
            'form'       => $form->createView(),
            'type'       => 'new',
        ));
    }
    
    /**
     * @Route("/admin/agenda/categorie/nouveau", name="planning_category_new")
     * @Template()
     */
    public function newCategoryAction($id=null)
    {
        $user = $this->container->get('security.context')->getToken()->getUser();
        $em = $this->getDoctrine()->getManager();
        if ($id)
            $category = $em->getRepository('MairieGestionPlanningBundle:CategoryEvent')->find($id);
        else
            $category = new CategoryEvent();
        $form       = $this->createForm(new CategoryEventType($category), $category);
        
        $request = $this->getRequest();
        
        if ($request->getMethod() == 'POST') {
            $form       = $this->createForm(new CategoryEventType($category), $category);
            $form->bind($request);
            
            
            
            if($form->isValid() && isset($category->getCodeColors()[$category->getColor()])) {
                if (!$id)
                    $category->setUser($user);
                $em->persist($category);
                $em->flush();
                return $this->redirect($this->generateUrl('planning_liste'));
           }
        }
        
        return $this->render('MairieGestionPlanningBundle:Default:newCategory.html.twig', array(
            'category'    => $category,
            'form'       => $form->createView(),
            'type'       => 'new',
        ));
    }
    
    /**
     * @Route("/admin/agenda/modification/{id}", name="planning_edit")
     * @Template()
     */
    public function editEventAction($id)
    {
        return $this->newEventAction($id);
    }
    
    /**
     * @Route("/admin/agenda/delete/{id}", name="planning_delete")
     * @Template()
     */
    public function deletePlanningAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $event = $em->getRepository('MairieGestionPlanningBundle:Event')->find($id);
        $this->checkEvent($event);
        $em->remove($event);
        $em->flush();
        return $this->redirect($this->generateUrl('planning_liste'));
    }
}
