<?php

namespace MairieGestion\PlanningBundle\Entity;

use Doctrine\ORM\Mapping as ORM;

/**
 * CategoryEvent
 *
 * @ORM\Table()
 * @ORM\Entity(repositoryClass="MairieGestion\PlanningBundle\Entity\CategoryEventRepository")
 */
class CategoryEvent
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $id;

    /**
     * @var string
     *
     * @ORM\Column(name="name", type="string", length=255)
     */
    private $name;
    
    /**
     * @var string
     *
     * @ORM\Column(name="color", type="string", length=7)
     */
    private $color; 

    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\UserBundle\Entity\User", inversedBy="event_categories")
     */
    private $user;
    
    /**
     * @ORM\OneToMany(targetEntity="MairieGestion\PlanningBundle\Entity\Event", mappedBy="category")
     */
    private $events;
    
    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set name
     *
     * @param string $name
     * @return CategoryEvent
     */
    public function setName($name)
    {
        $this->name = $name;
    
        return $this;
    }

    /**
     * Get name
     *
     * @return string 
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     * Set user
     *
     * @param \MairieGestion\UserBundle\Entity\User $user
     * @return CategoryEvent
     */
    public function setUser(\MairieGestion\UserBundle\Entity\User $user = null)
    {
        $this->user = $user;
    
        return $this;
    }

    /**
     * Get user
     *
     * @return \MairieGestion\UserBundle\Entity\User 
     */
    public function getUser()
    {
        return $this->user;
    }
    /**
     * Constructor
     */
    public function __construct()
    {
        $this->events = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    /**
     * Set color
     *
     * @param string $color
     * @return CategoryEvent
     */
    public function setColor($color)
    {
        $this->color = $color;
    
        return $this;
    }

    /**
     * Get color
     *
     * @return string 
     */
    public function getColor()
    {
        return $this->color;
    }

    /**
     * Add events
     *
     * @param \MairieGestion\PlanningBundle\Entity\Event $events
     * @return CategoryEvent
     */
    public function addEvent(\MairieGestion\PlanningBundle\Entity\Event $events)
    {
        $this->events[] = $events;
    
        return $this;
    }

    /**
     * Remove events
     *
     * @param \MairieGestion\PlanningBundle\Entity\Event $events
     */
    public function removeEvent(\MairieGestion\PlanningBundle\Entity\Event $events)
    {
        $this->events->removeElement($events);
    }

    /**
     * Get events
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getEvents()
    {
        return $this->events;
    }
    
    public function getCodeColors()
    {
        return array(
            'vert'=>'#99ff99', //vert
            'rouge'=>'#ff9999', //rouge
            'bleu'=>'#9999ff', //bleu
        );
    }
    
    public function getCodeColor()
    {
        if (isset($this->getCodeColors()[$this->color]))
            return $this->getCodeColors()[$this->color];
        else
            return '';
    }
}