<?php

namespace MairieGestion\PlanningBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * Event
 *
 * @ORM\Table()
 * @ORM\Entity(repositoryClass="MairieGestion\PlanningBundle\Entity\EventRepository")
 */
class Event
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $id;

    /**
     * @var string
     *
     * @ORM\Column(name="title", type="string", length=255)
     */
    private $title;
    
    /**
     * @var string
     *
     * @ORM\Column(name="url", type="string", length=255, nullable=true)
     */
    private $url;

    /**
     * @var string
     *
     * @ORM\Column(name="description", type="text")
     */
    private $description;
    
    /**
     * @var string
     *
     * @ORM\Column(name="lieu", type="string", length=255)
     */
    private $lieu;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="date_begin", type="datetime")
     */
    private $dateBegin;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="date_end", type="datetime")
     */
    private $dateEnd;
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="active", type="boolean")
     */
    private $active;
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="public", type="boolean")
     */
    private $public;

    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\PlanningBundle\Entity\CategoryEvent", inversedBy="events")
     */
    private $category;
    
    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\UserBundle\Entity\User", inversedBy="events")
     */
    private $user;
    
    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\MainBundle\Entity\Adresse")
     */
    private $adresse;
    
    /**
     * @var boolean
     *
     * @ORM\Column(name="home", type="boolean", nullable=false)
     * @Assert\NotNull()
     */
    private $home;
    
    /**
     * @ORM\OneToMany(targetEntity="MairieGestion\MainBundle\Entity\Photos", mappedBy="event", cascade={"persist", "remove"})
     */
    private $photos;
    
    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\MairieBundle\Entity\Mairie", inversedBy="events")
     */
    private $mairie;
    
    public function __construct()
    {
        $this->active = 1;
        $this->dateBegin = new \DateTime('now');
        $this->dateEnd = new \DateTime('now +1 hour');
    }
    
    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set title
     *
     * @param string $title
     * @return Event
     */
    public function setTitle($title)
    {
        $this->title = $title;
    
        return $this;
    }

    /**
     * Get title
     *
     * @return string 
     */
    public function getTitle()
    {
        return $this->title;
    }

    /**
     * Set description
     *
     * @param string $description
     * @return Event
     */
    public function setDescription($description)
    {
        $this->description = $description;
    
        return $this;
    }

    /**
     * Get description
     *
     * @return string 
     */
    public function getDescription()
    {
        return $this->description;
    }
    
    public function getDescriptionHtml()
    {
        return rawurlencode(str_replace('\'','\\\'',str_replace("\t",'&nbsp;&nbsp;&nbsp;&nbsp;',str_replace("\r\n",'<br />',$this->description))));
    }

    /**
     * Set dateBegin
     *
     * @param \DateTime $dateBegin
     * @return Event
     */
    public function setDateBegin($dateBegin)
    {
        $this->dateBegin = $dateBegin;
    
        return $this;
    }

    /**
     * Get dateBegin
     *
     * @return \DateTime 
     */
    public function getDateBegin()
    {
        return $this->dateBegin;
    }

    /**
     * Set dateEnd
     *
     * @param \DateTime $dateEnd
     * @return Event
     */
    public function setDateEnd($dateEnd)
    {
        $this->dateEnd = $dateEnd;
    
        return $this;
    }

    /**
     * Get dateEnd
     *
     * @return \DateTime 
     */
    public function getDateEnd()
    {
        return $this->dateEnd;
    }
    
    public function getDateEndFront()
    {
        // var_dump($this->dateEnd->modify('+1 day'));
        return $this->dateEnd->modify('+1 day');
    }

    /**
     * Set category
     *
     * @param \MairieGestion\PlanningBundle\Entity\CategoryEvent $category
     * @return Event
     */
    public function setCategory(\MairieGestion\PlanningBundle\Entity\CategoryEvent $category = null)
    {
        $this->category = $category;
    
        return $this;
    }

    /**
     * Get category
     *
     * @return \MairieGestion\PlanningBundle\Entity\CategoryEvent 
     */
    public function getCategory()
    {
        return $this->category;
    }

    /**
     * Set user
     *
     * @param \MairieGestion\UserBundle\Entity\User $user
     * @return Event
     */
    public function setUser(\MairieGestion\UserBundle\Entity\User $user = null)
    {
        $this->user = $user;
    
        return $this;
    }

    /**
     * Get user
     *
     * @return \MairieGestion\UserBundle\Entity\User 
     */
    public function getUser()
    {
        return $this->user;
    }

    /**
     * Set adresse
     *
     * @param \MairieGestion\MainBundle\Entity\Adresse $adresse
     * @return Event
     */
    public function setAdresse(\MairieGestion\MainBundle\Entity\Adresse $adresse = null)
    {
        $this->adresse = $adresse;
    
        return $this;
    }

    /**
     * Get adresse
     *
     * @return \MairieGestion\MainBundle\Entity\Adresse 
     */
    public function getAdresse()
    {
        return $this->adresse;
    }

    /**
     * Set lieu
     *
     * @param string $lieu
     * @return Event
     */
    public function setLieu($lieu)
    {
        $this->lieu = $lieu;
    
        return $this;
    }

    /**
     * Get lieu
     *
     * @return string 
     */
    public function getLieu()
    {
        return $this->lieu;
    }

    /**
     * Set active
     *
     * @param boolean $active
     * @return Event
     */
    public function setActive($active)
    {
        $this->active = $active;
    
        return $this;
    }

    /**
     * Get active
     *
     * @return boolean 
     */
    public function getActive()
    {
        return $this->active;
    }

    /**
     * Set home
     *
     * @param boolean $home
     * @return Event
     */
    public function setHome($home)
    {
        $this->home = $home;
    
        return $this;
    }

    /**
     * Get home
     *
     * @return boolean 
     */
    public function getHome()
    {
        return $this->home;
    }

    /**
     * Add photos
     *
     * @param \MairieGestion\MainBundle\Entity\Photos $photos
     * @return Event
     */
    public function addPhoto(\MairieGestion\MainBundle\Entity\Photos $photos)
    {
        $this->photos[] = $photos;
    
        return $this;
    }

    /**
     * Remove photos
     *
     * @param \MairieGestion\MainBundle\Entity\Photos $photos
     */
    public function removePhoto(\MairieGestion\MainBundle\Entity\Photos $photos)
    {
        $this->photos->removeElement($photos);
    }

    /**
     * Get photos
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getPhotos()
    {
        return $this->photos;
    }
    
    public function getPhoto()
    {
        return count($this->photos)?$this->photos[0]:null;
    }
    
    public function getImagePath()
    {
        return count($this->photos)?$this->photos[0]->getPath():'/bundles/mairiegestionplanning/images/eventDafault.jpg';
    }
    
    public function getImageThumb()
    {
        return count($this->photos)?$this->photos[0]->getThumb1():'/bundles/mairiegestionplanning/images/eventDefaultThumb.png';
    }

    /**
     * Set mairie
     *
     * @param \MairieGestion\MairieBundle\Entity\Mairie $mairie
     * @return Event
     */
    public function setMairie(\MairieGestion\MairieBundle\Entity\Mairie $mairie = null)
    {
        $this->mairie = $mairie;
    
        return $this;
    }

    /**
     * Get mairie
     *
     * @return \MairieGestion\MairieBundle\Entity\Mairie 
     */
    public function getMairie()
    {
        return $this->mairie;
    }

    /**
     * Set url
     *
     * @param string $url
     * @return Event
     */
    public function setUrl($url)
    {
        $this->url = $url;
    
        return $this;
    }

    /**
     * Get url
     *
     * @return string 
     */
    public function getUrl()
    {
        return $this->url;
    }
    
    public function getFrontUrl()
    {
        return 'http://'.str_replace('http://','',$this->url);
    }

    public function isExternUrl()
    {
        return str_replace($this->mairie->getDomaine(),'',$this->url)==$this->url?true:false;
    }
    
    /**
     * Set public
     *
     * @param boolean $public
     * @return Event
     */
    public function setPublic($public)
    {
        $this->public = $public;
    
        return $this;
    }

    /**
     * Get public
     *
     * @return boolean 
     */
    public function getPublic()
    {
        return $this->public;
    }
}