<?php

namespace MairieGestion\UserBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;

use MairieGestion\UserBundle\Entity\User;
use MairieGestion\UserBundle\Form\UserType;
use MairieGestion\UserBundle\Form\PersonnelType;
class DefaultController extends Controller
{
    public function checkUser($user)
    {
        $base_url = $this->getRequest()->getUriForPath('');
        $em = $this->getDoctrine()->getManager();
        $mairie = $em->getRepository('MairieGestionMairieBundle:Mairie')->getMairieByDomaine($base_url);
        if ($mairie != $user->getMairie() && $user->getMairie())
            throw new \Symfony\Component\Security\Core\Exception\AccessDeniedException ();
    }
    
    /**
     * @Route("/admin/personnel/liste/{filter}", name="param_user_liste")
     * @Template()
     */
    public function listeUserAction($filter='actifs')
    {
        $em = $this->getDoctrine()->getManager();
        $user = $this->container->get('security.context')->getToken()->getUser();
        $users = $em->getRepository('MairieGestionUserBundle:User')->getUsersFilter($user,$filter);
        $filters = array(
            'tous'=> 'Tous',
            'actifs'=> 'Actifs',
            'inactifs'=> 'Inactifs',
        );
        return array(
            'users'=>$users,
            'filter'=>$filter,
            'filters'=>$filters,
        );
    }
    
    /**
     * @Route("/admin/personnel/nouveau/", name="param_user_new")
     * @Template()
     */
    public function newUserAction($id=null)
    {
        $user_current = $this->container->get('security.context')->getToken()->getUser();
        $em = $this->getDoctrine()->getEntityManager();
        if ($id)
            $user = $em->getRepository('MairieGestionUserBundle:User')->find($id);
        else
            $user = new User();
        $this->checkUser($user);
        $form = $this->createForm(new PersonnelType($user), $user);
        $request = $this->getRequest();
        
        if ($request->getMethod() == 'POST') {
            $form       = $this->createForm(new PersonnelType($user), $user);
            $form->bind($request);
            if($form->isValid()) {
                if (!$id)
                {
                    $user->setMairie($user_current->getMairie());
                    $user->setRoles(array('ROLE_USER'));
                    if (!$user->getPlainPassword())
                        $user->setPlainPassword($user->getPassword());
                }
                $em->persist($user);
                $em->flush();
                return $this->redirect($this->generateUrl('param_user_liste'));
           }
        }
        
        return $this->render('MairieGestionUserBundle:Default:newUser.html.twig', array(
            'user'    => $user,
            'form'       => $form->createView(),
            'type'       => 'new',
        ));
    }
    
    /**
     * @Route("/admin/personnel/modification/{id}", name="param_user_edit")
     * @Template()
     */
    public function editUserAction($id)
    {
        return $this->newUserAction($id);
    }
    
    /**
     * @Route("/admin/personnel/delete/{id}", name="param_user_delete")
     * @Template()
     */
    public function deleteUserAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $user = $em->getRepository('MairieGestionUserBundle:User')->find($id);
        $this->checkUser($user);
        $em->remove($user);
        $em->flush();
        return $this->redirect($this->generateUrl('param_user_liste'));
    }
    
    /**
     * @Route("/admin/personnel/desactive/{id}", name="param_user_desactive")
     * @Template()
     */
    public function desactiveUserAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $user = $em->getRepository('MairieGestionUserBundle:User')->find($id);
        $this->checkUser($user);
        $user->setEnabled(0);
        $em->flush();
        return $this->redirect($this->generateUrl('param_user_liste'));
    }
    
    /**
     * @Route("/admin/personnel/active/{id}", name="param_user_active")
     * @Template()
     */
    public function activeUserAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $user = $em->getRepository('MairieGestionUserBundle:User')->find($id);
        $this->checkUser($user);
        $user->setEnabled(1);
        $em->flush();
        return $this->redirect($this->generateUrl('param_user_liste'));
    }
}
