<?php

namespace MairieGestion\UserBundle\Entity;

use Doctrine\ORM\Mapping as ORM;
use FOS\UserBundle\Model\User as BaseUser;
use Symfony\Component\Validator\Constraints as Assert;
use Symfony\Bridge\Doctrine\Validator\Constraints\UniqueEntity;

/**
 * User
 *
 * @ORM\Table()
 * @UniqueEntity(fields={"email"}, message="email.alreadyTaken.error")
 * @ORM\Entity(repositoryClass="MairieGestion\UserBundle\Entity\UserRepository")
 */
class User extends BaseUser
{
    /**
     * @var integer
     *
     * @ORM\Column(name="id", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    protected $id;

    /**
     * @var string
     *
     * @ORM\Column(name="name", type="string", length=255, nullable=true)
     */
    private $name;

    /**
     * @var string
     *
     * @ORM\Column(name="first_name", type="string", length=255, nullable=true)
     */
    private $firstName;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="birthday", type="datetime", nullable=true)
     */
    private $birthday;

    /**
     * @var boolean
     *
     * @ORM\Column(name="sexe", type="boolean", nullable=true)
     */
    private $sexe;
    
    /**
     * @var \DateTime
     *
     * @ORM\Column(name="created_at", type="datetime")
     */
    private $createdAt;
    
        /**
     * @var string
     *
     * @ORM\Column(name="tel_fixe", type="string", length=255, nullable=true)
     */
    private $telFixe;

    /**
     * @var string
     *
     * @ORM\Column(name="tel_portable", type="string", length=255, nullable=true)
     */
    private $telPortable;
    
    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\MairieBundle\Entity\Mairie", inversedBy="users")
     */
    private $mairie;
    
    /**
     * @ORM\OneToMany(targetEntity="MairieGestion\PageBundle\Entity\Page", mappedBy="user")
     */
    private $pages;
    
    /**
     * @ORM\OneToMany(targetEntity="MairieGestion\PageBundle\Entity\Album", mappedBy="user")
     */
    private $albums;

    /**
     * @ORM\OneToMany(targetEntity="MairieGestion\PageBundle\Entity\Carte", mappedBy="user")
     */
    private $cartes;
    
    /**
     * @ORM\OneToMany(targetEntity="MairieGestion\PageBundle\Entity\Plu", mappedBy="user")
     */
    private $plus;
    
    /**
     * @ORM\OneToMany(targetEntity="MairieGestion\PageBundle\Entity\Conseil", mappedBy="user")
     */
    private $conseils;
    
    /**
     * @ORM\OneToMany(targetEntity="MairieGestion\PageBundle\Entity\Archive", mappedBy="user")
     */
    private $archives;
    
    /**
     * @ORM\ManyToOne(targetEntity="MairieGestion\MainBundle\Entity\Adresse", cascade={"persist"})
     */
    private $adresse;
    
    public function __construct()
    {
        parent::__construct();
        $this->enabled = 1;
        $this->createdAt = new \DateTime('now');
        $this->username = uniqid();
    }
    
    /**
     * Get id
     *
     * @return integer 
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set mairie
     *
     * @param \MairieGestion\MairieBundle\Entity\Mairie $autoEcole
     * @return User
     */
    public function setMairie(\MairieGestion\MairieBundle\Entity\Mairie $autoEcole = null)
    {
        $this->mairie = $autoEcole;
    
        return $this;
    }

    /**
     * Get mairie
     *
     * @return \MairieGestion\MairieBundle\Entity\Mairie 
     */
    public function getMairie()
    {
        return $this->mairie;
    }

    /**
     * Set name
     *
     * @param string $name
     * @return User
     */
    public function setName($name)
    {
        $this->name = $name;
    
        return $this;
    }

    /**
     * Get name
     *
     * @return string 
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     * Set firstName
     *
     * @param string $firstName
     * @return User
     */
    public function setFirstName($firstName)
    {
        $this->firstName = $firstName;
    
        return $this;
    }

    /**
     * Get firstName
     *
     * @return string 
     */
    public function getFirstName()
    {
        return $this->firstName;
    }

    /**
     * Set birthday
     *
     * @param \DateTime $birthday
     * @return User
     */
    public function setBirthday($birthday)
    {
        $this->birthday = $birthday;
    
        return $this;
    }

    /**
     * Get birthday
     *
     * @return \DateTime 
     */
    public function getBirthday()
    {
        return $this->birthday;
    }

    /**
     * Set sexe
     *
     * @param boolean $sexe
     * @return User
     */
    public function setSexe($sexe)
    {
        $this->sexe = $sexe;
    
        return $this;
    }

    /**
     * Get sexe
     *
     * @return boolean 
     */
    public function getSexe()
    {
        return $this->sexe;
    }

    /**
     * Set createdAt
     *
     * @param \DateTime $createdAt
     * @return User
     */
    public function setCreatedAt($createdAt)
    {
        $this->createdAt = $createdAt;
    
        return $this;
    }

    /**
     * Get createdAt
     *
     * @return \DateTime 
     */
    public function getCreatedAt()
    {
        return $this->createdAt;
    }

    /**
     * Set adresse
     *
     * @param \MairieGestion\MainBundle\Entity\Adresse $adresse
     * @return User
     */
    public function setAdresse(\MairieGestion\MainBundle\Entity\Adresse $adresse = null)
    {
        $this->adresse = $adresse;
    
        return $this;
    }

    /**
     * Get adresse
     *
     * @return \MairieGestion\MainBundle\Entity\Adresse 
     */
    public function getAdresse()
    {
        return $this->adresse;
    }
    
    public function getRue()
    {
        if ($this->getAdresse())
            return $this->getAdresse()->getRue();
        return '';
    }
    
    public function getCp()
    {
        if ($this->getAdresse())
            return $this->getAdresse()->getCp();
        return '';
    }
    
    public function getCity()
    {
        if ($this->getAdresse())
            return $this->getAdresse()->getCity();
        return '';
    }
    
    public function getTel()
    {
        return ($this->telFixe?$this->telFixe.' - ':'').$this->telPortable;
    }

    /**
     * Set telFixe
     *
     * @param string $telFixe
     * @return User
     */
    public function setTelFixe($telFixe)
    {
        $this->telFixe = $telFixe;
    
        return $this;
    }

    /**
     * Set telPortable
     *
     * @param string $telPortable
     * @return User
     */
    public function setTelPortable($telPortable)
    {
        $this->telPortable = $telPortable;
    
        return $this;
    }

    /**
     * Get telFixe
     *
     * @return string 
     */
    public function getTelFixe()
    {
        return $this->telFixe;
    }

    /**
     * Get telPortable
     *
     * @return string 
     */
    public function getTelPortable()
    {
        return $this->telPortable;
    }

    /**
     * Add pages
     *
     * @param \MairieGestion\PageBundle\Entity\Page $pages
     * @return User
     */
    public function addPage(\MairieGestion\PageBundle\Entity\Page $pages)
    {
        $this->pages[] = $pages;
    
        return $this;
    }

    /**
     * Remove pages
     *
     * @param \MairieGestion\PageBundle\Entity\Page $pages
     */
    public function removePage(\MairieGestion\PageBundle\Entity\Page $pages)
    {
        $this->pages->removeElement($pages);
    }

    /**
     * Get pages
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getPages()
    {
        return $this->pages;
    }

    /**
     * Add cartes
     *
     * @param \MairieGestion\PageBundle\Entity\Carte $cartes
     * @return User
     */
    public function addCarte(\MairieGestion\PageBundle\Entity\Carte $cartes)
    {
        $this->cartes[] = $cartes;
    
        return $this;
    }

    /**
     * Remove cartes
     *
     * @param \MairieGestion\PageBundle\Entity\Carte $cartes
     */
    public function removeCarte(\MairieGestion\PageBundle\Entity\Carte $cartes)
    {
        $this->cartes->removeElement($cartes);
    }

    /**
     * Get cartes
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getCartes()
    {
        return $this->cartes;
    }

    /**
     * Add archives
     *
     * @param \MairieGestion\PageBundle\Entity\Archive $archives
     * @return User
     */
    public function addArchive(\MairieGestion\PageBundle\Entity\Archive $archives)
    {
        $this->archives[] = $archives;
    
        return $this;
    }

    /**
     * Remove archives
     *
     * @param \MairieGestion\PageBundle\Entity\Archive $archives
     */
    public function removeArchive(\MairieGestion\PageBundle\Entity\Archive $archives)
    {
        $this->archives->removeElement($archives);
    }

    /**
     * Get archives
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getArchives()
    {
        return $this->archives;
    }

    /**
     * Add conseils
     *
     * @param \MairieGestion\PageBundle\Entity\Conseil $conseils
     * @return User
     */
    public function addConseil(\MairieGestion\PageBundle\Entity\Conseil $conseils)
    {
        $this->conseils[] = $conseils;
    
        return $this;
    }

    /**
     * Remove conseils
     *
     * @param \MairieGestion\PageBundle\Entity\Conseil $conseils
     */
    public function removeConseil(\MairieGestion\PageBundle\Entity\Conseil $conseils)
    {
        $this->conseils->removeElement($conseils);
    }

    /**
     * Get conseils
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getConseils()
    {
        return $this->conseils;
    }

    /**
     * Add plus
     *
     * @param \MairieGestion\PageBundle\Entity\Plu $plus
     * @return User
     */
    public function addPlu(\MairieGestion\PageBundle\Entity\Plu $plus)
    {
        $this->plus[] = $plus;
    
        return $this;
    }

    /**
     * Remove plus
     *
     * @param \MairieGestion\PageBundle\Entity\Plu $plus
     */
    public function removePlu(\MairieGestion\PageBundle\Entity\Plu $plus)
    {
        $this->plus->removeElement($plus);
    }

    /**
     * Get plus
     *
     * @return \Doctrine\Common\Collections\Collection 
     */
    public function getPlus()
    {
        return $this->plus;
    }
}