<?php

namespace MairieGestion\UserBundle\Form;

use Doctrine\ORM\EntityRepository;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use MairieGestion\MainBundle\Form\AdresseType;
use MairieGestion\MainBundle\Entity\Adresse;
use Symfony\Component\Validator\Constraints\CallbackValidator;
use Symfony\Component\Validator\Constraints\NotBlank;
use Symfony\Component\Validator\Constraints\Email;

class PersonnelType extends AbstractType
{
	private $obj;
    
    public function __construct($obj)
    {
        $this->obj = $obj;
    }
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('email', 'text', array(
                'label' => 'Email',
                'constraints' => array(
                    new NotBlank(array(
                        'message' => 'Veuillez saisir une adresse email',
                    )),
                ),
                'attr' => array('class'=>'form-control'),
            ))
            ->add('first_name', 'text', array('label' => 'Prénom','attr' => array('class'=>'form-control'),))
            ->add('name', 'text', array('label' => 'Nom','attr' => array('class'=>'form-control'),))
            ->add('birthday','date',array(
                'label' => 'Date de naissance',
                'widget' => 'single_text',
                'format' => 'dd/MM/yyyy',
                'attr' => array('class' => 'date form-control')
            ))
            ->add('sexe', 'choice', array(
                'label' => ' ',
                'choices'   => array(
                    '0'   => 'Homme',
                    '1' => 'Femme',
                ),
                'expanded'  => true,
                'attr' => array('class'=>'sexe'),
            ))
            ->add('tel_fixe', 'text',array('label'=>'Téléphone fixe','attr' => array('class'=>'form-control'),))
            ->add('tel_portable', 'text',array('label'=>'Téléphone portable','attr' => array('class'=>'form-control'),))
            ->add('adresse', new AdresseType($this->obj->getAdresse()), array('label' => ' ',))
        ;
        if (!$this->obj->getId())
            $builder
                ->add('plainPassword', 'repeated', array(
                    'type' => 'password',
                    'options' => array('translation_domain' => 'FOSUserBundle'),
                    'first_options' => array('label' => 'Mot de passe'),
                    'second_options' => array('label' => 'Confirmation du mot de passe'),
                    'invalid_message' => 'Le mot de passe et la confirmation du mot de passe doivent être identiques',
                    'constraints' => array(
                        new NotBlank(array(
                                        'message' => 'Veuillez saisir le mot de passe',
                        )),
                    ),
                    'attr' => array('class'=>'form-control'),
                ));
        $builder
            ->add('Valider', 'submit',array(
                'attr'=> array('class'=>'btn', 'formnovalidate'=>true)
            ))
            ;
    }

    public function getName()
    {
        return 'usertype';
    }
    
    public function getDefaultOptions(array $options)
    {
        return array(
            'data_class' => 'MairieGestion\UserBundle\Entity\User',
        );
    }
}
