# Auteur  : Didier Pralon NeoLab-Systems
# Version : 4 Voir README.TXT

# Variables globales

    $EXCEL_GENERATOR="""C:\Program Files (x86)\Lizeo\ExcelGenerator\ExcelGenerator.exe"""
    #$EXCEL_GENERATOR="""C:\Program Files\Lizeo\ExcelGenerator\ExcelGenerator.exe"""

	# Attention, a adapter en fonction de la configuration de ExcelGenerator
    $EXCEL_GENERATOR_LOG_FILE="C:\ExcelGenerator\Logs\ExcelGenerator.log"
    
    $DIR_IN="C:\ExcelGenerator\Files\in"
    $DIR_OUT="C:\ExcelGenerator\Files\out"
    $DIR_TEMPLATES="C:\ExcelGenerator\Templates"
    $DIR_ARCHIVE_IN="C:\ExcelGenerator\Files\archives\in"
    $DIR_ARCHIVE_OUT="C:\ExcelGenerator\Files\archives\out"
    $DIR_ARCHIVE_LOG="C:\ExcelGenerator\Logs\archives"
    $DIR_TEMPLATE="C:\ExcelGenerator\Templates"
    $DIR_OK_KO="C:\ExcelGenerator\Files\out"

    $LOGFILEKO = "$DIR_OK_KO\generator.ko"
    $LOGFILEOK = "$DIR_OK_KO\generator.ok"

    $LOGFILEKO_ARCHIVE = "$DIR_ARCHIVE_LOG\generator.ko"
    $LOGFILEOK_ARCHIVE = "$DIR_ARCHIVE_LOG\generator.ok"
    
    function main()
    {
    	# Pour le fichier de logs
    	$logs = New-Object 'System.Collections.Generic.List[string]'
    	
    	PrepareLogs
	
        #Liste des pays

        $countries="FR ES IT GB DE AL AT BE BA BG CY HR DK EE FI GR HU IE IS LV LT LU MT MD NO NL PL PT CZ RO SI SK SE CH TR RS MK ME"

        TraitementProduitsSaisons "TC" "SUMMER" $countries $logs

        TraitementProduitsSaisons "TC" "WINTER" $countries $logs

        TraitementProduitsSaisons "PL" "ALL" $countries $logs
        
        FiniLogs $logs
    }
    
    function TraitementProduitsSaisons ([string]$product_line, [string] $season, [string] $countries, [System.Collections.Generic.List[string]]$logs)
    {
	    $cur_date = Get-Date
	    $cur_month = $cur_date.Month 
	    $cur_year = $cur_date.Year
	    $cur_day= $cur_date.Day
        $template = "INIT_ALL_"+$product_line+"_"+$season+"_template.xlsx"
        
        Write-Host "Traitement [$product_line] [$season]" 
            
        foreach ($country in $countries.split(" "))
        {
            #
            # Traitement pays
            #
            TraitementPays $country $product_line $season $template $logs

            #
            # Nettoyage pays
            #
            ArchiveFichiers 2 $DIR_IN  $DIR_ARCHIVE_IN  $cur_month $cur_year $country $product_line $season
            ArchiveFichiers 1 $DIR_OUT $DIR_ARCHIVE_OUT $cur_month $cur_year $country $product_line $season
                
        }

        Write-Host

    }

    function TraitementPays ([string]$country, [string]$product_line, [string]$season, [string]$template, [System.Collections.Generic.List[string]] $logs)
    {
        Write-Host "    Traitement pays $country"
        
        $cur_date = Get-Date
        $cur_month = $cur_date.Month 
        $cur_year = $cur_date.Year
        $cur_day= $cur_date.Day
        
        # Formatage pour le nom du fichier de sortie
        $fyear="{0:00}" -f $cur_year
        $fmonth="{0:00}" -f $cur_month
        $fday="{0:00}" -f $cur_day
        $filename=""

        # 
        # Recherche du fichier à mettre à jour : 
        #   last_file = null si pas de fichier dans le repertoire IN
        #
        $last_file = TrouveDernierFichier $DIR_IN $cur_month $cur_year $country $product_line $season
        
        Write-Host "    Country        : [$country] Product : [$product_line] Season : [$season]"
        Write-Host "    Current  day   : " $cur_day
        Write-Host "    Current  month : " $cur_month
        Write-Host "    Current  year  : " $cur_year
        Write-Host "    Last file      : " $last_file
        
        $retCode=-1
        
        if ($last_file -eq $null)
        {
        	$file_in="$DIR_TEMPLATES\$template"
        	
			if (Test-Path ($file_in))
			{

				# Si last_file = null -> Generation a partir du template dans le répertoire IN
				Write-Host "    Création à partir du template $template"

				# Le fichier généré par le mode CREATE est forcement du 01
				$filename="CO_"+$country+"_"+$product_line+"_"+$season+"_"+$fyear+$fmonth+"01.xlsx"

				$arguments="-d DATE=$cur_day/$cur_month/$cur_year -d POINT_VIRGULE=; -d DEUXPOINTSEGAL=:= -d COUNTRY=$country -d PRODUCT_LINE=$product_line -d SEASON=$season -t ""$DIR_TEMPLATES\$template"" -c ""C:\ExcelGenerator\Config\Requetes.txt"" -m CREATE -o ""$DIR_IN"""

				# Creation d'un nouveau fichier dans DIR_IN
				$retCode = ExecuteExcelGenerator $arguments
			}
			else
			{
				$retCode=10  # Cas spécial , a mettre en concordance avec les code dans generator.cs
				Write-Host
				Write-Host "ERROR : Le fichier template [$DIR_TEMPLATE\$template] est inexistant"
				Write-Host
			}
        }
        else
        {
         	$file_in=$last_file
       	
		    # Si last_file != null -> Update
		    Write-Host "    Mise à jour à partir de "$last_file

		    $filename="CO_"+$country+"_"+$product_line+"_"+$season+"_"+$fyear+$fmonth+"01.xlsx"

		    $arguments="-d DATE=$cur_day/$cur_month/$cur_year -d POINT_VIRGULE=; -d DEUXPOINTSEGAL=:= -d COUNTRY=$country -d PRODUCT_LINE=$product_line -d SEASON=$season -t ""$DIR_TEMPLATES\$template"" -c ""C:\ExcelGenerator\Config\Requetes.txt"" -m UPDATE -u ""$DIR_IN\$last_file"" -n ""$DIR_IN\$filename"""

		    $retCode = ExecuteExcelGenerator $arguments 

			$file_in = "$DIR_IN\$file_in"
        }
        
        #Copie dans out
        if ($retCode -eq 0)
        {
		    #Generation OK

		    Move-Item -Path "$DIR_IN\$filename" -Destination "$DIR_OUT" -force -WhatIf
		    Move-Item -Path "$DIR_IN\$filename" -Destination "$DIR_OUT" -force
		
		    $logs.Add([string]$cur_date + " : " + " " + $file_in + " " + "$DIR_IN\$filename" + " OK ")
        }
        else
        {
		    #Generation NOK
		
		    Write-Host "Le fichier $DIR_OUT\$filename n'a pas été généré"
 		   $logs.Add([string]$cur_date + " : " + " " + $file_in + " " + "$DIR_IN\$filename" + " KO " + "Error code : " + $retCode)
        }
            
        Write-Host
    }

    # Recherche dans le répertoire $folder le fichier le plus récent en commencant par le mois $currentMonth de l'année $currentYear pour un pays, un product_line, une saison
    #
    function TrouveDernierFichier ([string] $folder, [int] $currentMonth, [int] $currentYear, [string] $country, [string] $product_line, [string] $season)
    {
        $currentMonth=$currentMonth - 1
        
        while ($currentMonth -gt 0)
        {
            $fyear="{0:00}" -f $currentYear
            $fmonth="{0:00}" -f $currentMonth
            $pattern="CO_"+$country+"_"+$product_line+"_"+$season+"_"+$fyear+$fmonth+"*.xlsx"
            
            # On recherche dans le répertoire IN
            # Tri de la liste par date de modification la plus grande en premier
            $list = Get-ChildItem -Path $folder -Filter $pattern | Sort-Object LastWriteTime -descending
            if ($list)
            {
                foreach ($file in $list)
                {
                    # Retourne le premier de la liste qui est la date la plus grande soit le plus récente
                    return $file
                }
            }

            $currentMonth=$currentMonth - 1
        }
        return $null
    }


    # Déplace de $folder_src vers $folder_dest les fichiers plus ancien que $curMonth/$curYear - $delta  pour un pays, un product_line, une saison
    # Prend en compte les fichier de 01/$year-1 à $curMonth/$curYear
    #
    function ArchiveFichiers ([int] $delta, [string] $folder_src, [string] $folder_dest, [int] $curMonth, [int] $curYear, [string] $country, [string] $product_line, [string] $season)
    {
    	$year = $curYear
    	$month = $curMonth
        $keep = 0
        
        while ($year -ge $curYear - 1)
        {
        	while ($month -gt 0)
		    {
    			$fyear="{0:00}" -f $year
    			$fmonth="{0:00}" -f $month
    			$pattern="CO_"+$country+"_"+$product_line+"_"+$season+"_"+$fyear+$fmonth+"*.xlsx"

    			# On recherche dans le répertoire IN
    			$list = Get-ChildItem -Path $folder_src -Filter $pattern
    			if ($list)
    			{
    				if ($keep -ge $delta)
    				{
					foreach ($file in $list)
					{
						Move-Item -Path "$folder_src\$file" -Destination "$folder_dest" -force -WhatIf
						Move-Item -Path "$folder_src\$file" -Destination "$folder_dest" -force
					}
				}
				else
				{
					$keep = $keep + 1
				}
    			}

    			$month=$month - 1
		    }

    		$month = 12
    		$year = $year - 1
        }
    }

    function ExecuteExcelGenerator ([string] $arguments)
    {
        $Tempfile = "$Env:TEMP\"+[System.IO.Path]::GetRandomFileName()
        New-Item $Tempfile  -ItemType file  -Force   | Write-Host
        $process = Start-Process $EXCEL_GENERATOR -ArgumentList $arguments  -RedirectStandardOutput $Tempfile -passThru -Wait
        $ret=$process.ExitCode
        Get-Content $Tempfile | Write-Host
        Remove-Item $Tempfile -Force  | Write-Host
        return $ret
    }
    
    function PrepareLogs()
    {
    	
    	$fdate=FormatDate
    	
    	if(Test-Path -Path $LOGFILEKO)
		{
			$dest="$LOGFILEKO_ARCHIVE"+"."+"$fdate"
			Move-Item -Path "$LOGFILEKO" -Destination "$dest" -force -WhatIf
			Move-Item -Path "$LOGFILEKO" -Destination "$dest" -force
		}

    	if(Test-Path -Path $LOGFILEOK)
		{
			$dest="$LOGFILEOK_ARCHIVE"+"."+"$fdate"
			Move-Item -Path "$LOGFILEOK" -Destination "$dest" -force -WhatIf
			Move-Item -Path "$LOGFILEOK" -Destination "$dest" -force
		}

    	new-item -Path $LOGFILEKO -itemtype file
    	
    	# RAZ du fichier des logs d'ExcelGenerator
    	New-Item "$EXCEL_GENERATOR_LOG_FILE" -type file -force -WhatIf
    	New-Item "$EXCEL_GENERATOR_LOG_FILE" -type file -force
    	
    }
    

    #
    # Ecrit la liste des logs dans le fichier de log
    # Compte le nombre de OK et KO et les ecrit à la fin du fichier
    #
    function EcritLogs ( [string] $logfile, [System.Collections.Generic.List[string]] $liste)
    {
    	$ok=0
    	$ko=0

    	foreach ($str in $liste)
    	{
     		Add-Content -Path $logfile -Value "$str"

     		if ($str.Contains(" OK "))
     		{
     			$ok=$ok+1
     		}
     		else
     		{
     			$ko=$ko+1
     		}
     	}
     	Add-Content -Path $logfile -Value "ok=$ok;ko=$ko"
    }

    function FiniLogs([System.Collections.Generic.List[string]] $logs)
    {
        #Ecriture des logs
        EcritLogs $LOGFILEKO $logs

		Move-Item -Path "$LOGFILEKO" -Destination "$LOGFILEOK" -force -WhatIf
		Move-Item -Path "$LOGFILEKO" -Destination "$LOGFILEOK" -force
	
		#Archivage du fichier des logs ExcelGenerator
		$fdate=FormatDate
		$file=Get-ChildItem $EXCEL_GENERATOR_LOG_FILE
		$dest = "$DIR_ARCHIVE_LOG\" + $file.Name + "." + $fdate
		Move-Item -Path "$EXCEL_GENERATOR_LOG_FILE" -Destination "$dest" -force -WhatIf
		Move-Item -Path "$EXCEL_GENERATOR_LOG_FILE" -Destination "$dest" -force
	
    }

    function FormatDate()
    {
	$date=Get-Date
	$year = $date.Year
	$month = $date.Month 
	$day= $date.Day
	$hour = $date.Hour
	$minute= $date.Minute
	$second= $date.Second

	# Formatage pour le nom du fichier de sortie
	$fyear="{0:00}" -f $year
	$fmonth="{0:00}" -f $month
	$fday="{0:00}" -f $day
	$fhour="{0:00}" -f $hour
	$fminute="{0:00}" -f $minute
	$fsecond="{0:00}" -f $second
	$fdate=$fyear+$fmonth+$fday+"-"+$fhour+$fminute+$fsecond

	return $fdate
    }
    
    main
