<?php
    require_once __DIR__.'/bootstrap.php.cache';
    require_once __DIR__.'/AppKernel.php';
    
    use Lizeo\PCPBundle\Utils\FileManipulation;
    use Lizeo\PCPBundle\Utils\FileNameParse;
    use Lizeo\PCPBundle\Entity\TypeFile;
    use Lizeo\PCPBundle\Entity\File;
    
    CONST JOB_TALEND_PATH = "/home/pcp/script/pcp_batch.sh";
    $worker = new GearmanWorker();
    $worker->addServer();
    $worker->addFunction("executeJobTalend", "executeJobTalend");
    while($worker->work());

    function executeJobTalend($job)
    {
        $kernel = new \AppKernel("prod", false);
        $kernel->boot();
        $container = $kernel->getContainer();
        
        $job->sendStatus(1, 5);
        
        $em = $container->get('doctrine')->getEntityManager();
        $data = unserialize($job->workload());
        $filename = $data['file'];
        $filename_parse = new FileNameParse($filename);
                
        if (!is_dir($container->getParameter('talend_archive').$filename_parse->getYear())) {
            mkdir($container->getParameter('talend_archive').$filename_parse->getYear(), 0755);
        }
        
        if (!is_dir($container->getParameter('talend_file_reject').$filename_parse->getYear())) {
            mkdir($container->getParameter('talend_file_reject').$filename_parse->getYear(), 0755);
        }
        
        $file = new FileManipulation($container->getParameter('job_talend_log_dir').$data['id'].'-gearman.log', 'a+', true, true);

        $file->write('Begin');
        
        if ($em->isOpen()) {
            $file->write('Doctrine Open');
        } else {
            $file->write('Doctrine Close');
        }
        
        $file->write('Begin to get object data : '.$data['id']);
        
        // Update file information
        try {
            $file->write('Try');
            $_file = $em->getRepository('LizeoPCPBundle:File')->find($data['id']);
            $_file->setStatus(File::STATUS_IN_PROGESS);
            $em->persist($_file);
            $em->flush();
            $_file_typefile = $_file->getTypeFile();
        } catch(Exception $e) {
            $file->write('Catch exception : '.$e->getMessage());
        }
        
        $file->write('End of get object data : '.$data['id']);
        
        if ($_file instanceof File)
        {
            
            $file->write('Get object data OK');

            /**
            * Conversion CSV 
            */
            if ($_file_typefile->isConvertToCSV()) {
                $job->sendStatus(2, 5);
                try {
                    $file->write('Start converting file in CSV : '.$container->getParameter('talend_file_in').$filename);
                    $csv = new FileManipulation($container->getParameter('talend_file_in').$filename, 'w+');
                    $objPHPExcel = \PHPExcel_IOFactory::load($container->getParameter('www_dir').$_file->getUrl());
                    $file->write('Sizeof Sheet : '.sizeof($objPHPExcel->getAllSheets()));
                    
                    foreach ($_file_typefile->getCSVTabArray() as $iSheet) {
                        $file->write('Sheet : '.$iSheet);
                        $sheet = $objPHPExcel->getSheet($iSheet);
                        
                        foreach ($sheet->getRowIterator() as $row) {
                            $_data = array();
                            $cellIterator = $row->getCellIterator();
                            $cellIterator->setIterateOnlyExistingCells(false);
                            
                            if ($data['job_name'] == TypeFile::JOB_IMPORT_CO_ALL) {
                                $i = 0;
                                
                                foreach ($cellIterator as $cell) {
                                    if ($i == 14 || $i == 15 || $i == 29 || $i == 30) {
                                        $_data[] = $cell->getOldCalculatedValue();
                                    } else {
                                        $_data[] = $cell->getCalculatedValue();
                                    }
                                    $i++;
                                }
                            } else {
                                foreach ($cellIterator as $cell) {
                                    $_data[] = $cell->getCalculatedValue();
                                }
                            }
                            
                            if ($data['job_name'] == TypeFile::JOB_IMPORT_TS_ALL) {
                                $_data[13] = PHPExcel_Style_NumberFormat::toFormattedString($_data[13], PHPExcel_Style_NumberFormat::FORMAT_PERCENTAGE_00);
                                $_data[13] = str_replace("%", "", $_data[13]);
                            } else if ($data['job_name'] == TypeFile::JOB_IMPORT_CO_ALL || $data['job_name'] == "import_init_all") {
                                $_data[1] = $filename_parse->getFormattedDate();

                                if(strpos($filename, "TC") !== false) {
                                    if(strtolower($_data[4]) == "nokian" || strtolower($_data[4]) == "pirelli") {
                                        $_data[5] = "T1";
                                    }
                                } else if(strpos($filename, "PL") !== false) {
                                    // Sell in
                                    if (($_data[16] == "0.00" || $_data[16] == 0 || $_data[16] == "") && ($_data[12] <> 0 || $_data[12] <> "0" && is_numeric($_data[12])) && ($_data[15] <> 0 || $_data[15] <> "0" || $_data[15] <> "")) {
                                        $_data[16] = $_data[15] / $_data[12]; 
                                    }

                                    // Sell out
                                    if (($_data[28] == "0.00" || $_data[28] == 0 || $_data[28] == "") && ($_data[12] <> 0 || $_data[12] <> "0" && is_numeric($_data[12])) && ($_data[27] <> 0 || $_data[27] <> "0" || $_data[27] <> "")) {
                                        $_data[28] = $_data[27] / $_data[12]; 
                                    }
                                }

                                if (strpos($_data[2], "/") === false) {
                                    $_data[2] = str_replace(" R", "/0 R", $_data[2]);
                                }

                                if ($_data[9] == "0") {
                                    $_data[9] = "";
                                } else {
                                    $_data[9] = PHPExcel_Style_NumberFormat::toFormattedString($_data[9], "DD/MM/YYYY");
                                }
                            }
                            
                            if ($data['job_name'] == TypeFile::JOB_IMPORT_CO_ALL && strpos($filename, 'PL') !== false) {
                                /*
                                 * ONLY FOR CO PL
                                 * This condition permit us to keep only good data.
                                 * If we do not remove retread data we will have data with sell-in price at 0
                                 */
                                if (strpos(strtolower($_data[39]), 'retread') === false) {
                                    $csv->putcsv($_data);
                                }
                            } else {
                                $csv->putcsv($_data);
                            }
                        }
                    }

                    $csv->close();
                    $objPHPExcel->disconnectWorksheets();
                    unset($objPHPExcel);
                    $file->write('Finish converting file in CSV : '.$container->getParameter('talend_file_in').$_file->getName().'.csv');
                } catch(\Exception $e) {
                    if ($data['job_name'] == TypeFile::JOB_IMPORT_CONTEXT) {
                        $filename_position = strrpos($filename, '/');
                        rename($filename, $container->getParameter('talend_file_reject').$filename_parse->getYear().substr($filename, $filename_position + 1));
                    } else {
                        rename($container->getParameter('talend_file_in').$filename, $container->getParameter('talend_file_reject').$filename_parse->getYear().'/'.$filename);
                    }
                    
                    $job->sendStatus(5, 5);
                    $_file->setStatus(File::STATUS_FAILED);
                    $em->persist($_file);
                    $em->flush();
                    $mailer = $container->get('pcp_mailer');
                    $mailer->sendIntegrationReport($_file);
                    $mailer->sendFileBlocked($_file, $e->getMessage());
                    $file->write('During converting file in CSV ('.$container->getParameter('talend_file_in').$_file->getName().'.csv) : '.$e->getMessage());
                    $em->getConnection()->close();
                    unset($mailer);
                    
                    return;
                }
            } else {
                $file->write('Copy file into talend_file_in folder '.$container->getParameter('www_dir').$_file->getUrl().' - '.$data['file']);
                copy($container->getParameter('www_dir').$_file->getUrl(), $data['file']);
            }

            $execute = JOB_TALEND_PATH." ".$data['job_name']." ";
            
            switch ($data['job_name']) {
                case TypeFile::JOB_IMPORT_CONTEXT:
                    $execute .= executeImportContext($data['file']);
                    break;
                default:
                    $execute .= executeImport($data['file']);
                    break;
            }
            
            $em->getConnection()->close();

            $file->write('execute : '.$execute);
            
            $job->sendStatus(3, 5);
            $output = array();
            exec($execute.' 2>&1', $output, $return_var);
            $file->write('return_var : '.$return_var);
            $output_message = "";
            
            foreach ($output as $out) {
                $output_message .= $out."\n";
            }
            
            $file->write($output_message);
            
            $em = $container->get('doctrine')->getEntityManager();
            $_file = $em->getRepository('LizeoPCPBundle:File')->find($data['id']);
            
            if ($return_var == 0) {
                $job->sendStatus(4, 5);
                $file->write('Reset used file');
                $file->write('Reset Group Id : '.$_file->getGroup()->getId());
                $file->write('Reset Type File Id : '.$_file_typefile->getId());
                $file->write('Reset Date period : '.$_file->getDatePeriod()->format("Y-m-d"));
                $em->getRepository('LizeoPCPBundle:File')->resetUsedFile($_file->getGroup()->getId(), $_file_typefile->getId(), $_file->getDatePeriod()->format("Y-m-d"));
                $file->write('Reset');
                $_file->setUsed(true);
                $_file->setValid(true);
                $_file->setStatus(File::STATUS_SUCCEED);
                $em->persist($_file);
                $file->write('Flush File');
                $em->flush();
                
                // Envoi du fichier pousser par les utilisateurs sur le serveur QV (uniquement les CO)
                if($data['job_name'] == TypeFile::JOB_IMPORT_CO_ALL) {
                    $file->write('Send Qlikview file ' . $data['file']);
                    qvSendFile($container, $data['file'], $container->getParameter('www_dir').$_file->getUrl());
                }
                
                // Envoi du fichier pour le rechargement de Qlikview
                $file->write('Reload Qlikview file');
                qvReloadFile($container, $data['file']);
                
                if ($data['job_name'] == TypeFile::JOB_IMPORT_CONTEXT) {
                    $filename_position = strrpos($filename, '/');
                    rename($filename, $container->getParameter('talend_archive').$filename_parse->getYear().substr($filename, $filename_position + 1));
                } else {
                    rename($container->getParameter('talend_file_in').$filename, $container->getParameter('talend_archive').$filename_parse->getYear().'/'.$filename);
                }
            } else {
                $_file->setStatus(File::STATUS_FAILED);
                $em->persist($_file);
                $em->flush();
                
                if ($data['job_name'] == TypeFile::JOB_IMPORT_CONTEXT) {
                    $filename_position = strrpos($filename, '/');
                    rename($filename, $container->getParameter('talend_archive').$filename_parse->getYear().substr($filename, $filename_position + 1));
                } else {
                    rename($container->getParameter('talend_file_in').$filename, $container->getParameter('talend_archive').$filename_parse->getYear().'/'.$filename);
                }
            }
            
            $file->write('Send Mail');
            $mailer = $container->get('pcp_mailer');
            $mailer->sendIntegrationReport($_file);
            
            if ($return_var != 0) {
                $mailer->sendFileBlocked($_file, $output_message);
            }
            
            $mailer->stopTransport();
        } else {
            $file->write('Get object data KO');
        }
        
        $file->write('End');
        $file->close();
        $job->sendStatus(5, 5);
        $em->getConnection()->close();
    }
    
    function executeImportContext($filename_context)
    {
        return "--context_param filename_context=".$filename_context." ";
    }
    
    function executeImport($filename_in)
    {
        return "--context_param filename_in=".$filename_in." ";
    }
    
    /**
     * Create file for Qlikview remote server
     * @global type $container
     * @param type $filename 
     */
    function qvReloadFile($container, $filename)
    {
        $url = $container->getParameter('qlikview_reload_remote_directory');
        $datetime = date("YmdHis");
        $file = "reload_qv_".$datetime.".txt";
        $filename_verbose = $container->getParameter('job_talend_log_dir').'curl-verbose-'.$datetime.'.log';
        $filename_temp = $container->getParameter('job_talend_log_dir').'curl-temp-'.$datetime.'.log';
        
        $log = new FileManipulation($filename_verbose, 'w');
        $qv_file = new FileManipulation($filename_temp, 'w');
        $qv_file->putcsv(array('datetime', 'filename'), ';');
        $qv_file->putcsv(array("".date('Y-m-D H:i:s')."", $filename), ';');
        $qv_file->putcsv(array(), ';');
        $qv_file->close();
        $qv_file = new FileManipulation($filename_temp, 'r');

        $log->close();
        $qv_file->close();

        /** @var \Lizeo\PCPBundle\Service\SshConnector $sshConnector */
        $sshConnector = $container->get('pcp_ssh_connector');
        $sshConnector->initSession();
        $log = new FileManipulation($container->getParameter('job_talend_log_dir').'curl-'.$datetime.'.log', 'w');
        $log->write('SCP put file from : ' . $filename_temp . ' to : ' . $url . $file);
        $isSent = $sshConnector->putFileByScp($filename_temp, $url . $file);
        $sshConnector->closeSession();

        unlink($filename_temp);
        
        // If error we save a log
        if (!$isSent) {
            $log->write('Error during file sending over SSH : ' . $filename_temp);
            $log->close();
        } else {
            unlink($filename_verbose);
        }
        
        // Envoi mail Antoine
        mail("antoine.gallet@lizeo-group.com", "Reload file", "Reload file envoyé sur QV");
    }
    
    /**
     * Send file for Qlikview remote server
     * @global type $container
     * @param type $filename 
     */
    function qvSendFile($container, $filename_csv, $filename_xlsx)
    {
        $url = $container->getParameter('excel_template_remote_directory_in');
        $datetime = date("YmdHis");
        $filename_verbose = $container->getParameter('job_talend_log_dir').'curl-sendfile-verbose-'.$datetime.'.log';
      
        $log = new FileManipulation($filename_verbose, 'w');
        $qv_file = new FileManipulation($filename_xlsx, 'r');

        /** @var \Lizeo\PCPBundle\Service\SshConnector $sshConnector */
        $sshConnector = $container->get('pcp_ssh_connector');
        $sshConnector->initSession();

        $log = new FileManipulation($container->getParameter('job_talend_log_dir').'curl-sendfile-'.$datetime.'.log', 'w');
        $log->write('SCP put file from : ' . $filename_xlsx . ' to : ' . $url . str_replace(".csv", "", $filename_csv));
        $isSent = $sshConnector->putFileByScp($filename_xlsx, $url . str_replace(".csv", "", $filename_csv));
        $sshConnector->closeSession();
        
        $log->close();
        $qv_file->close();
        
        // If error we save a log
        if (!$isSent) {
            $log->write('Error during file sending over SSH : ' . $filename_xlsx);
            $log->close();
        } else {
            unlink($filename_verbose);
        }
    }
