<?php

namespace Lizeo\PCPBundle\Admin;

use Sonata\AdminBundle\Admin\Admin;
use Sonata\AdminBundle\Datagrid\ListMapper;
use Sonata\AdminBundle\Datagrid\DatagridMapper;
use Sonata\AdminBundle\Validator\ErrorElement;
use Sonata\AdminBundle\Form\FormMapper;
use Lizeo\PCPBundle\Model\ProductLine;

class TypeFileAdmin extends Admin
{
    protected $datagridValues = array(
        '_page'       => 1,
        '_sort_order' => 'ASC',
        '_sort_by'    => 'position',
    );
    
    protected function configureFormFields(FormMapper $formMapper)
    {
        $formMapper
            ->add('name')
            ->add('product_line', 'choice', 
                array('required' => true, 'choices' => array(
                    ProductLine::PRODUCT_LINE_ALL => "All",
                    ProductLine::PRODUCT_LINE_TC => "TC",
                    ProductLine::PRODUCT_LINE_PL => "PL",
            )))
            ->add('tag')
            ->add('type_period', 'entity', array('empty_value' => '', 'class' => 'Lizeo\PCPBundle\Entity\TypeFilePeriod', 'required' => true))
            ->add('convert_to_csv', null, array('required' => false))
            ->add('csv_tab', null, array('required' => false, 'help' => 'Set the position of tabs you want to upload separates by commat (Example : 0,1,2)'))
            ->add('groups', 'entity', array('class' => 'Lizeo\UserBundle\Entity\Group', 'multiple' => true, 'expanded' => true, 'required' => true))
            ->add('position')
            ->add('enabled', null, array('required' => false))
        ;
    }

    protected function configureDatagridFilters(DatagridMapper $datagridMapper)
    {
        $datagridMapper
            ->add('name')
            ->add('enabled')
        ;
    }

    protected function configureListFields(ListMapper $listMapper)
    {
        $listMapper
            ->addIdentifier('name')
            ->addIdentifier('type_period')
            ->addIdentifier('position')
            ->addIdentifier('enabled')
        ;
    }

    public function validate(ErrorElement $errorElement, $object)
    {
        $errorElement
            ->with('name')
                ->assertMaxLength(array('limit' => 50))
            ->end()
            ->with('tag')
                ->assertMaxLength(array('limit' => 50))
            ->end()
        ;
        
        if ($object->IsConvertToCSV() && $object->getCSVTab() == "") {
            $errorElement
                ->addViolation('You must set tabs position')
            ->end()
            ->with('csv_tab')
                ->addViolation('You must set tabs position')
            ->end();
        }
        
        if (!$object->IsConvertToCSV() && $object->getCSVTab() != "") {
            $errorElement
                ->addViolation('You must check "Convert To Csv" if you want set tabs position')
            ->end()
            ->with('convert_to_csv')
                ->addViolation('You must check "Convert To Csv" if you want set tabs position')
            ->end();
        }
        
        
        if ($object->IsConvertToCSV()) {
            $csv_tab = str_replace(' ', '', $object->getCSVTab());
            $csv_tab = explode(',', $csv_tab);

            foreach ($csv_tab as $tab) {
                if (!is_numeric($tab)) {
                    $errorElement
                        ->addViolation('You must set tabs position like this example : "0,1,2"')
                    ->end()
                    ->with('csv_tab')
                        ->addViolation('You must set tabs position like this example : "0,1,2"')
                    ->end();
                    break;
                }
            }
        }
    }
}
