<?php

namespace Lizeo\PCPBundle\Admin;

use Sonata\AdminBundle\Admin\Admin;
use Sonata\AdminBundle\Datagrid\ListMapper;
use Sonata\AdminBundle\Datagrid\DatagridMapper;
use Sonata\AdminBundle\Validator\ErrorElement;
use Sonata\AdminBundle\Form\FormMapper;

class TypeFilePeriodAdmin extends Admin
{
    protected function configureFormFields(FormMapper $formMapper)
    {
        $formMapper
            ->add('name')
            ->add('months', null, array('required' => true, 'help' => 'Set months number separates by commat (Example : "01,02,03"; 01 = January)'))
            ->add('enabled', null, array('required' => false))
        ;
    }

    protected function configureDatagridFilters(DatagridMapper $datagridMapper)
    {
        $datagridMapper
            ->add('name')
            ->add('enabled')
        ;
    }

    protected function configureListFields(ListMapper $listMapper)
    {
        $listMapper
            ->addIdentifier('name')
            ->addIdentifier('months')
            ->addIdentifier('enabled')
        ;
    }

    public function validate(ErrorElement $errorElement, $object)
    {
        $errorElement
            ->with('name')
                ->assertMaxLength(array('limit' => 50))
            ->end()
        ;
        
        $months = str_replace(' ', '', $object->getMonths());
        $months = explode(',', $months);
        
        foreach ($months as $tab) {
            if (!is_numeric($tab) || strlen($tab) != 2) {
                $errorElement
                    ->addViolation('You must set months like this example : "01,02,03"')
                ->end()
                ->with('months')
                    ->addViolation('You must set months like this example : "01,02,03"')
                ->end();
                break;
            } else if($tab < 1 || $tab > 12) {
                $errorElement
                    ->addViolation('Months must be between 01 and 12')
                ->end()
                ->with('months')
                    ->addViolation('Months must be between 01 and 12')
                ->end();
            }
        }
    }
}
