<?php

namespace Lizeo\PCPBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Lizeo\PCPBundle\Entity\File;
use Lizeo\PCPBundle\Entity\TypeFile;
use Lizeo\PCPBundle\Utils\FileManipulation;
use Lizeo\PCPBundle\Utils\Launcher;
use Lizeo\PCPBundle\Entity\DownloadFile;
use Lizeo\PCPBundle\Model\Contact;
use Lizeo\UserBundle\Entity\User;

class DefaultController extends Controller
{
    /**
     * @Route("/")
     * @Template() 
     */
    public function indexAction()
    {
        if (true === $this->get('security.context')->isGranted(array('ROLE_MANAGER'))) {
             return $this->redirect($this->generateUrl('lizeo_qlikview_reporting'));
        }
        return $this->redirect($this->generateUrl('lizeo_pcp_default_filemanager'));
    }
    
    /**
     * @Route("/faq.html")
     * @Template()
     */
    public function faqAction()
    {
        if ($this->getRequest()->getMethod() == 'GET') {
            $data = $this->getRequest()->get('id');
            
            if ($data != null) {
                $filename = $this->container->getParameter('www_dir')."uploads/pdf/";
                $name = "";
                
                switch ($data) {
                    case "1":
                        $filename .= $this->container->getParameter('pdf_context_roles_reports');
                        $name = $this->container->getParameter('pdf_context_roles_reports');
                        break;
                    case "2":
                        $filename .= $this->container->getParameter('pdf_using_competitiveness_tool');
                        $name = $this->container->getParameter('pdf_using_competitiveness_tool');
                        break;
                    case "3":
                        $filename .= $this->container->getParameter('pdf_qv_11_guidelines');
                        $name = $this->container->getParameter('pdf_qv_11_guidelines');
                        break;
                    case "4":
                        $filename .= $this->container->getParameter('pdf_monthly_co_files_upload_guidelines');
                        $name = $this->container->getParameter('pdf_monthly_co_files_upload_guidelines');
                        break;
                    case "5":
                        $filename .= $this->container->getParameter('pdf_semester_volumes_files_upload_guidelines');
                        $name = $this->container->getParameter('pdf_semester_volumes_files_upload_guidelines');
                        break;
                    default:
                        $filename = "";
                        $name = "";
                        break;
                }
                
                if ($name != "") {
                    $type = mime_content_type($filename);
                    header('Content-Type: application/force-download');
                    header('Content-Transfer-Encoding: '.$type.'\n');
                    header('Content-Length: '. filesize($filename));
                    header('Content-disposition: attachment; filename='. $name);
                    header('Pragma: no-cache');
                    header('Cache-Control: no-store, no-cache, must-revalidate, post-check=0, pre-check=0');
                    header('Expires: 0');
                    
                    return new \Symfony\Component\HttpFoundation\Response(readfile($filename));
                }
            }
        }
        
        $errors = $this->getDoctrine()->getRepository('LizeoPCPBundle:ErrorCode')->findByLevel(array(0, 1));
        $errors_code = array();
        
        if (!is_null($errors)) {
            foreach ($errors as $error) {
                $errors_code[$error->getLevel()][] = $error;
            }
            
            ksort($errors_code, SORT_NUMERIC);
        }
        
        return array(
            'errors_code' => $errors_code
        );
    }
    
    /**
     * @Route("/change-language-{language}.html")
     * @Template() 
     */
    public function changeLanguageAction($language)
    {
        if ($language != null) {
            $this->container->get('session')->setLocale($language);
        }
        
        $url = $this->container->get('request')->headers->get('referer');
        
        if (empty($url)) {
            $url = $this->container->get('router')->generate('lizeo_pcp_default_filemanager');
        }
        
        return new RedirectResponse($url);
    }
    
    /**
     * @Route("/file-manager.html")
     * @Template()
     */
    public function fileManagerAction()
    {
        if (false === $this->get('security.context')->isGranted(array('ROLE_CENTRAL', 'ROLE_PAYS'))) {
             return $this->redirect($this->generateUrl('lizeo_qlikview_reporting'));
        }
        
        $session = $this->getRequest()->getSession();
        $id_user = $this->get('security.context')->getToken()->getUser()->getId();
        $groups = $this->get('security.context')->getToken()->getUser()->getGroup();
        $group = null;
        $groups_form = array();
        $groups_object = array();
        $show_form_groups = false;
        
        if (!is_null($groups)) {
            if (sizeof($groups) > 1) {
                $show_form_groups = true;
                
                foreach ($groups as $_group) {
                    if (!$_group->hasRole(User::ROLE_ADMIN) && $_group->getCountry() != null && $_group->getCountry()->isEnabled()) {
                        $groups_form[$_group->getId()] = $_group->getName(); 
                        $groups_object[$_group->getId()] = $_group;
                        
                        if (is_null($group)) {
                            $group = $_group;
                        }
                    }
                }
            } else {
                $group = $groups->get(0);
            }
        }
        
        $date = date('Y-m');
        
        if ($session->has('FileManager.Form.Date')) {
            $date = $session->get('FileManager.Form.Date');
        } else {
            $session->set('FileManager.Form.Date', $date);
        }
        
        if ($session->has('FileManager.Form.Group')) {
            $group = $session->get('FileManager.Form.Group');
        } else {
            $session->set('FileManager.Form.Group', $group);
        }
        
        /**
         * Even if we have only one group, we make the form but we will hide it in the view thanks to $show_form_groups
         */
        $form = $this->createFormBuilder(array('groups' => $group->getId()))
                ->add('groups', 'choice', array('choices' => $groups_form))
                ->getForm();
        
        if ($this->getRequest()->getMethod() == 'POST') {
            $date = $this->getRequest()->get('date');
            $session->set('FileManager.Form.Date', $date);
            $data = $this->getRequest()->request->get($form->getName(), array());
            
            if (isset($data['groups'])) {    
                $group = $groups_object[$data['groups']];
                $session->set('FileManager.Form.Group', $group);
                $form = $this->createFormBuilder(array('groups' => $group->getId()))
                    ->add('groups', 'choice', array('choices' => $groups_form))
                    ->getForm();
            }
        }
        
        $group = $this->getDoctrine()->getRepository('LizeoUserBundle:Group')->find($group->getId());
        $country = $group->getCountry();
        
        // Get files template from remote server
        $date_template = str_replace("-", "", $date);
        $template_tc_summer = "CO_".$country->getCode()."_TC_SUMMER_".str_replace("-", "", $date)."01.xlsx";
        $template_tc_winter = "CO_".$country->getCode()."_TC_WINTER_".str_replace("-", "", $date)."01.xlsx";
        $template_pl = "CO_".$country->getCode()."_PL_ALL_".str_replace("-", "", $date)."01.xlsx";
        $dir_xlsx_template = $this->container->getParameter('excel_template_local_directory');
        
        if (strpos($group->getName(), "TC") !== false) {
            $template_pl = false;

            if (!file_exists($dir_xlsx_template.$date_template."/".$template_tc_summer)) {
                $template_tc_summer = false;
            }

            if (!file_exists($dir_xlsx_template.$date_template."/".$template_tc_winter)) {
                $template_tc_winter = false;
            }
        } else if (strpos($group->getName(), "PL") !== false) {
            $template_tc_summer = false;
            $template_tc_winter = false;

            if (!file_exists($dir_xlsx_template.$date_template."/".$template_pl)) {
                $template_pl = false;
            }
        }
        
        /**
         * Get list of type file and file 
         */
        $listTypeFile = $this->getDoctrine()->getRepository('LizeoPCPBundle:TypeFile')->findTypeFileByGroup($group->getId(), substr($date, 5, 2));
        $listFile = array();
        $status = true;
        
        if (!is_null($listTypeFile)) {
            foreach ($listTypeFile as $typeFile) {
                $listFile[$typeFile->getId()] = $this->getDoctrine()->getRepository('LizeoPCPBundle:File')->findFileByGroupAndTypeFileAndDatePeriod($group->getId(), $typeFile->getId(), $date);
                
                if (sizeof($listFile[$typeFile->getId()]) == 0) {
                    $status = false;
                }
            }
        }
        
        return array(
            'form'                  => $form->createView(),
            'listTypeFile'          => $listTypeFile,
            'listFile'              => $listFile,
            'date'                  => $date,
            'date_template'         => $date_template,
            'status'                => $status,
            'show_form_groups'      => $show_form_groups,
            'id_group'              => $group->getId(),
            'locale'                => $this->container->get('session')->getLocale(),
            'template_tc_summer'    => $template_tc_summer,
            'template_tc_winter'    => $template_tc_winter,
            'template_pl'           => $template_pl
        );
    }
    
    /**
     * @Route("upload-file/{date_period}/{id_group}/{id_type_file}.html", requirements={"id_type_file" = "\d+"}, name="uploadFile")
     * @Template() 
     */
    public function uploadFileAction($date_period, $id_group, $id_type_file)
    {
        if (false === $this->get('security.context')->isGranted(array('ROLE_CENTRAL', 'ROLE_PAYS'))) {
             return $this->redirect($this->generateUrl('lizeo_qlikview_reporting'));
        }
        
        if ($this->container->getParameter('mode_maintenance') == 1) {
             return $this->render('LizeoPCPBundle:Default:modeMaintenance.html.twig');
        }
        
        $error_message = false;
        $send = false;
        
        $type_file = $this->getDoctrine()->getRepository('LizeoPCPBundle:TypeFile')->find($id_type_file);
        $group = $this->getDoctrine()->getRepository('LizeoUserBundle:Group')->find($id_group);
        
        $file = new File();
        $file->setTypeFile($type_file->getTag());
        $date = new \DateTime();
        $date->setDate(substr($date_period, 0, 4), substr($date_period, 5, 2), '01');
        $file->setDatePeriod($date);
        $file->setGroup($group);
                
        $form = $this->createFormBuilder($file)
                    ->add('file', 'file', array('required' => true))
                    ->add('type_file', 'hidden')
                    ->getForm();

        if ($this->getRequest()->getMethod() == 'POST') {
            $form->bindRequest($this->getRequest());
            
            if ($form->isValid()) {
                $send = true;
                
                $em = $this->getDoctrine()->getEntityManager();
                
                // Define Web upload dir
                $file->setWwwDir($this->container->getParameter('www_dir'));
                
                $file->setTypeFile($type_file);
                $file->setDatePeriod($date);
                $file->setUser($this->get('security.context')->getToken()->getUser());
                $file->setGroup($group);
                         
                $original_filename = $file->getFile()->getClientOriginalName();
                $em->persist($file);
                $em->flush();
                
                try {
                    $filename = $file->getName();
                    $log = new FileManipulation($this->container->getParameter('job_talend_log_dir').$file->getId().'.log', 'w');
                    $log->write('Start file treatment : '.$filename);
                    
                    /**
                     * Launch talend's job 
                     */
                    if ($type_file->getJobTalend() == "") {
                        $log->write('No talend\'s job to launch');
                    } else {
                        try {
                            $log->write('Launch talend\'s job : '.$type_file->getJobTalend());
                            $launcher = new Launcher();
                            
                            if ($type_file->isConvertToCSV()) {
                                $filename = $file->getName().'.csv';
                            } else {
                                $filename = $file->getName();
                            }
                            
                            if ($type_file->getJobTalend() == TypeFile::JOB_IMPORT_CONTEXT) {
                                $filename = $this->container->getParameter('talend_file_in').$filename;
                            }
                            
                            $log->write('Filename : '.$filename);
                            
                            $info = $launcher->executeJob($type_file->getJobTalend(), $file->getId(), $filename);
                            $file->setGearmanId($info[0]);
                            $file->setGearmanReturnCode($info[1]);
                        } catch(\Exception $e) {
                            $log->write('During launching talend\'s job : '.$e->getMessage());
                            throw new \Exception($e->getMessage());
                        }
                    }
                    
                    $log->write('End of file treatment');
                    
                    $em->persist($file);
                    $em->flush();
                    
                    $log->write('File flush');
                    $log->close();
                    
                    return $this->redirect($this->generateUrl('lizeo_pcp_default_filemanager'));
                } catch(\Exception $e) {
                    $log->write($e->getMessage());
                    $error_message = $e->getMessage();
                }
                
                $log->write('End of file treatment');
                $log->close();
            }
        }
        
        return array(
            'form'          => $form->createView(),
            'typeFile'      => $type_file,
            'date_file'     => '_'.str_replace('-', '', $date_period).'01',
            'date_period'   => $date_period.'-01',
            'error_message' => $error_message,
            'file'          => $file,
            'send'          => $send,
        );
    }
    
    /**
     * @Route("check-country.html")
     * @Template() 
     */
    public function checkCountryAction()
    {
        if (false === $this->get('security.context')->isGranted('ROLE_CENTRAL')) {
             return $this->redirect($this->generateUrl('lizeo_pcp_default_filemanager'));
        }
        
        $session = $this->getRequest()->getSession();
        $date = date('Y-m');
        $current_country = array(0 => '', 1 => '');
        
        if ($session->has('CheckCountry.Form.Date')) {
            $date = $session->get('CheckCountry.Form.Date');
        } else {
            $session->set('CheckCountry.Form.Date', $date);
        }
        
        if ($session->has('CheckCountry.Form.Country')) {
            $current_country = $session->get('CheckCountry.Form.Country');
        } else {
            $session->set('CheckCountry.Form.Country', $current_country);
        }
        
        $countries = array();
        $_countries = $this->getDoctrine()->getRepository('LizeoPCPBundle:Country')->findAll(true, false, true);
        
        foreach ($_countries as $_country) {
            $countries[$_country->getId()] = $_country->getName();
        }
        
        $form = $this->createFormBuilder(array('countries' => $current_country[0]))
                ->add('countries', 'choice', array('choices' => $countries, 'empty_value' => '', 'required'=>false))
                ->getForm();
        
        if ($this->getRequest()->getMethod() == 'POST') {
            $date = $this->getRequest()->get('date');
            $session->set('CheckCountry.Form.Date', $date);
            $data = $this->getRequest()->request->get($form->getName(), array());
            $current_country = array(0 => '', 1 => '');
            
            if ($data['countries'] != '') {
                $country = $this->getDoctrine()->getRepository('LizeoPCPBundle:Country')->find($data['countries']);
                $current_country = array(0 => $data['countries'], 1 => $country->getName());
            }
            
            $session->set('CheckCountry.Form.Country', $current_country);
            $form = $this->createFormBuilder(array('countries' => $current_country[0]))
                ->add('countries', 'choice', array('choices' => $countries, 'empty_value' => '', 'required'=>false))
                ->getForm();
        } else if($this->getRequest()->getMethod() == 'GET') {
            $data = $this->getRequest()->get('country');
            
            if ($data != null) {
                $current_country = array(0 => '', 1 => '');
                
                if ($data != '' && $data != 0) {
                    $country = $this->getDoctrine()->getRepository('LizeoPCPBundle:Country')->findOneBy(array('id' => $data, 'enabled' => 1));
                    $current_country = array(0 => $data, 1 => $country->getName());
                }
                
                $session->set('CheckCountry.Form.Country', $current_country);
                $form = $this->createFormBuilder(array('countries' => $current_country[0]))
                    ->add('countries', 'choice', array('choices' => $countries, 'empty_value' => '', 'required'=>false))
                    ->getForm();
            }
        }
        
        $listTypeFile = array();
        $listFile = array();
        $files_countries = array();
        $types_file = array();
        
        if ($current_country[0] != '') {
            $groups = $this->getDoctrine()->getRepository('LizeoUserBundle:Group')->findGroupByCountry($current_country[0]);
            
            if (!is_null($groups)) {
                $list_group = array();
                
                if (sizeof($groups) > 1) {
                    foreach ($groups as $group) {
                        $list_group[] = $group->getId();
                    }
                } else {
                    $list_group = $groups[0]->getId();
                }
                
                $listTypeFile = $this->getDoctrine()->getRepository('LizeoPCPBundle:TypeFile')->findTypeFileByGroup($list_group);
            }
            
            if (!is_null($listTypeFile)) {
                foreach ($listTypeFile as $typeFile) {
                    $listFile[$typeFile->getId()] = $this->getDoctrine()->getRepository('LizeoPCPBundle:File')->findFileByGroupAndTypeFileAndDatePeriod($list_group, $typeFile->getId(), $date);
                    
                    if (sizeof($listFile[$typeFile->getId()]) == 0) {
                        $status = false;
                    }
                }
            }
        } else {
            // CO Type File
            $types_file = $this->getDoctrine()->getRepository('LizeoPCPBundle:TypeFile')->findByCO();
            
            foreach ($countries as $key => $country) {
                foreach($types_file as $type_file) {
                    $files_countries[$key][$type_file->getId()] = null;
                }
            }

            // Uniquement pour les groupes pays
            $files = $this->getDoctrine()->getRepository('LizeoPCPBundle:File')->findForCheckCountry($date.'-01');
            
            foreach ($files as $file) {
                $files_countries[$file->getGroup()->getCountry()->getId()][$file->getTypeFile()->getId()] = $file->isValid();
            }
        }

        return array(
            'form'              => $form->createView(),
            'listTypeFile'      => $listTypeFile,
            'listFile'          => $listFile,
            'date'              => $date,
            'locale'            => $this->container->get('session')->getLocale(),
            'countries'         => $countries,
            'files_countries'   => $files_countries,
            'types_file'        => $types_file,
        );
    }
    
    /**
     * @Route("view-file-status/{id_file}.html")
     * @Template
     */
    public function viewFileStatusAction($id_file)
    {
        $file = $this->getDoctrine()->getRepository('LizeoPCPBundle:File')->find($id_file);
        
        if ($file && $file->getGearmanId() != "") {
            $percentage = 0;
            $known = false;
            $execution = false;
            $step = 0;
            $isCOFile = false;
            
            if ($this->container->getParameter('gearman') == 1) {
                $gmclient = new \GearmanClient();
                $gmclient->addServer();
                $result = $gmclient->jobStatus($file->getGearmanId());
                $known = $result[0];
                $execution = $result[1];
                $step = $result[2];
                
                if ($result[3] != 0) {
                    $percentage = $result[2] / $result[3] * 100;
                }
            }
            
            $messages = array();
            $success = false;
            $typeErrorMessages = array();
            $errors = array();
            
            if (!$known) {
                if ($file->getTypeFile()->getLogTable() != '') {
                    $result = $this->getDoctrine()->getRepository('LizeoPCPBundle:'.$file->getTypeFile()->getLogTable())->findErrorMessages($file->getName(), array(0, 1));
                    
                    if ($file->getTypeFile()->getLogTable() == "FileRejectedCo") {
                        $isCOFile = true;
                        $typeErrorMessages = $this->getDoctrine()->getRepository('LizeoPCPBundle:'.$file->getTypeFile()->getLogTable())->findTypeErrorMessages($file->getName(), array(0, 1));
                        
                        foreach ($result as $message) {
                            $messages[$message->getErrorLevel()][$message->getErrorCode()][] = $message;
                        }
                        
                        $errors_code = $this->getDoctrine()->getRepository('LizeoPCPBundle:ErrorCode')->findByLevel(array(0, 1));
                        
                        foreach ($errors_code as $error) {
                            $errors[$error->getCode()] = $error;
                        }
                    } else {
                        $messages = $result;
                    }
                }
                
                if ($this->container->getParameter('gearman') == 1) {
                    if ($file->getGearmanReturnCode() == GEARMAN_SUCCESS) {
                        $success = true;
                    }
                }
            }
        } else {
            $error = 1;
            
            if ($file && $file->getGearmanId() == "") {
                $error = 2;
            }
            
            return $this->render('LizeoPCPBundle:Default:viewFileStatusError.html.twig', array('error' => $error));
        }
        
        return array(
            'file'              => $file,
            'known'             => $known,
            'step'              => $step,
            'percentage'        => $percentage,
            'success'           => $success,
            'messages'          => $messages,
            'isCOFile'          => $isCOFile,
            'typeErrorMessages' => $typeErrorMessages,
            'errors'            => $errors,
        );
    }
    
    /**
     * @Route("download/file/{id_file}.html")
     */
    public function downloadAction($id_file)
    {
        $file = $this->getDoctrine()->getRepository('LizeoPCPBundle:File')->find($id_file);
        $user = $this->get('security.context')->getToken()->getUser();
        
        if (false === $this->get('security.context')->isGranted('ROLE_CENTRAL')) {
            if (!$user->hasGroup($file->getGroup()->getName())) {
                return $this->render('LizeoPCPBundle:Default:downloadBadAccess.html.twig');
            }
        }
        
        if (!$file) {
            return $this->render('LizeoPCPBundle:Default:downloadError.html.twig');
        }
        
        $filename = $this->container->getParameter('www_dir').$file->getUrl();
        
        if (!file_exists($filename)) {
            return $this->render('LizeoPCPBundle:Default:downloadError.html.twig');
        }
        
        $type = mime_content_type($filename);
        header('Content-Type: application/force-download');
        header('Content-Transfer-Encoding: '.$type.'\n');
        header('Content-Length: '. filesize($filename));
        header('Content-disposition: attachment; filename='. $file->getName());
        header('Pragma: no-cache');
        header('Cache-Control: no-store, no-cache, must-revalidate, post-check=0, pre-check=0');
        header('Expires: 0');
        
        return new \Symfony\Component\HttpFoundation\Response(readfile($filename));
    }
    
    /**
     * @Route("download/excel-template/{date}/{filename}")
     */
    public function downloadExcelTemplate($date, $filename)
    {
        $file = $this->container->getParameter('excel_template_local_directory').$date."/".$filename;
        
        if (!file_exists($file)) {
            return $this->render('LizeoPCPBundle:Default:downloadError.html.twig', array('filename' => $filename));
        }
        
        $user = $this->get('security.context')->getToken()->getUser();
        
        $downloadFile = new DownloadFile();
        $downloadFile->setFilename($filename);
        $downloadFile->setUser($user);
        $em = $this->getDoctrine()->getEntityManager();
        $em->persist($downloadFile);
        $em->flush();
        
        $type = mime_content_type($file);
        header('Content-Type: application/force-download');
        header('Content-Transfer-Encoding: '.$type.'\n');
        header('Content-Length: '. filesize($file));
        header('Content-disposition: attachment; filename='. $filename);
        header('Pragma: no-cache');
        header('Cache-Control: no-store, no-cache, must-revalidate, post-check=0, pre-check=0');
        header('Expires: 0');
        
        return new \Symfony\Component\HttpFoundation\Response(readfile($file));
    }
    
    
    /**
     * @Route("contact.html")
     * @Template()
     */
    public function contactAction()
    {
        $success = 0;
        $choices = array(   "Demande d'information" => "contact.request_information",
                            "Rapport de dysfonctionnement" => "contact.report_dysfunction",
                            "Divers" => "contact.various",
        );
        
        $form = $this->createFormBuilder(new Contact())
                ->add('subject', 'choice', array('choices' => $choices))
                ->add('message', 'textarea')
                ->getForm();
        
        if ($this->getRequest()->getMethod() == 'POST') {
            $form->bindRequest($this->getRequest());
            
            if ($form->isValid()) {
                $contact = $form->getData();
                $body = "Ce email a été envoyé par ".$this->get('security.context')->getToken()->getUser()->getUsername()." : ".$this->get('security.context')->getToken()->getUser()->getEmail()."\n\n";
                $body .= $contact->getMessage();
                $message = \Swift_Message::newInstance()
                    ->setSubject('PCP : '.$contact->getSubject())
                    ->setFrom(array($this->get('security.context')->getToken()->getUser()->getEmail() => $this->get('security.context')->getToken()->getUser()->getUsername()))
                    ->setTo($this->container->getParameter('email_contact'))
                    ->setBody($body);
                
                try {
                    if ($this->get('mailer')->send($message, $fail)) {
                        $success = 1;
                    } else {
                        $success = 2;
                    }
                } catch (Swift_TransportException $e) {
                    $success = 2;
                }
            }
        }
        
        return array(
            'form' => $form->createView(),
            'success' => $success,
        );
    }
}
