<?php

namespace Lizeo\PCPBundle\Entity;

use Lizeo\PCPBundle\Model\File as AbstractFile;
use Doctrine\ORM\Mapping as ORM;
use Lizeo\PCPBundle\Validator\FileName;
use Symfony\Component\Validator\ExecutionContext;
use Symfony\Component\Validator\Constraints as Assert;
use Lizeo\PCPBundle\Utils\FileNameParse;

/**
 * @ORM\Entity(repositoryClass="Lizeo\PCPBundle\Entity\Repository\FileRepository")
 * @ORM\Table(name="sy_file")
 * @ORM\HasLifecycleCallbacks
 * @Assert\Callback(methods={"isValidFile"})
 */
class File extends AbstractFile
{
    /**
     * @ORM\Id
     * @ORM\Column(type="integer")
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    protected $id;
    
    /**
     *
     * @ORM\Column(type="string")
     */
    protected $name;
    
    /**
     *
     * @ORM\Column(type="string")
     */
    protected $url;
    
    /**
     * @ORM\Column(type="decimal")
     */
    protected $size;
    
    /**
     *
     * @ORM\Column(type="datetime")
     */
    protected $date_upload;
    
    /**
     *
     * @ORM\Column(type="date")
     */
    protected $date_period;
    
    /**
     * @ORM\ManyToOne(targetEntity="TypeFile") 
     */
    protected $type_file;
    
    /**
     * @ORM\ManyToOne(targetEntity="Lizeo\UserBundle\Entity\User") 
     */
    protected $user;
    
    /**
     * @ORM\ManyToOne(targetEntity="Lizeo\UserBundle\Entity\Group") 
     */
    protected $group;
    
    /**
     *
     * @ORM\Column(type="boolean") 
     */
    protected $used;
    
    /**
     *
     * @ORM\Column(type="boolean") 
     */
    protected $valid;
    
    /**
     *
     * @ORM\Column(type="integer", columnDefinition="TINYINT(1) NOT NULL DEFAULT 0")
     */
    protected $reload;
    
    /**
     *
     * @FileName()
     */
    protected $file;
    
    /**
     *
     * @ORM\Column(type="string", nullable=true)
     */
    protected $gearman_id;
    
    /**
     *
     * @ORM\Column(type="integer", nullable=true) 
     */
    protected $gearman_return_code;
    
    /**
     * @ORM\Column(type="integer", columnDefinition="TINYINT(1) NOT NULL DEFAULT 0")
     */
    protected $status;
    
    public $www_dir;
    
    public function __construct()
    {
        $this->date_upload = new \DateTime();
        $this->used = false;
        $this->valid = false;
        $this->reload = false;
        $this->status = false;
    }
    
    public function setWwwDir($dir)
    {
        $this->web_upload_dir = $dir;
        
        return $this;
    }
    
    public function getUrl()
    {
        return $this->url;
    }
    
    public function setUrl($url)
    {
        $this->url = $url;
    }
    
    public function getDateUpload()
    {
        return $this->date_upload;
    }
    
    public function setTypeFile($type_file)
    {
        $this->type_file = $type_file;
    }
    
    public function getTypeFile()
    {
        return $this->type_file;
    }
    
    public function setUser($user)
    {
        $this->user = $user;
    }
    
    public function getUser()
    {
        return $this->user;
    }
    
    public function setGroup($group)
    {
        $this->group = $group;
        
        return $this;
    }
    
    public function getGroup()
    {
        return $this->group;
    }
    
    public function setFile($file)
    {
        $this->file = $file;
    }
    
    public function getFile()
    {
        return $this->file;
    }
    
    public function getAbsolutePath($date = null)
    {
        return null === $this->url ? null : $this->getUploadRootDir($date).'/'.$this->url;
    }

    public function getWebPath($date = null)
    {
        return null === $this->url ? null : $this->getUploadDir($date).'/'.$this->url;
    }

    protected function getUploadRootDir($date = null)
    {
        return $this->www_dir.$this->getUploadDir($date);
    }

    protected function getUploadDir($date = null)
    {
        if (is_null($date)) {
            $date = date("Ym");
        }
        
        $date = substr($date, 0, 6);
        
        return 'uploads/'.$date;
    }
    
    /**
     * @ORM\PrePersist()
     * @ORM\PreUpdate() 
     */
    public function preUpload()
    {
        if (null !== $this->file) {
            /*
             * this solution does not work with microsoft office file and transform for example xlsx in zip extension
             * so we must get extension by parsing file name's
             * 
             * $this->name = str_replace('.'.$this->file->guessExtension(), '', $this->file->getClientOriginalName()).'.'.  uniqid().'.'.$this->file->guessExtension();
             *
             */
            
            $date = $this->date_period->format("Ym");
            $extension = explode('.', $this->file->getClientOriginalName());
            $extension = $extension[sizeof($extension) - 1];
            $name = substr($this->file->getClientOriginalName(), 0, - strlen($extension) - 1);
            $this->name = $name.'_'.uniqid().'.'.$extension;
            $this->url = $this->getUploadDir($date).'/'.$this->name;
            $this->size = $this->file->getClientSize();
        }
    }
    
    /**
     * @ORM\PostPersist()
     * @ORM\PostUpdate() 
     */
    public function upload()
    {
        if (!is_null($this->file)) {
            // check if the directory is created
            $filename = $this->file->getClientOriginalName();
            $date = $this->date_period->format("Ym");
            
            if (!is_dir($this->getUploadRootDir($date))) {
                mkdir($this->getUploadRootDir($date));
            }

            $this->file->move($this->getUploadDir($date), $this->url);
            $this->file = null;
        }
    }
    
    /**
     * @ORM\PostRemove() 
     */
    public function removeUpload()
    {
        $date = $this->date_period->format("Ym");
        
        if ($file = $this->getAbsolutePath($date)) {
            unlink($file);
        }
    }
    
    /**
     * Check if type file's upload correspond to the type file's selected
     * @param ExecutionContext $context 
     */
    public function isValidFile(ExecutionContext $context)
    {
        try {
            $parse = new \Lizeo\PCPBundle\Utils\FileNameParse($this->file->getClientOriginalName());
            
            if (strtolower($this->type_file) != $parse->getTag()) {
                $propertyPath = $context->getPropertyPath().'.file';
                $context->setPropertyPath($propertyPath);
                $context->addViolation('Type file does not correspond to the type file selected and must be "%type_file%"', array('%type_file%' => strtoupper($this->type_file)), null);
            } else if ($parse->getCountryCode() != strtolower ($this->getGroup()->getCountry()->getCode())) {
                $propertyPath = $context->getPropertyPath().'.file';
                $context->setPropertyPath($propertyPath);
                $context->addViolation('The file\'s country must be the same as you select "%country%"', array('%country%' => $this->getGroup()->getCountry()->getName()), null);
            } else if ($this->getDatePeriod()->format("Ym"."01") != $parse->getDate()) {
                $propertyPath = $context->getPropertyPath().'.file';
                $context->setPropertyPath($propertyPath);
                $context->addViolation('The file\'s date must be the same as you select "%date_period%"', array('%date_period%' => $this->getDatePeriod()->format("Ym"."01")), null);
            }
        } catch (\Exception $e) {
        }
    }
}
