<?php

namespace Lizeo\PCPBundle\Entity\Repository;

use Doctrine\ORM\EntityRepository;

class CountryRepository extends EntityRepository
{
    public function findOneCountryByCode($code)
    {
        $query = $this->_em->createQuery('SELECT c FROM LizeoPCPBundle:Country c WHERE c.code = :code_country')
                      ->setParameter('code_country', $code);
        
        try {
            return $query->getSingleResult();
        } catch (\Doctrine\ORM\NoResultException $e) {
            return null;
        }
    }
    
    public function findAll($enabled = false, $is_all = null, $link = false)
    {
        $qb = $this->findAllQuery($enabled, $is_all, $link);
        
        try {
            return $qb->getQuery()->getResult();
        } catch (\Doctrine\ORM\NoResultException $e) {
            return null;
        }
    }
    
    public function findAllQuery($enabled = false, $is_all = null, $link = false)
    {
        $qb = $this->createQueryBuilder('c');
        $conditions = array();
        
        if ($enabled) {
            $qb->andWhere('c.enabled = 1');
        }
        
        if(!is_null($is_all)) {
            if ($is_all) {
                $qb->andWhere('c.is_all = 1');
            } else {
                $qb->andWhere('c.is_all = 0');
            }
        }
        
        if ($link) {
            $qb->andWhere(
                $qb->expr()->in('c.id', 
                    $this->createQueryBuilder('g1')
                            ->select('c2.id')
                            ->from('LizeoUserBundle:Group', 'g2')
                            ->innerJoin('g2.country', 'c2')
                            ->getDQL()
                )      
            );
        }
        
        $qb->orderBy('c.name', 'ASC');
        
        return $qb;
    }
    
    /**
     * Retrieve only countries not link to user's group
     * @param type $entityRepository
     * @param type $exclude_id
     * @return QueryBuilder 
     */
    public function findCountryNotLinkToGroupQuery($exclude_id = 0)
    {
        $qb = $this->createQueryBuilder('c');
        $qb->where(
                $qb->expr()->notIn('c.id', 
                        $this->createQueryBuilder('g1')
                            ->select('c2.id')
                            ->from('LizeoUserBundle:Group', 'g2')
                            ->innerJoin('g2.country', 'c2')
                            ->getDQL()
                )
        )
        ->orWhere('c.id = :exclude_id')
        ->setParameter('exclude_id', $exclude_id);
        
        return $qb;
    }
}
