<?php

namespace Lizeo\PCPBundle\Entity\Repository;

use Doctrine\ORM\EntityRepository;

class FileRejectedCoRepository extends EntityRepository
{
    public function findErrorMessages($filename, $error_levels = null)
    {
        $qb = $this->createQueryBuilder('f');
        $qb->select('f')
            ->where($qb->expr()->like('f.filename', ':filename'))
            ->orderBy('f.error_level, f.error_code, f.line_number')
            ->setParameter('filename', '%'.$filename.'%');
        
        if (!is_null($error_levels)) {
            if (is_array($error_levels)) {
                $qb->andWhere($qb->expr()->in('f.error_level', $error_levels));
            } else {
                $qb->andWhere('f.error_level = :error_levels')
                        ->setParameter('error_levels', $error_levels);
            }
        }
        
        try {
            return $qb->getQuery()->getResult();
        } catch (\Doctrine\ORM\NoResultException $e) {
            return null;
        }
    }
    
    public function findTypeErrorMessages($filename, $error_levels = null)
    {
        $qb = $this->createQueryBuilder('f');
        $qb->select('f.error_level, f.error_code, f.error_message, count(f) AS error_count')
            ->where($qb->expr()->like('f.filename', ':filename'))
            ->groupBy('f.error_code')
            ->orderBy('f.error_level, f.error_code')
            ->setParameter('filename', '%'.$filename.'%');
        
        if (!is_null($error_levels)) {
            if (is_array($error_levels)) {
                $qb->andWhere($qb->expr()->in('f.error_level', $error_levels));
            } else {
                $qb->andWhere('f.error_level = :error_levels')
                        ->setParameter('error_levels', $error_levels);
            }
        }
        
        try {
            return $qb->getQuery()->getResult();
        } catch (\Doctrine\ORM\NoResultException $e) {
            return null;
        }
    }
}
