<?php

namespace Lizeo\PCPBundle\Entity\Repository;

use Doctrine\ORM\EntityRepository;

class FileRepository extends EntityRepository
{
    /**
     *
     * @param type $date : datetime YYY-MM-DD H:i:s
     * @param type $reload : boolean
     */
    public function findByDateUploadAndReload($date, $reload = false)
    {
        $qb = $this->createQueryBuilder('f')
                ->innerJoin('f.user', 'u')
                ->where('f.date_upload < :date')
                ->andWhere('f.reload = :reload')
                ->andWhere('f.used = 1')
                ->andWhere('f.valid = 1')
                ->setParameters(array(
                    'date' => $date,
                    'reload' => $reload,
                ));
        
        try {
            return $qb->getQuery()->getResult();
        } catch(\Doctrine\ORM\NoResultException $e) {
            return null;
        }
    }
    
    public function updateReloadByDateUpload($date, $reload = false)
    {
        $qb = $this->createQueryBuilder('f')
                ->update()
                ->set('f.reload', ':reload')
                ->where('f.date_upload < :date')
                ->setParameters(array(
                    'date' => $date,
                    'reload' => $reload,
                ));
        
        try {
            return $qb->getQuery()->getResult();
        } catch(\Doctrine\ORM\NoResultException $e) {
            return null;
        }
    }
    
    /**
     *
     * @param type $date : YYYY-MM-DD
     */
    public function findByDateUpload($date)
    {
        $date1 = new \DateTime();
        $date1->setDate(substr($date, 0, 4), substr($date, 5, 2), substr($date, 8, 2));
        $date2 = new \DateTime();
        $date2->setDate(substr($date, 0, 4), substr($date, 5, 2), substr($date, 8, 2));
        $date2->add(new \DateInterval("P1D"));
        
        $qb = $this->createQueryBuilder('f')
                    ->innerJoin('f.user', 'u')
                    ->innerJoin('f.group', 'g')
                    ->leftJoin('g.country', 'c')
                    ->where('f.date_upload BETWEEN :date_start AND :date_end')
                    ->orderBy('f.date_upload', 'DESC')
                    ->setParameters(array(
                        'date_start' => $date1->format("Y-m-d"), 
                        'date_end' => $date2->format("Y-m-d")
              ));
        
        try {
            return $qb->getQuery()->getResult();
        } catch(\Doctrine\ORM\NoResultException $e) {
            return null;
        }
    }
    
    /**
     *
     * @param type $date_period
     * @return null 
     */
    public function findForCheckCountry($date_period)
    {
        $dql = 'SELECT f '
                .'FROM LizeoPCPBundle:File f '
                .'INNER JOIN f.type_file t '
                .'INNER JOIN f.group g '
                .'INNER JOIN g.country c '
                .'WHERE f.date_period = :date_period '
                .'AND t.id IN (7, 13, 14)'
                .'AND f.date_upload = ('
                    .'SELECT MAX(f1.date_upload) '
                    .'FROM LizeoPCPBundle:File f1 '
                    .'INNER JOIN f1.type_file t1 '
                    .'INNER JOIN f1.group g1 '
                    .'INNER JOIN g1.country c1 '
                    .'WHERE f.date_period = f1.date_period '
                    .'AND c.id = c1.id '
                    .'AND t.id = t1.id '
                .')';
        
        $query = $this->getEntityManager()->createQuery($dql)->setParameter('date_period', $date_period);
        
        try {
            return $query->getResult();
        } catch (\Doctrine\ORM\NoResultException $e) {
            return null;
        }
    }
    
    /**
     * Get files by group, type file and upload date
     * @param type $user_id
     * @param type $type_file_id
     * @param type $date_upload - format YYYY-MM
     * @return null 
     */
    public function findFileByGroupAndTypeFileAndDatePeriod($group_id, $type_file_id, $date_period)
    {
        $sql = 'SELECT f FROM LizeoPCPBundle:File f WHERE f.group ';
        
        if (is_array($group_id)) {
            if (sizeof($group_id) > 1) {
                $sql .= 'IN (:group_id)';
            } else if(sizeof($group_id) == 1) {
                $sql .= ' = :group_id ';
            } else {
                return null; 
            }
        } else {
            $sql .= ' = :group_id ';
        }
        
        $sql .= ' AND f.type_file = :type_file_id AND f.date_period = :date_period ORDER BY f.date_upload DESC';
        $query = $this->_em->createQuery($sql)
                      ->setParameter('group_id', $group_id)
                      ->setParameter('type_file_id', $type_file_id)
                      ->setParameter('date_period', $date_period.'-01');
        
        try {
            return $query->getResult();
        } catch (\Doctrine\ORM\NoResultException $e) {
            return null;
        }
    }
    
    /**
     * Reset used file to false
     * @param type $group_id
     * @param type $type_file_id
     * @param type $date_upload - format YYYY-MM-DD
     * @return type 
     */
    public function resetUsedFile($group_id, $type_file_id, $date_period)
    {
        $query = $this->_em->createQuery('UPDATE LizeoPCPBundle:File f SET f.used = 0 WHERE f.date_period = :date_period AND f.group = :group_id AND f.type_file = :type_file_id')
                    ->setParameter('date_period', $date_period)
                    ->setParameter('group_id', $group_id)
                    ->setParameter('type_file_id', $type_file_id);
        
        return $query->execute();
    }
    
    /**
     * 
     * @param type $file_id 
     * @return boolean
     */
    public function isMostRecent($file_id, $group_id, $type_file_id, $date_period)
    {
        $query = $this->_em->createQuery('SELECT f FROM LizeoPCPBundle:File f WHERE f.date_period = :date_period AND f.group = :group_id AND f.type_file = :type_file_id ORDER BY f.date_upload DESC')
                    ->setParameter('date_period', $date_period)
                    ->setParameter('group_id', $group_id)
                    ->setParameter('type_file_id', $type_file_id)
                    ->setMaxResults(1);
        
        try  {
            $object = $query->getSingleResult();
            
            if ($object->getId() == $file_id) {
                return true;
            }
            
            return false;
        } catch (\Doctrine\ORM\NoResultException $e) {
            return true;
        }
    }
    
    /**
     * Check if at least one file is used
     * @param type $product_line
     * @param type $country_id
     * @param type $date_period 
     */
    public function atLeastOneUsed($product_line, $country_id, $date_period)
    {
        $qb = $this->createQueryBuilder('f')
                ->select('count(f)')
                ->innerJoin('f.group', 'g')
                ->where('g.country = :country_id')
                ->andWhere('g.product_line = :product_line')
                ->andWhere('f.date_period = :date_period')
                ->andWhere('f.used = 1')
                ->setParameters(array(
                    'country_id' => $country_id,
                    'product_line' => $product_line,
                    'date_period' => $date_period,
                ));
        
        $result = $qb->getQuery()->getSingleScalarResult();
        
        if ($result > 0) {
            return true;
        }
        
        return false;
    }
    
    /**
     * Get the last file used for a country, a product line, a season and a date period
     * @param type $country
     * @param type $prodult_line
     * @param type $season
     * @param type $date_period
     */
    public function lastUsed($country, $prodult_line, $season, $date_period) {
        $name = "CO_".$country."_".$prodult_line."_".$season."_".$date_period."%";
        $qb = $this->createQueryBuilder('f')
                ->where('f.used = 1')
                ->andWhere('f.valid = 1')
                ->andWhere('f.name LIKE :name')
                ->orderBy('f.date_upload', 'DESC')
                ->setParameter("name", $name);
        
        try  {
            return $qb->getQuery()->getSingleResult();
        } catch (\Doctrine\ORM\NoResultException $e) {
            return null;
        }
    }
}
