<?php

namespace Lizeo\PCPBundle\Entity\Repository;

use Doctrine\ORM\EntityRepository;

class TypeFileRepository extends EntityRepository
{
    public function findByCO()
    {
        return $this->findByTag('CO\_%');
    }
    
    /**
     * Find TypeFile by Tag
     * @return null 
     */
    public function findByTag($tag)
    {
        $qb = $this->createQueryBuilder('t');
        $qb->where($qb->expr()->like('t.tag', ':tag'))
                ->setParameter('tag', $tag);
        
        try {
            return $qb->getQuery()->getResult();
        } catch (\Doctrine\ORM\NoResultException $e) {
            return null;
        }
    }
    
    /**
     *
     * @param integer $group_id 
     */
    public function findTypeFileByGroup($group_id, $month = null)
    {
        if ((is_array($group_id) && sizeof($group_id) == 0) || empty($group_id)) {
            return null;
        }
        
        if (is_null($month)) {
           $month = date('m');
        }
        
        $qb = $this->createQueryBuilder('t');
        $qb->innerJoin('t.groups', 'g')
            ->innerJoin('t.type_period', 'p')
            ->where($qb->expr()->like('p.months', ':month'))
            ->andWhere($qb->expr()->in('g.id', ':group_id'))
            ->orderBy('t.position', 'ASC')
            ->addOrderBy('t.name', 'ASC')
            ->setParameter('group_id', $group_id)
            ->setParameter('month', '%'.$month.'%');
        
        try {
            return $qb->getQuery()->getResult();
        } catch (\Doctrine\ORM\NoResultException $e) {
            return null;
        }
    }
   
    public function findOneTypeFileByTag($tag)
    {
        $query = $this->_em->createQuery('SELECT t FROM LizeoPCPBundle:TypeFile t WHERE t.tag = :tag')->setParameter('tag', $tag);
        
        try {
            return $query->getSingleResult();
        } catch (\Doctrine\ORM\NoResultException $e) {
            return null;
        }
    }
    
    public function findAllQuery($enabled = null)
    {
        $qb = $this->createQueryBuilder('t');
        $conditions = array();
        
        if (!is_null($enabled)) {
            if ($enabled) {
                $qb->andWhere('t.enabled = 1');
            }
        }
        
        $qb->orderBy('t.position', 'ASC');
        $qb->addOrderBy('t.name', 'ASC');
        
        return $qb;
    }
}
