<?php

namespace Lizeo\PCPBundle\Model;

abstract class TypeFile
{
    CONST JOB_IMPORT_CONTEXT = "import_context";
    CONST JOB_IMPORT_TS_ALL = "import_ts_all";
    CONST JOB_IMPORT_CO_ALL = "import_co_all";
    
    protected $id;
    
    /**
     * @var string
     */
    protected $name;
    
    /**
     *
     * @var string 
     */
    protected $tag;
    
    /**
     * @var integer
     */
    protected $day_deadline;
    
    /**
     * @var boolean 
     */
    protected $convert_to_csv;
    
    /**
     * @var string
     */
    protected $csv_tab;

    /**
     * @var integer
     */
    protected $position;
    
    /**
     * @var boolean
     */
    protected $enabled;
    
    /**
     * @var string
     */
    protected $log_table;
    
    /**
     * @var string
     */
    protected $job_talend;
    
    /**
     * @var string
     */
    protected $product_line;
    
    public function __construct($name = "", $date_start = null, $date_end = null, $enabled = true)
    {
        $this->name = $name;
        $this->date_start = $date_start;
        $this->date_end = $date_end;
        $this->enabled = $enabled;
        $this->product_line = ProductLine::PRODUCT_LINE_ALL;
    }

    public function getId()
    {
        return $this->id;
    }

    public function getName()
    {
        return $this->name;
    }
    
    public function getTag()
    {
        return $this->tag;
    }

    public function getDayDeadline()
    {
        if (strlen($this->day_deadline) == 1) {
            return '0'.$this->day_deadline;
        }
        
        return $this->day_deadline;
    }
    
    public function setTag($tag)
    {
        $this->tag = $tag;
    }

    /**
     * @param string $name
     * @return TypeFile
     */
    public function setName($name)
    {
        $this->name = $name;

        return $this;
    }

    /**
     * @param integer $day
     * @return TypeFile
     */
    public function setDayDeadline($day)
    {
        $this->day_deadline = $day;

        return $this;
    }
    
    /**
     * Checks whether the type file is enabled.
     *
     * @return Boolean true if the type file is enabled, false otherwise
     */
    public function isEnabled()
    {
        return $this->enabled;
    }

    /**
     * @param Boolean $boolean
     * @return TypeFile
     */
    public function setEnabled($boolean)
    {
        $this->enabled = (Boolean) $boolean;
        
        return $this;
    }
    
    /**
     * Checks if this type file must be convert to CSV
     * @return Boolean 
     */
    public function isConvertToCSV()
    {
        return $this->convert_to_csv;
    }
    
    /**
     *
     * @param type $boolean
     * @return TypeFile 
     */
    public function setConvertToCSV($boolean)
    {
        $this->convert_to_csv = (Boolean) $boolean;
        
        return $this;
    }
    
    public function getCSVTab()
    {
        return $this->csv_tab;
    }
    
    public function setCSVTab($csv_tab)
    {
        $this->csv_tab = $csv_tab;
        
        return $this;
    }
    
    public function getPosition()
    {
        return $this->position;
    }
    
    public function setPosition($position)
    {
        $this->position = $position;
        
        return $this;
    }
    
    public function getLogTable()
    {
        return $this->log_table;
    }
    
    public function setLogTable($log_table)
    {
        $this->log_table = $log_table;
        
        return $this;
    }
    
    public function getJobTalend()
    {
        return $this->job_talend;
    }
    
    public function setJobTalend($job_talend)
    {
        $this->job_talend = $job_talend;
        
        return $this;
    }
    
    public function getProductLine()
    {
        return $this->product_line;
    }
    
    public function setProductLine($product_line)
    {
        $this->product_line = $product_line;
        return $this;
    }
}
