<?php

namespace Lizeo\PCPBundle\Service;

use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpKernel\Log\LoggerInterface;
use Lizeo\PCPBundle\Entity\File;
use Lizeo\PCPBundle\Entity\Mail;

class Mailer extends Service
{
    CONST INTEGRATION_REPORT = 1;
    CONST FILE_BLOCKED = 2;
    CONST DAILY_REPORT = 3;
    CONST REMINDER_FILE_INTEGRATION = 4;
    CONST REPORTING_RELOAD = 5;
    
    CONST VIEW_INTEGRATION_REPORT = 'integrationReport';
    CONST VIEW_FILE_BLOCKED = 'fileBlocked';
    CONST VIEW_DAILY_REPORT = 'dailyReport';
    CONST VIEW_REMINDER_FILE_INTEGRATION = 'reminderFileIntegration';
    CONST VIEW_REPORTING_RELOAD = 'reportingReload';
    
    public function __construct(ContainerInterface $container, LoggerInterface $logger)
    {
        parent::__construct($container, $logger);
        $this->container->get('session')->setLocale('en');
    }
    
    /**
     * Send integration report of file to the user
     * @param File $file 
     */
    public function sendIntegrationReport(File $file)
    {
        $messages = array();
        $isCOFile = false;
        $typeErrorMessages = array();
        $errors = array();
        
        if ($file->getTypeFile()->getLogTable() != '') {
            $result = $this->getDoctrine()->getRepository('LizeoPCPBundle:'.$file->getTypeFile()->getLogTable())->findErrorMessages($file->getName(), array(0, 1));
            
            if ($file->getTypeFile()->getLogTable() == "FileRejectedCo") {
                $isCOFile = true;
                $typeErrorMessages = $this->getDoctrine()->getRepository('LizeoPCPBundle:'.$file->getTypeFile()->getLogTable())->findTypeErrorMessages($file->getName(), array(0, 1));
                
                foreach ($result as $message) {
                    $messages[$message->getErrorLevel()][$message->getErrorCode()] = true;
                }
                        
                $errors_code = $this->getDoctrine()->getRepository('LizeoPCPBundle:ErrorCode')->findByLevel(array(0, 1));

                foreach ($errors_code as $error) {
                    $errors[$error->getCode()] = $error;
                }
            } else {
                $messages = $result;
            }
        }
        
        $template = 'LizeoPCPBundle:Mail:'.self::VIEW_INTEGRATION_REPORT.'.html.twig';
        $renderedTemplate = $this->container->get('templating')->render($template, array(
            'file' => $file, 
            'messages' => $messages,
            'isCOFile' => $isCOFile,
            'typeErrorMessages' => $typeErrorMessages,
            'errors' => $errors,
            'url_view_file' => $this->getParameter('www').$this->container->get('router')->generate('lizeo_pcp_default_viewfilestatus', array('id_file' => $file->getId()))
        ));
        $this->sendEmailMessage($renderedTemplate, $file->getUser()->getEmail(), self::INTEGRATION_REPORT, $file->getUser(), $file);
    }
    
    public function sendFileBlocked(File $file, $message)
    {
        $template = 'LizeoPCPBundle:Mail:'.self::VIEW_FILE_BLOCKED.'.html.twig';
        $renderedTemplate = $this->container->get('templating')->render($template, array('file' => $file, 'message' => $message));
        $this->sendEmailMessage($renderedTemplate, $this->getParameter('email_support_email'), self::FILE_BLOCKED, $file->getUser(), $file);
    }
    
    public function sendDailyReport()
    {
        $date = new \DateTime("now");
        $date->sub(new \DateInterval("P1D"));
        $result = $this->getDoctrine()->getRepository('LizeoPCPBundle:File')->findByDateUpload($date->format("Y-m-d"));
        
        $template = 'LizeoPCPBundle:Mail:'.self::VIEW_DAILY_REPORT.'.html.twig';
        $renderedTemplate = $this->container->get('templating')->render($template, array('files' => $result));
        $this->sendEmailMessage($renderedTemplate, $this->getParameter('email_support_email'), self::DAILY_REPORT);
    }
    
    /**
     * Send mails to users who don't have push a valid files in comparaison with deadline
     */
    public function sendReminderFileIntegration()
    {
        $list = array();
        $deadlines = $this->getDoctrine()->getRepository('LizeoPCPBundle:TypeFileDeadline')->findByDeadline($this->getParameter('alert_reminder_day'));
        
        foreach ($deadlines as $deadline) {
            $type_file = $deadline->getTypeFile();
            $countries = $this->getDoctrine()->getRepository('LizeoPCPBundle:Country')->findAll(true);
            
            foreach ($countries as $country) {
                if (!$this->getDoctrine()->getRepository('LizeoPCPBundle:File')->atLeastOneUsed($type_file->getProductLine(), $country->getId(), $deadline->getDatePeriod())) {
                    $groups = $this->getDoctrine()->getRepository('LizeoUserBundle:Group')->findGroupByCountryAndProductLine($country->getId(), $type_file->getProductLine());
                    
                    foreach ($groups as $group) {
                        $users = $this->getDoctrine()->getRepository('LizeoUserBundle:User')->findByGroup($group->getId());
                        
                        foreach ($users as $user) {
                            if ($user->hasRole(\Lizeo\UserBundle\Entity\User::ROLE_PAYS)) {
                                $list[$user->getId()]['user'] = $user;
                                $list[$user->getId()]['type_file'][$deadline->getTypeFile()->getId()] = true;
                                $date_period_key = $deadline->getDatePeriod()->format("Ymd");
                                $list[$user->getId()]['files'][$date_period_key][$country->getCode()][] = array(
                                    'country' => $country->getCode(),
                                    'deadline' => $deadline,
                                );
                            }
                        }
                    }
                }
            }
        }
        
        foreach ($list as $element) {
            $user = $element['user'];
            $template = 'LizeoPCPBundle:Mail:'.self::VIEW_REMINDER_FILE_INTEGRATION.'.html.twig';
            $renderedTemplate = $this->container->get('templating')->render($template, array(
                'user' => $user,
                'files' => $element['files'],
                'type_file' => $element['type_file'],
                'www' => $this->getParameter('www'),
                'deadlines' => $deadlines,
            ));
            $this->sendEmailMessage($renderedTemplate, $user->getEmail(), self::REMINDER_FILE_INTEGRATION, $user);
        }
    }
    
    public function sendReportingReload($date)
    {
        $files = $this->getDoctrine()->getRepository('LizeoPCPBundle:File')->findByDateUploadAndReload($date);
        
        foreach ($files as $file) {
            $template = 'LizeoPCPBundle:Mail:'.self::VIEW_REPORTING_RELOAD.'.html.twig';
            $renderedTemplate = $this->container->get('templating')->render($template, array(
                'filename' => $file->getName(),
            ));
            $this->sendEmailMessage($renderedTemplate, $file->getUser()->getEmail(), self::REPORTING_RELOAD, $file->getUser(), $file);
        }
        
        $this->getDoctrine()->getRepository('LizeoPCPBundle:File')->updateReloadByDateUpload($date, true);
    }
    
    public function stopTransport()
    {
        return $this->container->get('mailer')->getTransport()->stop();
    }

    private function sendEmailMessage($renderedTemplate, $email_to, $type, $user = null, $file = null, $cc = null, $bcc = null)
    {
        // Render the email, use the first line as the subject, and the rest as the body
        $renderedLines = explode("\n", trim($renderedTemplate));
        $subject = $renderedLines[0];
        $body = implode("\n", array_slice($renderedLines, 1));

        $message = \Swift_Message::newInstance()
            ->setSubject($subject)
            ->setFrom(array(
                $this->getParameter('email_support_email') => $this->getParameter('email_support_name'),
            ))
            ->setTo($email_to)
            ->addPart($body, 'text/html');
        
        if ($cc != null) {
            if (is_array($cc)) {
                $message->setCc($cc);
            } else {
                $message->addCc($cc);
            }
        }
        
        if ($bcc != null) {
            if (is_array($bcc)) {
                $message->setBcc($bcc);
            } else {
                $message->addBcc($bcc);
            }
        }

        $status = false;
        
        if ($this->getParameter('email_activated') == 1) {
            try {
                $status = $this->container->get('mailer')->send($message);
            } catch(\Exception $e) {
                $status = false;
            }
            
            $mail = new Mail($type, $user, $file, $status);
            $em = $this->getDoctrine()->getEntityManager();
            $em->persist($mail);
            $em->flush();
        }
        
        return $status;
    }
}
