<?php

namespace Lizeo\PCPBundle\Service;

use Symfony\Component\DependencyInjection\ContainerInterface;
use Lizeo\PCPBundle\Entity\TypeFile;
use Lizeo\PCPBundle\Entity\Country;
use FOS\UserBundle\Model\UserInterface;
use Lizeo\PCPBundle\Entity\File;
use Lizeo\PCPBundle\Utils\FileNameParse;

class Manager extends Service
{
    /**
     * Reload last valid and used file for a type file, country, product line, season and period
     * @param \FOS\UserBundle\Model\UserInterface $user
     * @param \Lizeo\PCPBundle\Entity\TypeFile $typeFile
     * @param \Lizeo\PCPBundle\Entity\Country $country
     * @param type $productLine
     * @param type $season
     * @param type $datePeriod
     */
    public function reloadLastFile(UserInterface $user, Country $country, $productLine, $season, $datePeriod)
    {
        $_file = $this->getDoctrine()->getRepository('LizeoPCPBundle:File')->lastUsed($country->getCode(), $productLine, $season, $datePeriod);
        
        if (!is_null($_file)) {
            $_filenameParse = new FileNameParse($_file->getName());
            
            $uniqid = uniqid();
            $name = $_filenameParse->getFileName($uniqid);
            $url = $_filenameParse->getFileUrl($uniqid);
            
            /**
             * Copy the file to reload
             */
            $_filenameSource = $this->container->getParameter('www_dir').DIRECTORY_SEPARATOR.$_file->getUrl();
            $_filenameDest = $this->container->getParameter('www_dir').DIRECTORY_SEPARATOR.$url;
            copy($_filenameSource, $_filenameDest);
            $this->getLogger()->info('Copy '.$_filenameSource.' to '.$_filenameDest);
            
            /**
             * Create a new file from the last file reload
             */
            $this->getLogger()->info('Starting to reload file id '.$_file->getId());
            $file = new File();
            $file->setTypeFile($_file->getTypeFile());
            $file->setName($name);
            $file->setUrl($url);
            $file->setUser($user);
            $file->setSize(filesize($_filenameDest));
            $file->setDatePeriod($_file->getDatePeriod());
            $file->setGroup($_file->getGroup());
            
            $em = $this->getDoctrine()->getEntityManager();
            $em->persist($file);
            $em->flush();
            
            if ($file->getTypeFile()->isConvertToCSV()) {
                $filename = $file->getName().'.csv';
            } else {
                $filename = $file->getName();
            }

            if ($file->getTypeFile()->getJobTalend() == TypeFile::JOB_IMPORT_CONTEXT) {
                $filename = $this->container->getParameter('talend_file_in').$filename;
            }
            
            /**
             * Execute Job talend with this new file
             */
            $this->getLogger()->info('Execute job for file id : '.$file->getId());
            $info = $this->executeJob($file->getTypeFile()->getJobTalend(), $file->getId(), $filename);
            $file->setGearmanId($info[0]);
            $file->setGearmanReturnCode($info[1]);
            
            $em->persist($file);
            $em->flush();
            
            return true;
        }
        
        return false;
    }
    
    /**
     * Execute a job
     * @param type $jobName
     * @param type $fileId
     * @param type $file
     * @return type
     */
    public function executeJob($jobName, $fileId, $file)
    {
        $data = array();
        $data['job_name'] = $jobName;
        $data['file'] = $file;
        $data['id'] = $fileId;
        
        $client = new \GearmanClient();
        $client->addServer();
        $job_handle = $client->doBackground("executeJobTalend", serialize($data));
        $code = $client->returnCode();
        
        return array(0 => $job_handle, 1 => $code);
    }
}