<?php


namespace Lizeo\PCPBundle\Utils;

/**
 * Parse file name
 * @author  Yenkong LYBLIAMAY
 * @version 2012-05-07 
 */
class FileNameParse
{
    private $tag;
    private $filename;
    private $typefile;
    private $countrycode;
    private $categoryvehicle;
    private $season;
    private $date;
    private $uniqid;
    private $extension;
    private $year;
    private $month;
    private $day;
    
    CONST SEPARATOR = "_";
    
    public function __construct($filename)
    {
        $this->filename = $filename;
        
        try {
            $this->parse();
        } catch(\Exception $e) {
            throw new \Exception($e->getMessage());
        }
    }
    
    /**
     * Parse file name's
     */
    private function parse()
    {
        if (empty($this->filename)) {
            throw new Exception('File name\'s is empty');
        }
        
        $parse = explode(self::SEPARATOR, $this->filename);
        
        if (sizeof($parse) < 5 || sizeof($parse) > 7) {
            throw new \Exception('File name\'s pattern must be "[TYPE_FILE]_[COUNTRY_CODE]_[CATEGORY]_[SEASON]_[DATE_YYYYMMDD].[FILE_EXTENSION]"');
        }
        
        $this->typefile = strtolower($parse[0]);
        $this->countrycode = strtolower($parse[1]);
        $this->categoryvehicle = strtolower($parse[2]);
        $this->season = strtolower($parse[3]);
        
        if (sizeof($parse)  == 5) {
            $parse_extension = explode('.', $parse[4]);
            $this->date = $parse_extension[0];
        } else {
            $this->date = $parse[4];
            $parse_extension = explode('.', $parse[5]);
            $this->uniqid = $parse_extension[0];
        }
        
        $this->extension = $parse_extension[1];
        $this->year = substr($this->date, 0, 4);
        $this->month = substr($this->date, 4, 2);
        $this->day = substr($this->date, 6, 2);
        
        /**
         * @todo If extension is .xlsx.csv, we have to get $parse_extension[sizeof($parse_extension) - 1] 
         */
        $this->extension = $parse_extension[1];
        $this->tag = $this->typefile.self::SEPARATOR.$this->countrycode.self::SEPARATOR.$this->categoryvehicle.self::SEPARATOR.$this->season;
        
        /**
         * Exception for type file's tag CO 
         */
        if ($this->typefile == "co") {
            $this->tag = $this->typefile.self::SEPARATOR."[country]".self::SEPARATOR.$this->categoryvehicle.self::SEPARATOR.$this->season;
        }
    }
    
    public function getTag()
    {
        return $this->tag;
    }
    
    public function getTypeFile()
    {
        return $this->typefile;
    }
    
    public function getCountryCode()
    {
        return $this->countrycode;
    }
    
    public function getCategoryVehicle()
    {
        return $this->categoryvehicle;
    }
    
    public function getSeason()
    {
        return $this->season;
    }
    
    public function getDate()
    {
        return $this->date;
    }
    
    public function getUniqid()
    {
        return $this->uniqid;
    }
    
    public function getExtension()
    {
        return $this->extension;
    }
    
    public function getYear()
    {
        return $this->year;
    }
    
    public function getMonth()
    {
        return $this->month;
    }
    
    public function getDay()
    {
        return $this->day;
    }
    
    public function getFormattedDate()
    {
        return $this->day."/".$this->month."/".$this->year;
    }
    
    /**
     * Get file name for file
     */
    public function getFileName($uniqid = null)
    {
        if (empty($this->filename)) {
            throw new Exception('File name\'s is empty');
        }
        
        if (is_null($uniqid)) {
            $uniqid = uniqid();
        }
        
        return strtoupper($this->getTypeFile().self::SEPARATOR.$this->getCountryCode().self::SEPARATOR.$this->getCategoryVehicle().self::SEPARATOR.$this->getSeason()).self::SEPARATOR.$this->getDate().self::SEPARATOR.$uniqid.'.'.$this->extension;
    }
    
    /**
     * Get url for file
     * @param type $directory
     */
    public function getFileUrl($uniqid = null, $directory = "uploads")
    {
        return $directory.DIRECTORY_SEPARATOR.$this->year.$this->month.DIRECTORY_SEPARATOR.$this->getFileName($uniqid);
    }
}
