<?php

namespace Lizeo\PCPBundle\Validator;

use Symfony\Component\Security\Core\Encoder\EncoderFactoryInterface;
use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;
use Symfony\Component\Validator\Exception\UnexpectedTypeException;
use Doctrine\ORM\EntityManager;
use Symfony\Component\Security\Core\SecurityContext;
use Lizeo\PCPBundle\Utils\FileNameParse;

class FileNameValidator extends ConstraintValidator {
    private $entityManager;
    private $securityContext;
    public static $MESSAGE_GLOBAL = "Global message";
    
    public function __construct(EntityManager $entityManager, SecurityContext $securityContext) {
        $this->entityManager = $entityManager;
        $this->securityContext = $securityContext;
    }
    
    public function isValid($value, Constraint $constraint) {
        try {
            // Parse file
            $parse = new FileNameParse($value->getClientOriginalName());

            // Check if type file exist
            $result = $this->entityManager->getRepository('LizeoPCPBundle:TypeFile')->findOneTypeFileByTag($parse->getTag());

            if (is_null($result)) {
                $this->setMessage('Type file "%type_file%" does not exist', array('%type_file%' => $parse->getTag()));
                throw new \Exception(self::$MESSAGE_GLOBAL);
            }

            // Check if country code exist
            $result = $this->entityManager->getRepository('LizeoPCPBundle:Country')->findOneCountryByCode($parse->getCountryCode());
            if (is_null($result)) {
                $this->setMessage('Country code "%country_code%" does not exist', array('%country_code%' => $parse->getCountryCode()));
                throw new \Exception(self::$MESSAGE_GLOBAL);
            }

            // Check if user can upload for this country
            /*$groups = $this->securityContext->getToken()->getUser()->getGroup();
            foreach ($groups as $group) {
                if (!(strtolower($group->getCountry()->getCode()) == $parse->getCountryCode())) {
                    $this->setMessage('You can not upload file for code country "%country_code%"', array('%country_code%' => $parse->getCountryCode()));
                    throw new \Exception(self::$MESSAGE_GLOBAL);
                } else {
                    break;
                }
            }*/

            // Check category of vehicle (TC or PL)
           /* $category_vehicle = array('tc', 'pl');
            if (!in_array($parse->getCategoryVehicle(), $category_vehicle)) {
                $this->setMessage('Category of vehicle must be "TC" or "PL"');
                throw new \Exception(self::$MESSAGE_GLOBAL);
            }
            
            // Check season (SUMMER, WINTER, ALL)
            $seasons = array('summer', 'winter', 'all');
            if (!in_array($parse->getSeason(), $seasons)) {
                $this->setMessage('Season must be "SUMMER" or "WINTER" or "ALL"');
                throw new \Exception(self::$MESSAGE_GLOBAL);
            }*/

            // Check date
            /* Uncomment this line if you want use deadline
             * if ($parse->getDate() != date("Ym")."01") {
                $this->setMessage('Date must be "%date%"', array('%date%' => date('Ym')."01"));
                throw new \Exception(self::$MESSAGE_GLOBAL);
            }*/
            return true;
        } catch (\Exception $e) {
            if ($e->getMessage() != self::$MESSAGE_GLOBAL) {
                $this->setMessage($e->getMessage());
            }
            return false;
        }
    }
}
