<?php

namespace Lizeo\UserBundle\Admin;

use Sonata\AdminBundle\Admin\Admin;
use Sonata\AdminBundle\Datagrid\ListMapper;
use Sonata\AdminBundle\Datagrid\DatagridMapper;
use Sonata\AdminBundle\Validator\ErrorElement;
use Sonata\AdminBundle\Form\FormMapper;
use Lizeo\UserBundle\Entity\User;
use Lizeo\PCPBundle\Entity\Repository\CountryRepository;
use Lizeo\PCPBundle\Entity\Repository\TypeFileRepository;
use Lizeo\PCPBundle\Entity\TypeFile;
use Doctrine\ORM\EntityRepository;
use Lizeo\PCPBundle\Model\ProductLine;

class GroupAdmin extends Admin
{
    protected $datagridValues = array(
        '_page'       => 1,
        '_sort_order' => 'ASC',
        '_sort_by'    => 'position',
    );
    
    protected function configureFormFields(FormMapper $formMapper)
    {
        $id_country = 0;
        
        if (!is_null($this->getSubject()->getCountry())) {
            $id_country = $this->getSubject()->getCountry()->getId();
        }
        
        $formMapper
            ->add('name')
            ->add('roles', 'choice', array( 'expanded' => true, 
                                            'multiple' => true, 
                                            'required' => false,
                                            'choices'  => User::$LIST_ROLE))
                
            ->add('types_file', 'entity',
                    array(
                        'multiple' => true, 
                        'expanded' => true,
                        'required' => false,
                        'class' => 'LizeoPCPBundle:TypeFile', 
                        'query_builder' => function(TypeFileRepository $er) {
                            return $er->findAllQuery(true);
                        })
            )
            ->add('product_line', 'choice', 
                array('required' => true, 'choices' => array(
                    ProductLine::PRODUCT_LINE_ALL => "All",
                    ProductLine::PRODUCT_LINE_TC => "TC",
                    ProductLine::PRODUCT_LINE_PL => "PL",
            )))
            ->add('position')
            ->add('country', 'entity',
                    array(
                        'required' => false,
                        'empty_value' => '',
                        'class' => 'LizeoPCPBundle:Country', 
                        'query_builder' => function(CountryRepository $er) {
                            return $er->findAllQuery(true);
                        })
            )
        ;
    }

    protected function configureDatagridFilters(DatagridMapper $datagridMapper)
    {
        $datagridMapper
            ->add('name')
        ;
    }

    protected function configureListFields(ListMapper $listMapper)
    {
        $listMapper
            ->addIdentifier('name')
            ->addIdentifier('country')
        ;
    }

    public function validate(ErrorElement $errorElement, $object)
    {
        $errorElement
            ->with('name')
                ->assertMaxLength(array('limit' => 32))
            ->end()
        ;
    }
}
