<?php

namespace Lizeo\UserBundle\Admin;

use Sonata\AdminBundle\Admin\Admin;
use Sonata\AdminBundle\Datagrid\ListMapper;
use Sonata\AdminBundle\Datagrid\DatagridMapper;
use Sonata\AdminBundle\Validator\ErrorElement;
use Sonata\AdminBundle\Form\FormMapper;
use Lizeo\UserBundle\Entity\User;
use Lizeo\UserBundle\Entity\Repository\GroupRepository;
use Doctrine\ORM\EntityRepository;

class UserAdmin extends Admin
{
    protected function configureFormFields(FormMapper $formMapper)
    {
        $formMapper
            ->add('username')
            ->add('email', 'email')
            ->add('plainPassword', 'password', array('required' => false))
            ->add('group', 'entity',
                    array(
                        'required' => false,
                        'expanded' => false, 
                        'multiple' => true, 
                        'empty_value' => '',
                        'class' => 'LizeoUserBundle:Group', 
                        'query_builder' => function(GroupRepository $er) {
                            return $er->findAllQuery();
                        })
            )
            ->add('enabled', null, array('required' => false))
        ;
    }

    protected function configureDatagridFilters(DatagridMapper $datagridMapper)
    {
        $datagridMapper
            ->add('username')
            ->add('group')
            ->add('enabled')
        ;
    }

    protected function configureListFields(ListMapper $listMapper)
    {
        $listMapper
            ->addIdentifier('username')
            ->addIdentifier('group')
            ->addIdentifier('enabled')
        ;
    }

    public function validate(ErrorElement $errorElement, $object)
    {
        $errorElement
            ->with('username')
                ->assertMaxLength(array('limit' => 32))
            ->end()
        ;
        
        if ($object->getPlainPassword() == "" && $object->getId() == "") {
            $errorElement
                ->addViolation('You must choose a password')
            ->end()
            ->with('plainPassword')
                ->addViolation('You must choose a password')
            ->end();
        }
        
        $roles = array();
        
        foreach ($object->getGroup() as $group) {
            foreach ($group->getRoles() as $role) {
                $roles[] = $role;    
            }
        }
        
        if (in_array(User::ROLE_CENTRAL, $roles) && in_array(User::ROLE_PAYS, $roles)) {
            $errorElement
                ->addViolation('You cannot choose both central and country groups')
            ->end()
            ->with('group')
                ->addViolation('You cannot choose both central and country groups')
            ->end();
        }
    }
}
