<?php

namespace Lizeo\UserBundle\Entity\Repository;

use Doctrine\ORM\EntityRepository;

class GroupRepository extends EntityRepository
{
    public function findAllQuery($enabled = null)
    {
        $qb = $this->createQueryBuilder('g');
        $conditions = array();
        
        if (!is_null($enabled)) {
            if ($enabled) {
                $qb->andWhere('g.enabled = 1');
            } else {
                $qb->andWhere('g.enabled = 0');
            }
        }
        
        $qb->orderBy('g.position', 'ASC')
           ->addOrderBy('g.name', 'ASC');
        
        return $qb;
    }
    
    public function findOneGroupByCountry($country_id)
    {
        $qb = $this->createQueryBuilder('g')
                ->where('g.country = :country_id')
                ->setParameter('country_id', $country_id)
                ->setMaxResults(1);
        try {
            return $qb->getQuery()->getSingleResult();
        } catch (\Doctrine\ORM\NoResultException $e) {
            return null;
        }
    }
    
    public function findGroupByCountry($country_id)
    {
        $qb = $this->createQueryBuilder('g');
        
        if (is_array($country_id)) {
            $qb->where($qb->expr()->in('g.country', $country_id));
        } else {
            $qb->where('g.country = :country_id')
                ->setParameter('country_id', $country_id);
        }
        
        try {
            return $qb->getQuery()->getResult();
        } catch (\Doctrine\ORM\NoResultException $e) {
            return null;
        }
    }
    
    public function findGroupByCountryAndProductLine($country_id, $product_line)
    {
        $qb = $this->createQueryBuilder('g')
                ->where('g.country = :country_id')
                ->andWhere('g.product_line = :product_line')
                ->setParameter('country_id', $country_id)
                ->setParameter('product_line', $product_line);
        
        try {
            return $qb->getQuery()->getResult();
        } catch (\Doctrine\ORM\NoResultException $e) {
            return null;
        }
    }
}
