<?php

namespace ZooParkBundle\Controller;

use Symfony\Component\HttpFoundation\Request;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Method;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use ZooParkBundle\Entity\Park;
use ZooParkBundle\Form\ParkType;

/**
 * Park controller.
 *
 * @Route("/admin/park")
 */
class ParkController extends Controller
{

    /**
     * Lists all Park entities.
     *
     * @Route("/", name="admin_park")
     * @Method("GET")
     * @Template()
     */
    public function indexAction()
    {
        $em = $this->getDoctrine()->getManager();

        $entities = $em->getRepository('ZooParkBundle:Park')->findAll();

        return array(
            'entities' => $entities,
        );
    }
    /**
     * Creates a new Park entity.
     *
     * @Route("/", name="admin_park_create")
     * @Method("POST")
     * @Template("ZooParkBundle:Park:new.html.twig")
     */
    public function createAction(Request $request)
    {
        $entity = new Park();
        $form = $this->createCreateForm($entity);
        $form->handleRequest($request);

        if ($form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->persist($entity);
            $em->flush();

            return $this->redirect($this->generateUrl('admin_park_show', array('id' => $entity->getId())));
        }

        return array(
            'entity' => $entity,
            'form'   => $form->createView(),
        );
    }

    /**
     * Creates a form to create a Park entity.
     *
     * @param Park $entity The entity
     *
     * @return \Symfony\Component\Form\Form The form
     */
    private function createCreateForm(Park $entity)
    {
        $form = $this->createForm(new ParkType(), $entity, array(
            'action' => $this->generateUrl('admin_park_create'),
            'method' => 'POST',
        ));

        $form->add('submit', 'submit', array('label' => 'Create'));

        return $form;
    }

    /**
     * Displays a form to create a new Park entity.
     *
     * @Route("/new", name="admin_park_new")
     * @Method("GET")
     * @Template()
     */
    public function newAction()
    {
        $entity = new Park();
        $form   = $this->createCreateForm($entity);

        return array(
            'entity' => $entity,
            'form'   => $form->createView(),
        );
    }

    /**
     * Finds and displays a Park entity.
     *
     * @Route("/{id}", name="admin_park_show")
     * @Method("GET")
     * @Template()
     */
    public function showAction($id)
    {
        $em = $this->getDoctrine()->getManager();

        $entity = $em->getRepository('ZooParkBundle:Park')->find($id);

        if (!$entity) {
            throw $this->createNotFoundException('Unable to find Park entity.');
        }

        $deleteForm = $this->createDeleteForm($id);

        return array(
            'entity'      => $entity,
            'delete_form' => $deleteForm->createView(),
        );
    }

    /**
     * Displays a form to edit an existing Park entity.
     *
     * @Route("/{id}/edit", name="admin_park_edit")
     * @Method("GET")
     * @Template()
     */
    public function editAction($id)
    {
        $em = $this->getDoctrine()->getManager();

        $entity = $em->getRepository('ZooParkBundle:Park')->find($id);

        if (!$entity) {
            throw $this->createNotFoundException('Unable to find Park entity.');
        }

        $editForm = $this->createEditForm($entity);
        $deleteForm = $this->createDeleteForm($id);

        return array(
            'entity'      => $entity,
            'edit_form'   => $editForm->createView(),
            'delete_form' => $deleteForm->createView(),
        );
    }

    /**
    * Creates a form to edit a Park entity.
    *
    * @param Park $entity The entity
    *
    * @return \Symfony\Component\Form\Form The form
    */
    private function createEditForm(Park $entity)
    {
        $form = $this->createForm(new ParkType(), $entity, array(
            'action' => $this->generateUrl('admin_park_update', array('id' => $entity->getId())),
            'method' => 'PUT',
        ));

        $form->add('submit', 'submit', array('label' => 'Update'));

        return $form;
    }
    /**
     * Edits an existing Park entity.
     *
     * @Route("/{id}", name="admin_park_update")
     * @Method("PUT")
     * @Template("ZooParkBundle:Park:edit.html.twig")
     */
    public function updateAction(Request $request, $id)
    {
        $em = $this->getDoctrine()->getManager();

        $entity = $em->getRepository('ZooParkBundle:Park')->find($id);

        if (!$entity) {
            throw $this->createNotFoundException('Unable to find Park entity.');
        }

        $deleteForm = $this->createDeleteForm($id);
        $editForm = $this->createEditForm($entity);
        $editForm->handleRequest($request);

        if ($editForm->isValid()) {
            $em->flush();

            return $this->redirect($this->generateUrl('admin_park_edit', array('id' => $id)));
        }

        return array(
            'entity'      => $entity,
            'edit_form'   => $editForm->createView(),
            'delete_form' => $deleteForm->createView(),
        );
    }
    /**
     * Deletes a Park entity.
     *
     * @Route("/{id}", name="admin_park_delete")
     * @Method("DELETE")
     */
    public function deleteAction(Request $request, $id)
    {
        $form = $this->createDeleteForm($id);
        $form->handleRequest($request);

        if ($form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $entity = $em->getRepository('ZooParkBundle:Park')->find($id);

            if (!$entity) {
                throw $this->createNotFoundException('Unable to find Park entity.');
            }

            $em->remove($entity);
            $em->flush();
        }

        return $this->redirect($this->generateUrl('admin_park'));
    }

    /**
     * Creates a form to delete a Park entity by id.
     *
     * @param mixed $id The entity id
     *
     * @return \Symfony\Component\Form\Form The form
     */
    private function createDeleteForm($id)
    {
        return $this->createFormBuilder()
            ->setAction($this->generateUrl('admin_park_delete', array('id' => $id)))
            ->setMethod('DELETE')
            ->add('submit', 'submit', array('label' => 'Delete'))
            ->getForm()
        ;
    }
}
